@@ -24,18 +24,18 @@
 #include <exception>
 #include <vector>
 #include <string>
+#include <stdint.h>
 
-#if _MSC_VER<1800
-    #include <boost/cstdint.hpp>
-    using namespace boost;
-#else
-    #include <stdint.h>
-#endif
-
-#include "hugin_utils/shared_ptr.h"
+#include <memory>
 #include <vigra/stdimage.hxx>
 #include <vigra/imageinfo.hxx>
 
+#ifdef _MSC_VER
+#define THROWNOIMAGESBADDIMENSION
+#else
+#define THROWNOIMAGESBADDIMENSION throw(NoImages, BadDimensions)
+#endif
+
 namespace deghosting {
     
     /** exception called when image dimensions differ
@@ -58,8 +58,8 @@ namespace deghosting {
             }
     };
     
-    typedef sharedPtrNamespace::shared_ptr<vigra::BImage> BImagePtr;
-    typedef sharedPtrNamespace::shared_ptr<vigra::FImage> FImagePtr;
+    typedef std::shared_ptr<vigra::BImage> BImagePtr;
+    typedef std::shared_ptr<vigra::FImage> FImagePtr;
     // type for camera response
     typedef std::vector<float> EMoR;
 
@@ -74,7 +74,7 @@ namespace deghosting {
     class Deghosting
     {
     public:
-        Deghosting() {}
+        Deghosting() : flags(0), debugFlags(0), iterations(0), verbosity(0) {}
         
         /** create weight masks
          * create weight masks for masking out ghosting regions
@@ -84,9 +84,9 @@ namespace deghosting {
         /** load images for processing
          * @param inputFiles images to be processed
          */
-        virtual void loadImages(std::vector<std::string>& inputFiles) throw(NoImages, BadDimensions);
-        virtual void loadImages(std::vector<vigra::ImageImportInfo>& inputFiles) throw(NoImages, BadDimensions);
-        
+        virtual void loadImages(std::vector<std::string>& inputFiles) THROWNOIMAGESBADDIMENSION;
+        virtual void loadImages(std::vector<vigra::ImageImportInfo>& inputFiles) THROWNOIMAGESBADDIMENSION;
+
         /** set advanced flags
          * Allows to change behavior of used algorithm
          * @param flags one of the constants describing advanced mode
