@@ -22,16 +22,16 @@
 */
 
 #include "Executor.h"
+#include "hugin_config.h"
 
 #include <iostream>
 #include <wx/utils.h>
 #include <wx/config.h>
 #include <wx/filename.h>
 #include <wx/log.h>
-#if wxCHECK_VERSION(3,0,0)
 #include <wx/translation.h>
-#else
-#include <wx/intl.h>
+#if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
+#include "base_wx/platform.h"
 #endif
 #include "base_wx/wxPlatform.h"
 
@@ -110,15 +110,21 @@ namespace HuginQueue
             ++i;
         };
         // clean up queue
+        CleanQueue(queue);
+        delete queue;
+        return isSuccessful;
+    };
+
+    void CleanQueue(CommandQueue* queue)
+    {
         while (!queue->empty())
         {
             delete queue->back();
             queue->pop_back();
         };
-        delete queue;
-        return isSuccessful;
     };
 
+
     // return path in internal program (program that is shipped with Hugin)
     wxString GetInternalProgram(const wxString& bindir, const wxString& name)
     {
@@ -126,13 +132,12 @@ namespace HuginQueue
         CFStringRef filename = MacCreateCFStringWithWxString(name);
         wxString fn = MacGetPathToBundledExecutableFile(filename);
         CFRelease(filename);
-
         if (fn == wxT(""))
         {
-            std::cerr << wxString::Format(_("External program %s not found in the bundle, reverting to system path"), file.c_str());
+            std::cerr << wxString::Format(_("External program %s not found in the bundle, reverting to system path"), name.c_str()) << std::endl;
             return name;
         }
-        return filename;
+        return fn;
 #else
         return bindir + name;
 #endif
@@ -152,10 +157,9 @@ namespace HuginQueue
             }
             else
             {
-                std::cerr << wxString::Format(_("WARNING: External program %s not found as specified in preferences, reverting to bundled version"), fn.c_str());
+                std::cerr << wxString::Format(_("WARNING: External program %s not found as specified in preferences, reverting to bundled version"), fn.c_str()) << std::endl;
             };
         };
-
         if (name == wxT("exiftool"))
         {
             wxString exiftoolDirPath = MacGetPathToBundledResourceFile(CFSTR("ExifTool"));
@@ -165,7 +169,7 @@ namespace HuginQueue
             }
             else
             {
-                std::cerr << wxString::Format(_("WARNING: External program %s not found in the bundle, reverting to system path"), file.c_str());
+                std::cerr << wxString::Format(_("WARNING: External program %s not found in the bundle, reverting to system path"), name.c_str()) << std::endl;
                 return wxT("exiftool");
             };
         };
@@ -173,10 +177,9 @@ namespace HuginQueue
         CFStringRef filename = MacCreateCFStringWithWxString(name);
         wxString fn = MacGetPathToBundledExecutableFile(filename);
         CFRelease(filename);
-
         if (fn == wxT(""))
         {
-            std::cerr << wxString::Format(_("WARNING: External program %s not found in the bundle, reverting to system path"), name.c_str());
+            std::cerr << wxString::Format(_("WARNING: External program %s not found in the bundle, reverting to system path"), name.c_str()) << std::endl;
             return name;
         };
         return fn;
@@ -184,27 +187,30 @@ namespace HuginQueue
         if (config->Read(name + wxT("/Custom"), 0l))
         {
             wxString fn = config->Read(name + wxT("/Exe"), wxT(""));
-            wxFileName prog(fn);
-            if (prog.IsAbsolute())
+            if (!fn.IsEmpty())
             {
-                if (prog.FileExists())
+                wxFileName prog(fn);
+                if (prog.IsAbsolute())
                 {
-                    return fn;
-                };
-            }
-            else
-            {
-                // search in PATH
-                wxPathList pathlist;
-                pathlist.Add(bindir);
-                pathlist.AddEnvList(wxT("PATH"));
-                fn = pathlist.FindAbsoluteValidPath(fn);
-                if (!fn.IsEmpty())
+                    if (prog.FileExists())
+                    {
+                        return fn;
+                    };
+                }
+                else
                 {
-                    return fn;
+                    // search in PATH
+                    wxPathList pathlist;
+                    pathlist.Add(bindir);
+                    pathlist.AddEnvList(wxT("PATH"));
+                    fn = pathlist.FindAbsoluteValidPath(fn);
+                    if (!fn.IsEmpty())
+                    {
+                        return fn;
+                    };
                 };
+                std::cerr << wxString::Format(_("WARNING: External program %s not found as specified in preferences, reverting to bundled version"), name.c_str()) << std::endl;
             };
-            std::cerr << wxString::Format(_("WARNING: External program %s not found as specified in preferences, reverting to bundled version"), name.c_str()) << std::endl;
         };
         // no user specified program or not found
 #ifdef __WXMSW__
@@ -225,4 +231,46 @@ namespace HuginQueue
         return s;
     };
 
+#ifdef __WXMSW__
+    // search for executable in program folder and in PATH
+    // add exe extension if no one is given
+    wxString MSWGetProgname(const wxString& bindir, const wxString& name)
+    {
+        wxFileName prog(name);
+        if (prog.IsAbsolute())
+        {
+            if (prog.FileExists())
+            {
+                return prog.GetFullPath();
+            };
+        }
+        else
+        {
+            // search in program folder and in PATH
+            const bool hasExt = prog.HasExt();
+            if (!prog.HasExt())
+            {
+                prog.SetExt("exe");
+            };
+            wxPathList pathlist;
+            pathlist.Add(bindir);
+            pathlist.AddEnvList(wxT("PATH"));
+            const wxString fullName = pathlist.FindAbsoluteValidPath(prog.GetFullName());
+            if (!fullName.IsEmpty())
+            {
+                return fullName;
+            };
+        };
+        return name;
+    };
+#endif
+
+// read a string from setting and remove all whitespaces
+const wxString GetSettingString(wxConfigBase* setting, const wxString& name, const wxString defaultValue)
+{
+    wxString s = setting->Read(name, defaultValue);
+    s = s.Trim(true).Trim(false);
+    return s;
+};
+
 }; // namespace
