@@ -102,6 +102,9 @@ wxString getResponseString(const HuginBase::SrcPanoImage& img)
     case HuginBase::BaseSrcPanoImage::RESPONSE_LINEAR:
         s = _("Linear");
         break;
+    default:
+        s = wxEmptyString;
+        break;
     };
     return s;
 };
@@ -395,11 +398,7 @@ void SaveLensParametersToIni(wxWindow * parent, HuginBase::Panorama *pano, const
             if(!filename.HasExt())
             {
                 filename.SetExt(wxT("ini"));
-#if wxCHECK_VERSION(3,0,0)
                 if (filename.Exists())
-#else
-                if (wxFile::Exists(filename.GetFullPath()))
-#endif
                 {
                     int d = wxMessageBox(wxString::Format(_("File %s exists. Overwrite?"), filename.GetFullPath().c_str()),
                         _("Save project"), wxYES_NO | wxICON_QUESTION);
