@@ -24,7 +24,7 @@
 
 // This class is written based on 'exec' sample of wxWidgets library.
 
-#include <config.h>
+#include "hugin_config.h"
 #include "panoinc_WX.h"
 #include "panoinc.h"
 
@@ -76,7 +76,7 @@ END_EVENT_TABLE()
 // frame constructor
 MyExecPanel::MyExecPanel(wxWindow * parent)
        : wxPanel(parent),
-       m_timerIdleWakeUp(this), m_queue(NULL), m_checkReturnCode(true), m_queueLength(0)
+       m_timerIdleWakeUp(this), m_queue(NULL), m_queueLength(0), m_checkReturnCode(true)
 {
     m_pidLast = 0;
 
@@ -227,11 +227,7 @@ int MyExecPanel::ExecWithRedirect(wxString cmd)
 #endif
 
     MyPipedProcess *process = new MyPipedProcess(this, cmd);
-#if wxCHECK_VERSION(3,0,0)
     m_pidLast = wxExecute(cmd, wxEXEC_ASYNC | wxEXEC_MAKE_GROUP_LEADER, process, &m_executeEnv);
-#else
-    m_pidLast = wxExecute(cmd, wxEXEC_ASYNC | wxEXEC_MAKE_GROUP_LEADER, process);
-#endif
     if ( m_pidLast == 0 )
     {
         wxLogError(_T("Execution of '%s' failed."), cmd.c_str());
@@ -252,9 +248,11 @@ int MyExecPanel::ExecWithRedirect(wxString cmd)
 
 int MyExecPanel::ExecQueue(HuginQueue::CommandQueue* queue)
 {
-#if wxCHECK_VERSION(3,0,0)
     wxConfigBase* config = wxConfigBase::Get();
     const long threads = config->Read(wxT("/output/NumberOfThreads"), 0l);
+    // read all current environment variables
+    wxGetEnvMap(&m_executeEnv.env);
+    // now modify some variables before passing them to wxExecute
     if (threads > 0)
     {
         wxString s;
@@ -271,7 +269,6 @@ int MyExecPanel::ExecQueue(HuginQueue::CommandQueue* queue)
         m_executeEnv.env["TMP"] = tempDir;
 #endif
     };
-#endif
     m_queue = queue;
     m_queueLength = queue->size() + 1;
     if (m_queue->empty())
@@ -345,7 +342,7 @@ void MyExecPanel::RemoveAsyncProcess(MyPipedProcess *process)
 void MyExecPanel::AddToOutput(wxInputStream & s)
 {
     DEBUG_TRACE("");
-#if defined __WXGTK__ && wxCHECK_VERSION(3,0,0)
+#if defined __WXGTK__
     wxTextInputStream ts(s, " \t", wxConvLibc);
 #else
     wxTextInputStream ts(s);
