@@ -19,12 +19,12 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
-#include <config.h>
+#include "hugin_config.h"
 #include "panoinc.h"
 #include "panoinc_WX.h"
 #include "PTWXDlg.h"
@@ -37,8 +37,6 @@ extern "C" {
 
 // Error reporting
 
-wxWindow* appParent = NULL;
-
 static void PTPrintErrorWX(char* fmt, va_list ap)
 {
     char message[257];
@@ -46,7 +44,7 @@ static void PTPrintErrorWX(char* fmt, va_list ap)
     vsprintf(message, fmt, ap);
 	
 //		MessageBox(GetFocus(), (LPSTR)message, (LPSTR)"", MB_OK | MB_ICONHAND) ;
-    wxMessageBox(wxString(message,wxConvLocal), _("Panorama Tools"), wxOK | wxICON_HAND,appParent);
+    wxMessageBox(wxString(message,wxConvLocal), _("Panorama Tools"), wxOK | wxICON_HAND);
 }	
 
 
@@ -130,11 +128,7 @@ static int PTInfoDlgWX ( int command, char* argument )	// Display info: same arg
                 if (dlg == 0) {
                     return FALSE;
                 }
-#if wxCHECK_VERSION(2,8,0)
                 dlg->Pulse(wxString(argument, wxConvLocal));
-#else
-                dlg->Update(0, wxString(argument, wxConvLocal));
-#endif
             }
             return TRUE;
         case _setProgress:
@@ -152,11 +146,7 @@ static int PTInfoDlgWX ( int command, char* argument )	// Display info: same arg
                     {
                         sprintf( text,"%s%s", mainMessage, &(argument[1]) );
                     }
-#if wxCHECK_VERSION(2,8,0)
                     cont = dlg->Pulse(wxString(argument, wxConvLocal));
-#else
-                    cont = dlg->Update(1, wxString(argument, wxConvLocal));
-#endif
                     if (! cont) {
                         return FALSE;
                     }
@@ -180,9 +170,8 @@ static int PTInfoDlgWX ( int command, char* argument )	// Display info: same arg
     return TRUE;
 }
 
-void registerPTWXDlgFcn(wxWindow* parent)
+void registerPTWXDlgFcn()
 {
-    appParent = parent;
     PT_setProgressFcn(&PTProgressWX);
     PT_setErrorFcn(&PTPrintErrorWX);
     PT_setInfoDlgFcn(&PTInfoDlgWX);
