@@ -30,12 +30,13 @@
 #include <algorithms/basic/TranslatePanorama.h>
 #include <algorithms/basic/CalculateMeanExposure.h>
 #include <algorithms/basic/StraightenPanorama.h>
+#include <panodata/ParseExp.h>
 
 namespace PanoCommand
 {
     CombinedPanoCommand::~CombinedPanoCommand()
     {
-        for (std::vector<PanoCommand*>::iterator it = commands.begin(); it != commands.end(); it++)
+        for (std::vector<PanoCommand*>::iterator it = commands.begin(); it != commands.end(); ++it)
         {
             delete *it;
         }
@@ -44,7 +45,7 @@ namespace PanoCommand
     bool CombinedPanoCommand::processPanorama(HuginBase::Panorama & pano)
     {
         bool result = true;
-        for (std::vector<PanoCommand*>::iterator it = commands.begin(); it != commands.end(); it++)
+        for (std::vector<PanoCommand*>::iterator it = commands.begin(); it != commands.end(); ++it)
         {
             result &= (**it).processPanorama(pano);
         }
@@ -140,6 +141,19 @@ namespace PanoCommand
         return true;
     }
 
+    bool UpdateVariablesByParseExpression::processPanorama(HuginBase::Panorama& pano)
+    {
+        if (!m_expression.empty())
+        {
+            Parser::PanoParseExpression(pano, m_expression);
+            return true;
+        }
+        else
+        {
+            return false;
+        };
+    }
+
     bool UpdateOptimizeVectorCmd::processPanorama(HuginBase::Panorama & pano)
     {
         pano.setOptimizeVector(m_optvec);
@@ -348,7 +362,7 @@ namespace PanoCommand
         HuginBase::UIntSet testedLens;
         HuginBase::StandardImageVariableGroups variable_groups(pano);
         HuginBase::ImageVariableGroup & lenses = variable_groups.getLenses();
-        for (HuginBase::UIntSet::const_iterator it = imgNrs.begin(); it != imgNrs.end(); it++)
+        for (HuginBase::UIntSet::const_iterator it = imgNrs.begin(); it != imgNrs.end(); ++it)
         {
             allImgWithSameLens.insert(*it);
             unsigned int lensNr = lenses.getPartNumber(*it);
@@ -374,7 +388,7 @@ namespace PanoCommand
         // it might change as we are setting them
         std::size_t new_new_part_number = new_part_number;
         HuginBase::ImageVariableGroup group(variables, pano);
-        for (HuginBase::UIntSet::iterator it = image_numbers.begin(); it != image_numbers.end(); it++)
+        for (HuginBase::UIntSet::iterator it = image_numbers.begin(); it != image_numbers.end(); ++it)
         {
             group.switchParts(*it, new_new_part_number);
             // update the lens number if it changes.
@@ -388,11 +402,11 @@ namespace PanoCommand
         HuginBase::ImageVariableGroup group(groupVariables, pano);
         if (new_linked_state)
         {
-            for (HuginBase::UIntSet::iterator imageIt = image_numbers.begin(); imageIt != image_numbers.end(); imageIt++)
+            for (HuginBase::UIntSet::iterator imageIt = image_numbers.begin(); imageIt != image_numbers.end(); ++imageIt)
             {
                 // link the variables
                 for (std::set<HuginBase::ImageVariableGroup::ImageVariableEnum>::iterator variableIt = changeVariables.begin();
-                    variableIt != changeVariables.end(); variableIt++)
+                    variableIt != changeVariables.end(); ++variableIt)
                 {
                     group.linkVariableImage(*variableIt, *imageIt);
                 }
@@ -400,11 +414,11 @@ namespace PanoCommand
         }
         else
         {
-            for (HuginBase::UIntSet::iterator imageIt = image_numbers.begin(); imageIt != image_numbers.end(); imageIt++)
+            for (HuginBase::UIntSet::iterator imageIt = image_numbers.begin(); imageIt != image_numbers.end(); ++imageIt)
             {
                 // unlink the variable
                 for (std::set<HuginBase::ImageVariableGroup::ImageVariableEnum>::iterator variableIt = changeVariables.begin();
-                    variableIt != changeVariables.end(); variableIt++)
+                    variableIt != changeVariables.end(); ++variableIt)
                 {
                     group.unlinkVariableImage(*variableIt, *imageIt);
                     group.updatePartNumbers();
@@ -419,7 +433,7 @@ namespace PanoCommand
         HuginBase::StandardImageVariableGroups variable_groups(pano);
         HuginBase::ImageVariableGroup & lenses = variable_groups.getLenses();
         std::set<HuginBase::ImageVariableGroup::ImageVariableEnum>::iterator it;
-        for (it = variables.begin(); it != variables.end(); it++)
+        for (it = variables.begin(); it != variables.end(); ++it)
         {
             lenses.linkVariablePart(*it, lens_number);
         }
@@ -446,7 +460,7 @@ namespace PanoCommand
         // unlink all the variables in the first image.
         DEBUG_ASSERT(image_numbers.size() > 0);
         unsigned int image_index = *image_numbers.begin();
-        for (std::set<HuginBase::ImageVariableGroup::ImageVariableEnum>::iterator it = vars.begin(); it != vars.end(); it++)
+        for (std::set<HuginBase::ImageVariableGroup::ImageVariableEnum>::iterator it = vars.begin(); it != vars.end(); ++it)
         {
             switch (*it)
             {
@@ -461,7 +475,7 @@ namespace PanoCommand
         // now the first image should have a new part in the group.
         // we want to switch the rest of the images to the new part.
         HuginBase::ImageVariableGroup group(vars, pano);
-        for (HuginBase::UIntSet::iterator it = ++image_numbers.begin(); it != image_numbers.end(); it++)
+        for (HuginBase::UIntSet::iterator it = ++image_numbers.begin(); it != image_numbers.end(); ++it)
         {
             std::size_t part_number = group.getPartNumber(image_index);
             group.switchParts(*it, part_number);
