@@ -24,7 +24,7 @@
  *
  */
 
-#include <config.h>
+#include "hugin_config.h"
 
 #include "panoinc_WX.h"
 #include "panoinc.h"
@@ -197,18 +197,6 @@ void copySrcImageExif(HuginBase::SrcPanoImage& destImg, HuginBase::SrcPanoImage
     destImg.setFileMetadata(srcImg.getFileMetadata());
 };
 
-#if !wxCHECK_VERSION(3,0,0)
-//only needed for older wxWidgets version, in newer we are using wxMessageDialog and this workaround is not necessary
-class StackDialog :public wxDialog
-{
-public:
-    void HandleNoButton(wxCommandEvent &e)
-    {
-        EndModal(wxID_NO);
-    };
-};
-#endif
-
 bool getLensDataFromUser(wxWindow * parent, HuginBase::SrcPanoImage & srcImg)
 {
     // display lens dialog
@@ -257,13 +245,6 @@ bool wxAddImagesCmd::processPanorama(HuginBase::Panorama& pano)
     HuginBase::ImageVariableGroup & lenses = variable_groups.getLenses();
     const size_t oldImgCount = pano.getNrOfImages();
 
-    // read number of bands of first image
-    int panoBandCount = 0;
-    if (pano.getNrOfImages() > 0)
-    {
-        vigra::ImageImportInfo info(pano.getImage(0).getFilename().c_str());
-        panoBandCount = info.numBands() - info.numExtraBands();
-    };
     // load additional images...
     for (it = files.begin(); it != files.end(); ++it) {
         const std::string &filename = *it;
@@ -298,15 +279,15 @@ bool wxAddImagesCmd::processPanorama(HuginBase::Panorama& pano)
                     _("Warning"), wxOK | wxICON_EXCLAMATION);
                 continue;
             };
-            if (panoBandCount == 0)
+            if (pano.getNrOfImages() == 0)
             {
-                panoBandCount = bands - extraBands;
+                pano.setNrOfBands(bands - extraBands);
             };
-            if (panoBandCount != bands - extraBands)
+            if (pano.getNrOfBands() != bands - extraBands)
             {
                 wxString s(_("Hugin supports only grayscale or RGB images (without and with alpha channel)."));
                 s.Append(wxT("\n"));
-                if (panoBandCount == 3)
+                if (pano.getNrOfBands() == 3)
                 {
                     s.Append(wxString::Format(_("File \"%s\" is a grayscale image, but other images in project are color images."), fname.c_str()));
                 }
@@ -315,7 +296,7 @@ bool wxAddImagesCmd::processPanorama(HuginBase::Panorama& pano)
                     s.Append(wxString::Format(_("File \"%s\" is a color image, but other images in project are grayscale images."), fname.c_str()));
                 };
                 s.Append(wxT("\n"));
-                s.Append(_("Hugin does not support this mixing. Skipping this image.\nConvert this image to grayscale or RGB image and try loading again."));
+                s.Append(_("Hugin does not support this mixing. Skipping this image.\nConvert this image to grayscale or RGB image respectively and try loading again."));
                 wxMessageBox(s, _("Warning"), wxOK | wxICON_EXCLAMATION);
                 continue;
             };
@@ -545,7 +526,6 @@ bool wxAddImagesCmd::processPanorama(HuginBase::Panorama& pano)
         {
             message = _("Hugin has image stacks detected in the whole project. Stack numbers will be re-assigned on base of this detection. Existing stack assignments will be overwritten.");
         };
-#if wxCHECK_VERSION(3,0,0)
         message.append(wxT("\n"));
         message.append(_("Should the position of images in each stack be linked?"));
         wxMessageDialog dialog(wxGetActiveWindow(), message,
@@ -564,25 +544,6 @@ bool wxAddImagesCmd::processPanorama(HuginBase::Panorama& pano)
         {
             dialog.SetYesNoCancelLabels(_("Link position"), _("Don't link position"), _("Keep existing stacks"));
         };
-#else
-        wxDialog dialog;
-        wxXmlResource::Get()->LoadDialog(&dialog, wxGetActiveWindow(), wxT("stack_detected_dlg"));
-        message.append(wxT(" "));
-        message.append(_("Should the position of images in each stack be linked?"));
-        wxStaticText* text = XRCCTRL(dialog, "stack_text1", wxStaticText);
-        text->SetLabel(message);
-        text->Wrap(350);
-        dialog.Connect(XRCID("wxID_NO"), wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(StackDialog::HandleNoButton));
-        if (oldImgCount == 0)
-        {
-            XRCCTRL(dialog, "wxID_CANCEL", wxButton)->SetLabel(_("Don't assign stacks"));
-        }
-        else
-        {
-            XRCCTRL(dialog, "wxID_CANCEL", wxButton)->SetLabel(_("Keep existing stacks"));
-        };
-        dialog.Layout();
-#endif
         switch (dialog.ShowModal())
         {
             case wxID_OK:
@@ -681,14 +642,14 @@ bool wxLoadPTProjectCmd::processPanorama(HuginBase::Panorama& pano)
                     }
                 }
 
-                wxMessageBox(wxString::Format(_("Image file not found:\n%s\nPlease select correct image"), fname.GetFullPath().c_str()), _("Image file not found"));
+                wxMessageBox(wxString::Format(_("The project file \"%s\" refers to image \"%s\" which was not found.\nPlease manually select the correct image."), filename, fname.GetFullPath()), _("Image file not found"));
 
                 if (basedir == wxT("")) {
                     basedir = fname.GetPath();
                 }
 
                 // open file dialog
-                wxFileDialog dlg(wxGetActiveWindow(), _("Add images"),
+                wxFileDialog dlg(wxGetActiveWindow(), wxString::Format(_("Select image %s"), fname.GetFullName()),
                                  basedir, fname.GetFullName(),
                                  HUGIN_WX_FILE_IMG_FILTER, wxFD_OPEN  | wxFD_FILE_MUST_EXIST | wxFD_PREVIEW, wxDefaultPosition);
                 dlg.SetDirectory(basedir);
@@ -742,6 +703,7 @@ bool wxLoadPTProjectCmd::processPanorama(HuginBase::Panorama& pano)
             // remember icc profile, only from first image
             if (i == 0)
             {
+                pano.setNrOfBands(imginfo.numBands() - imginfo.numExtraBands());
                 pano.setICCProfileDesc(hugin_utils::GetICCDesc(imginfo.getICCProfile()));
             }
             pano.setSrcImage(i, srcImg);
