@@ -41,12 +41,10 @@ class GLOverview;
 class ViewState;
 class wxSpinEvent;
 class wxChoice;
-#if wxCHECK_VERSION(2,9,1)
 //forward declaration for wxInfoBar works only for wxGTK
 //for other systems wxInfoBar is defined as preprocessor macro and not as class
 //class wxInfoBar;
 #include <wx/infobar.h>
-#endif
 
 class MeshManager;
 
@@ -98,7 +96,7 @@ class ImageToogleButtonEventHandler : public wxEvtHandler
 {
 public:
     ImageToogleButtonEventHandler(unsigned int image_number,
-                                  wxToolBarToolBase* identify_toolbutton_in,
+                                  wxToggleButton* identify_button_in,
                                   HuginBase::Panorama * m_pano);
     void OnChange(wxCommandEvent &e);
     void AddIdentifyTool(PreviewIdentifyTool** identify_tool_in);
@@ -109,7 +107,7 @@ private:
     DECLARE_EVENT_TABLE()
     unsigned int image_number;
     std::vector<PreviewIdentifyTool**> identify_tools;
-    wxToolBarToolBase *identify_toolbutton;
+    wxToggleButton* m_identify_button;
     HuginBase::Panorama * m_pano;
 };
 
@@ -306,8 +304,6 @@ protected:
     // void OnOutputChoice(wxCommandEvent & e);
     // update tools according to blend mode choice
     void updateBlendMode();
-    // update the panorama display
-    void updatePano();
     /** event handler for full screen */
     void OnFullScreen(wxCommandEvent &e);
     /** event handler for selection of new mode */
@@ -376,9 +372,9 @@ private:
 
     int m_mode;
     int non_layout_blend_mode;
-    wxToolBar* m_ToolBar_Identify;
-    wxToolBar* m_ToolBar_ColorPicker;
-    wxToolBar* m_ToolBar_editCP;
+    wxToggleButton* m_identify_togglebutton;
+    wxToggleButton* m_colorpicker_togglebutton;
+    wxToggleButton* m_editCP_togglebutton;
     wxNotebook* m_tool_notebook;
     wxPanel* m_projection_panel;
     wxSlider * m_HFOVSlider;
@@ -402,13 +398,8 @@ private:
     wxBitmapButton * m_defaultExposureBut;
     wxTextCtrl* m_exposureText;
     wxSpinButton * m_exposureSpinBut;
-#if wxCHECK_VERSION(2, 9, 1)
     /// Bar for context sensitive projection information.
     wxInfoBar * m_infoBar;
-#else
-    // True if the status bar text has been replaced with projection information
-    bool m_projectionStatusPushed;
-#endif
     //assistant related controls
     wxStaticText * m_imagesText;
     wxButton * m_alignButton;
@@ -420,11 +411,7 @@ private:
     wxMenu* m_filemenuSimple;
     wxMenu* m_filemenuAdvanced;
     wxMenu* m_selectAllMenu;
-#if wxCHECK_VERSION(2,9,2)
     wxButton* m_selectAllButton;
-#else
-    wxBitmapButton* m_selectAllButton;
-#endif
     enum SelectAllMode
     {
         SELECT_ALL_IMAGES = 0,
@@ -450,15 +437,12 @@ private:
 
     wxBoxSizer * m_topsizer;
     wxBoxSizer * m_projParamSizer;
+    wxPanel* m_overviewCommandPanel;
     std::vector<wxStaticText *> m_projParamNamesLabel;
     std::vector<wxTextCtrl *>   m_projParamTextCtrl;
     std::vector<wxSlider *>     m_projParamSlider;
 
-#ifdef USE_TOGGLE_BUTTON
     std::vector<wxToggleButton *> m_ToggleButtons;
-#else
-    std::vector<wxCheckBox *> m_ToggleButtons;
-#endif
     std::vector<wxCheckBox *> m_GroupToggleButtons;
     std::vector<wxPanel *> m_ToggleButtonPanel;
     std::vector<ImageToogleButtonEventHandler *> toogle_button_event_handlers;
