@@ -25,7 +25,7 @@
  *
  */
 
-#include <config.h>
+#include "hugin_config.h"
 #include "panoinc_WX.h"
 #include "panoinc.h"
 #include <time.h>
@@ -155,7 +155,10 @@ bool ImagesPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, co
     config->Flush();
     cpdetector_config.FillControl(m_CPDetectorChoice,true);
     Layout();
-
+#ifdef __WXGTK__
+    // explicitly set focus to propogate correctly key presses/shortcuts
+    m_images_tree->SetFocus();
+#endif
     return true;
 }
 
@@ -254,8 +257,8 @@ void ImagesPanel::panoramaChanged(HuginBase::Panorama & pano)
         m_optPhotoChoice->SetSelection(found);
     };
     const HuginBase::PanoramaOptions opts = m_pano->getOptions();
-    m_overlap->SetValue(hugin_utils::doubleTowxString(opts.outputStacksMinOverlap,3));
-    m_maxEv->SetValue(hugin_utils::doubleTowxString(opts.outputLayersExposureDiff,2));
+    m_overlap->ChangeValue(hugin_utils::doubleTowxString(opts.outputStacksMinOverlap,3));
+    m_maxEv->ChangeValue(hugin_utils::doubleTowxString(opts.outputLayersExposureDiff,2));
 }
 
 void ImagesPanel::panoramaImagesChanged(HuginBase::Panorama &pano, const HuginBase::UIntSet & _imgNr)
@@ -312,11 +315,7 @@ void ImagesPanel::RunCPGenerator(CPDetectorSetting &setting, const HuginBase::UI
 {
     wxConfigBase* config=wxConfigBase::Get();
     long nFeatures = HUGIN_ASS_NCONTROLPOINTS;
-#if wxCHECK_VERSION(2,9,4)
     if(wxGetKeyState(WXK_COMMAND))
-#else
-    if(wxGetKeyState(WXK_CONTROL))
-#endif
     {
         nFeatures = config->Read(wxT("/MainFrame/nControlPoints"), HUGIN_ASS_NCONTROLPOINTS);
         nFeatures = wxGetNumberFromUser(
@@ -399,7 +398,8 @@ void ImagesPanel::OnSelectionChanged(wxTreeEvent & e)
         };
         if(focallength>0)
         {
-            m_focallength->SetValue(hugin_utils::doubleTowxString(focallength,m_degDigits));
+            // use ChangeValue explicit, SetValue would create EVT_TEXT event which collides with our TextKillFocusHandler
+            m_focallength->ChangeValue(hugin_utils::doubleTowxString(focallength,m_degDigits));
         }
         else
         {
@@ -407,7 +407,7 @@ void ImagesPanel::OnSelectionChanged(wxTreeEvent & e)
         };
         if(cropFactor>0)
         {
-            m_cropfactor->SetValue(hugin_utils::doubleTowxString(cropFactor,m_degDigits));
+            m_cropfactor->ChangeValue(hugin_utils::doubleTowxString(cropFactor,m_degDigits));
         }
         else
         {
