@@ -33,11 +33,7 @@
 #include "hugin/PanoOperation.h"
 
 /** the main images tree control, used on images and optimizer tabs */
-#if wxCHECK_VERSION(2,9,0)
 class ImagesTreeCtrl: public wxcode::wxTreeListCtrl, public HuginBase::PanoramaObserver
-#else
-class ImagesTreeCtrl: public wxTreeListCtrl, public HuginBase::PanoramaObserver
-#endif
 {
 public:
     /** enumeration for grouping mode */
@@ -93,6 +89,8 @@ public:
      *
      *  if a lens or stack is selected it returns all images of the selected lens/stack */
     HuginBase::UIntSet GetSelectedImages();
+    /** sets the flag, if active/disabled image should be marked with different colour */
+    void MarkActiveImages(const bool markActive);
 
 protected:
     /** updates the information for the given image in tree */
@@ -111,10 +109,12 @@ protected:
     void OnEditImageVariables(wxCommandEvent &e);
     /** event handler when dragging begins, veto if dragging is not possible */
     void OnBeginDrag(wxTreeEvent &e);
-    /** event handler when dragging ends, updates the Panorama */
-    void OnEndDrag(wxMouseEvent &e);
+    /** event handler for left up, handles end of dragging and updates of optimizer variables states */
+    void OnLeftUp(wxMouseEvent &e);
     /** event handler for left mouse down, handles toggle of optimizer variables */
     void OnLeftDown(wxMouseEvent &e);
+    /** event handler for mouse motion, handles focussing of check boxes */
+    void OnMouseMove(wxMouseEvent &e);
     /** event handler for left double click */
     void OnLeftDblClick(wxMouseEvent &e);
     /** event handler for select all optimizer variables */
@@ -137,6 +137,10 @@ protected:
     void OnContextMenu(wxTreeEvent & e);
     /** event handler for context menu on header */
     void OnHeaderContextMenu(wxListEvent & e);
+    /** event handler for activate image */
+    void OnActivateImage(wxCommandEvent& e);
+    /** event handler for deactivate image */
+    void OnDeactivateImage(wxCommandEvent& e);
 
 private:
     /** creates all columns and stores information in m_columnMap, m_columnVector, m_editableColumns and m_variableVector */
@@ -152,6 +156,8 @@ private:
     void UpdateOptimizerVariables();
     /** generates submenu for given PanoOperationVector */
     void GenerateSubMenu(wxMenu* menu, PanoOperation::PanoOperationVector* operations, int& id);
+    /** update the font colour for all items */
+    void UpdateItemFont();
 
     // the model
     HuginBase::Panorama * m_pano;
@@ -169,6 +175,8 @@ private:
     GuiLevel m_guiLevel;
     /** true, if in optimizer mode */
     bool m_optimizerMode;
+    /** true, if disabled images should be marked with other font color */
+    bool m_markDisabledImages;
     /** the active display mode */
     DisplayMode m_displayMode;
     /** map for easier access to column information */
@@ -197,6 +205,13 @@ private:
     /** pointer to root item, not shown */
     wxTreeItemId m_root;
 
+    /** stores last item on which the mouse was hovering */
+    wxTreeItemId m_lastCurrentItem;
+    long m_lastCurrentCol;
+    /** stores where left mouse click happend */
+    wxTreeItemId m_leftDownItem;
+    long m_leftDownColumn;
+
     //for saving column width
     wxString m_configClassName;
     DECLARE_EVENT_TABLE()
@@ -205,11 +220,7 @@ private:
 
 
 /** xrc handler */
-#if wxCHECK_VERSION(2,9,0)
 class ImagesTreeCtrlXmlHandler : public wxcode::wxTreeListCtrlXmlHandler
-#else
-class ImagesTreeCtrlXmlHandler : public wxTreeListCtrlXmlHandler
-#endif
 {
     DECLARE_DYNAMIC_CLASS(ImagesTreeCtrlXmlHandler)
 
