@@ -24,12 +24,11 @@
  *
  */
 
-#include <config.h>
-#include <exiv2/exif.hpp>
-#include <exiv2/image.hpp>
+#include "hugin_config.h"
 
 #include <wx/dir.h>
 #include <wx/stdpaths.h>
+#include <wx/wfstream.h>
 #include "panoinc_WX.h"
 #include "panoinc.h"
 
@@ -129,7 +128,8 @@ bool PanoDropTarget::OnDropFiles(wxCoord x, wxCoord y, const wxArrayString& file
             file.GetExt().CmpNoCase(wxT("pts")) == 0 )
         {
             // load project
-            if (mf->CloseProject(true)) {
+            if (mf->CloseProject(true, MainFrame::LOAD_NEW_PROJECT))
+            {
                 mf->LoadProjectFile(file.GetFullPath());
                 // remove old images from cache
                 ImageCache::getInstance().flush();
@@ -194,6 +194,11 @@ bool PanoDropTarget::OnDropFiles(wxCoord x, wxCoord y, const wxArrayString& file
 }
 
 
+#if defined _WIN32 && defined Hugin_shared
+DEFINE_LOCAL_EVENT_TYPE(EVT_LOADING_FAILED)
+#else
+DEFINE_EVENT_TYPE(EVT_LOADING_FAILED)
+#endif
 
 // event table. this frame will recieve mostly global commands.
 BEGIN_EVENT_TABLE(MainFrame, wxFrame)
@@ -213,7 +218,6 @@ BEGIN_EVENT_TABLE(MainFrame, wxFrame)
     EVT_MENU(XRCID("action_show_tip"),  MainFrame::OnTipOfDay)
     EVT_MENU(XRCID("action_show_shortcuts"),  MainFrame::OnKeyboardHelp)
     EVT_MENU(XRCID("action_show_faq"),  MainFrame::OnFAQ)
-    EVT_MENU(XRCID("action_show_donate"),  MainFrame::OnShowDonate)
     EVT_MENU(XRCID("action_show_prefs"), MainFrame::OnShowPrefs)
     EVT_MENU(XRCID("action_assistant"), MainFrame::OnRunAssistant)
     EVT_MENU(XRCID("action_batch_assistant"), MainFrame::OnSendToAssistantQueue)
@@ -233,6 +237,7 @@ BEGIN_EVENT_TABLE(MainFrame, wxFrame)
 
     EVT_MENU(XRCID("action_optimize"),  MainFrame::OnOptimize)
     EVT_MENU(XRCID("action_optimize_only_active"), MainFrame::OnOnlyActiveImages)
+    EVT_MENU(XRCID("action_optimize_ignore_line_cp"), MainFrame::OnIgnoreLineCp)
     EVT_BUTTON(XRCID("action_optimize"),  MainFrame::OnOptimize)
     EVT_MENU(XRCID("action_finetune_all_cp"), MainFrame::OnFineTuneAll)
 //    EVT_BUTTON(XRCID("action_finetune_all_cp"), MainFrame::OnFineTuneAll)
@@ -255,6 +260,7 @@ BEGIN_EVENT_TABLE(MainFrame, wxFrame)
     EVT_BUTTON(XRCID("action_add_time_images"),  MainFrame::OnAddTimeImages)
     EVT_CLOSE(  MainFrame::OnExit)
     EVT_SIZE(MainFrame::OnSize)
+    EVT_COMMAND(wxID_ANY, EVT_LOADING_FAILED, MainFrame::OnLoadingFailed)
 END_EVENT_TABLE()
 
 // change this variable definition
@@ -263,6 +269,13 @@ END_EVENT_TABLE()
 //wxBitmap *p_img = (wxBitmap *) NULL;
 //WX_DEFINE_ARRAY()
 
+enum
+{
+    wxIDPYTHONSCRIPTS = wxID_HIGHEST + 2000,
+    wxIDUSEROUTPUTSEQUENCE = wxID_HIGHEST + 2500,
+    wxIDUSERASSISTANT = wxID_HIGHEST + 3000
+};
+
 MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
     : cp_frame(0), pano(pano)
 {
@@ -270,11 +283,7 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
     svmModel=NULL;
 
     bool disableOpenGL=false;
-#if wxCHECK_VERSION(2,9,4)
     if(wxGetKeyState(WXK_COMMAND))
-#else
-    if(wxGetKeyState(WXK_CONTROL))
-#endif
     {
         wxDialog dlg;
         wxXmlResource::Get()->LoadDialog(&dlg, NULL, wxT("disable_opengl_dlg"));
@@ -362,7 +371,8 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
     m_menu_file_advanced=wxXmlResource::Get()->LoadMenu(wxT("file_menu_advanced"));
     mainMenu->Insert(0, m_menu_file_simple, _("&File"));
     SetMenuBar(mainMenu);
-    SetOptimizeOnlyActiveImages(m_optOnlyActiveImages);
+    m_optOnlyActiveImages = (wxConfigBase::Get()->Read(wxT("/OptimizePanel/OnlyActiveImages"), 1l) != 0);
+    m_optIgnoreLineCp = false;
 
 #ifdef HUGIN_HSI
     wxMenuBar* menubar=GetMenuBar();
@@ -388,7 +398,7 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
         };
         items.sort(comparePluginItem);
 
-        int pluginID = wxID_HIGHEST + 2000;
+        int pluginID = wxIDPYTHONSCRIPTS;
         for (PluginItems::const_iterator it = items.begin(); it != items.end(); ++it)
         {
             PluginItem item = *it;
@@ -418,6 +428,122 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
     GetMenuBar()->Enable(XRCID("action_python_script"), false);
 #endif
 
+    // add saved user defined output sequences
+    {
+        wxArrayString files;
+        // search all .executor files, do not follow links
+        wxDir::GetAllFiles(GetDataPath(), &files, wxT("*.executor"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
+        const size_t nrAllUserSequences = files.size();
+        wxDir::GetAllFiles(hugin_utils::GetUserAppDataDir(), &files, wxT("*.executor"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
+        if (!files.IsEmpty())
+        {
+            // we found some files
+            long outputId = wxIDUSEROUTPUTSEQUENCE;
+            int outputMenuId=mainMenu->FindMenu(_("&Output"));
+            if (outputMenuId != wxNOT_FOUND)
+            {
+                wxMenu* outputSequencesMenu = new wxMenu;
+                size_t i = 0;
+                for (auto file : files)
+                {
+                    if (i > 0 && i == nrAllUserSequences && outputSequencesMenu->GetMenuItemCount() > 0)
+                    {
+                        outputSequencesMenu->AppendSeparator();
+                    };
+                    wxFileInputStream inputStream(file);
+                    if (inputStream.IsOk())
+                    {
+                        // read descriptions from file
+                        wxFileConfig executorFile(inputStream);
+                        wxString desc = executorFile.Read(wxT("/General/Description"), wxEmptyString);
+                        desc = desc.Trim(true).Trim(false);
+                        wxString help = executorFile.Read(wxT("/General/Help"), wxEmptyString);
+                        help = help.Trim(true).Trim(false);
+                        if (help.IsEmpty())
+                        {
+                            help = wxString::Format(_("User defined sequence: %s"), file);
+                        };
+                        // add menu
+                        if (!desc.IsEmpty())
+                        {
+                            outputSequencesMenu->Append(outputId, desc, help);
+                            Bind(wxEVT_MENU, &MainFrame::OnUserDefinedStitchSaved, this, outputId);
+                            m_userOutput[outputId] = file;
+                            ++outputId;
+                        };
+                    };
+                    i++;
+                };
+                if ((outputSequencesMenu->GetMenuItemCount() == 1 && !(outputSequencesMenu->FindItemByPosition(0)->IsSeparator())) ||
+                    outputSequencesMenu->GetMenuItemCount() > 1)
+                {
+                    m_outputUserMenu = mainMenu->GetMenu(outputMenuId)->AppendSubMenu(outputSequencesMenu, _("User defined output sequences"));
+                }
+                else
+                {
+                    delete outputSequencesMenu;
+                };
+            };
+        };
+    };
+    // add saved user defined assistants
+    {
+        wxArrayString files;
+        // search all .assistant files, do not follow links
+        wxDir::GetAllFiles(GetDataPath(), &files, wxT("*.assistant"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
+        const size_t nrAllUserSequences = files.size();
+        wxDir::GetAllFiles(hugin_utils::GetUserAppDataDir(), &files, wxT("*.assistant"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
+        if (!files.IsEmpty())
+        {
+            // we found some files
+            long assistantId = wxIDUSERASSISTANT;
+            const int editMenuId = mainMenu->FindMenu(_("&Edit"));
+            if (editMenuId != wxNOT_FOUND)
+            {
+                wxMenu* userAssistantMenu = new wxMenu;
+                size_t i = 0;
+                for (auto file : files)
+                {
+                    if (i > 0 && i == nrAllUserSequences && userAssistantMenu->GetMenuItemCount() > 0)
+                    {
+                        userAssistantMenu->AppendSeparator();
+                    };
+                    wxFileInputStream inputStream(file);
+                    if (inputStream.IsOk())
+                    {
+                        // read descriptions from file
+                        wxFileConfig assistantFile(inputStream);
+                        wxString desc = assistantFile.Read(wxT("/General/Description"), wxEmptyString);
+                        desc = desc.Trim(true).Trim(false);
+                        wxString help = assistantFile.Read(wxT("/General/Help"), wxEmptyString);
+                        help = help.Trim(true).Trim(false);
+                        if (help.IsEmpty())
+                        {
+                            help = wxString::Format(_("User defined assistant: %s"), file);
+                        };
+                        // add menu
+                        if (!desc.IsEmpty())
+                        {
+                            userAssistantMenu->Append(assistantId, desc, help);
+                            Bind(wxEVT_MENU, &MainFrame::OnRunAssistantUserdefined, this, assistantId);
+                            m_userAssistant[assistantId] = file;
+                            ++assistantId;
+                        };
+                    };
+                    i++;
+                };
+                if (userAssistantMenu->GetMenuItemCount() > 0)
+                {
+                    m_assistantUserMenu = mainMenu->GetMenu(editMenuId)->Insert(5, wxID_ANY, _("User defined assistant"), userAssistantMenu);
+                }
+                else
+                {
+                    delete userAssistantMenu;
+                };
+            };
+        };
+    };
+
     // create tool bar
     SetToolBar(wxXmlResource::Get()->LoadToolBar(this, wxT("main_toolbar")));
 
@@ -545,6 +671,7 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
 
     // disable automatic Layout() calls, to it by hand
     SetAutoLayout(false);
+    SetOptimizeOnlyActiveImages(m_optOnlyActiveImages);
 
 
 #ifdef __WXMSW__
@@ -575,13 +702,14 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
     {
         guiLevel=GUI_ADVANCED;
     };
-    SetGuiLevel((GuiLevel)guiLevel);
+    SetGuiLevel(static_cast<GuiLevel>(guiLevel));
+
+#ifndef __WXMSW__
+    // check settings of help window and fix when needed
+    FixHelpSettings();
+#endif
 
     DEBUG_TRACE("");
-#ifdef __WXGTK__
-    // set explicit focus to assistant panel for better processing key presses
-    images_panel->SetFocus();
-#endif
 }
 
 MainFrame::~MainFrame()
@@ -612,6 +740,9 @@ MainFrame::~MainFrame()
     m_mruFiles.Save(*config);
     //store gui level
     config->Write(wxT("/GuiLevel"),(long)m_guiLevel);
+    // store optimize only active images
+    config->Write("/OptimizePanel/OnlyActiveImages", m_optOnlyActiveImages ? 1l : 0l);
+
     config->Flush();
     if(svmModel!=NULL)
     {
@@ -677,13 +808,7 @@ void MainFrame::panoramaImagesChanged(HuginBase::Panorama &panorama, const Hugin
 {
     DEBUG_TRACE("");
     assert(&pano == &panorama);
-    if (pano.getNrOfImages() == 0) {
-	  enableTools(false);
-	} else {
-	  enableTools(true);
-	}
-    GetMenuBar()->Enable(XRCID("action_assistant"), pano.getNrOfImages()>=2);
-    GetMenuBar()->Enable(XRCID("action_batch_assistant"), pano.getNrOfImages()>=2);
+    enableTools(pano.getNrOfImages() > 0);
 }
 
 void MainFrame::OnUserQuit(wxCommandEvent & e)
@@ -691,19 +816,43 @@ void MainFrame::OnUserQuit(wxCommandEvent & e)
     Close();
 }
 
-bool MainFrame::CloseProject(bool cancelable)
+bool MainFrame::CloseProject(bool cancelable, CloseReason reason)
 {
     if (pano.isDirty()) {
-        wxMessageDialog message(wxGetActiveWindow(),
-                                _("Save changes to the panorama before closing?"),
+        wxString messageString;
+        switch (reason)
+        {
+            case LOAD_NEW_PROJECT:
+                messageString = _("Save changes to the project file before opening another project?");
+                break;
+            case NEW_PROJECT:
+                messageString = _("Save changes to the project file before starting a new project?");
+                break;
+            case CLOSE_PROGRAM:
+            default:
+                messageString = _("Save changes to the project file before closing?");
+                break;
+        };
+                wxMessageDialog message(wxGetActiveWindow(), messageString,
 #ifdef _WIN32
                                 _("Hugin"),
 #else
                                 wxT(""),
 #endif
                                 wxICON_EXCLAMATION | wxYES_NO | (cancelable? (wxCANCEL):0));
-#if wxCHECK_VERSION(2, 9, 0)
-    message.SetExtendedMessage(_("If you close without saving, changes since your last save will be discarded"));
+        switch(reason)
+        {
+            case LOAD_NEW_PROJECT:
+                message.SetExtendedMessage(_("If you load another project without saving, your changes since last save will be discarded."));
+                break;
+            case NEW_PROJECT:
+                message.SetExtendedMessage(_("If you start a new project without saving, your changes since last save will be discarded."));
+                break;
+            case CLOSE_PROGRAM:
+            default:
+                message.SetExtendedMessage(_("If you close without saving, your changes since your last save will be discarded."));
+                break;
+        };
     #if defined __WXMAC__ || defined __WXMSW__
         // Apple human interface guidelines and Windows user experience interaction guidelines
         message.SetYesNoLabels(wxID_SAVE, _("Don't Save"));
@@ -711,7 +860,6 @@ bool MainFrame::CloseProject(bool cancelable)
         // Gnome human interface guidelines:
         message.SetYesNoLabels(wxID_SAVE, _("Close without saving"));
     #endif
-#endif
         int answer = message.ShowModal();
         switch (answer){
             case wxID_YES:
@@ -734,7 +882,7 @@ void MainFrame::OnExit(wxCloseEvent & e)
     DEBUG_TRACE("");
     if(m_guiLevel!=GUI_SIMPLE)
     {
-        if(!CloseProject(e.CanVeto()))
+        if(!CloseProject(e.CanVeto(), CLOSE_PROGRAM))
         {
            if (e.CanVeto())
            {
@@ -877,7 +1025,6 @@ void MainFrame::OnSavePTStitcherAs(wxCommandEvent & e)
 void MainFrame::LoadProjectFile(const wxString & filename)
 {
     DEBUG_TRACE("");
-    m_filename = filename;
 
     // remove old images from cache
     // hmm probably not a good idea, if the project is reloaded..
@@ -887,7 +1034,9 @@ void MainFrame::LoadProjectFile(const wxString & filename)
 
     wxFileName fname(filename);
     wxString path = fname.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
-    if (fname.IsOk() && fname.FileExists()) {
+    if (fname.IsOk() && fname.FileExists())
+    {
+        m_filename = filename;
         wxBusyCursor wait;
         deregisterPTWXDlgFcn();
         PanoCommand::GlobalCmdHist::getInstance().addCommand(
@@ -901,19 +1050,39 @@ void MainFrame::LoadProjectFile(const wxString & filename)
         {
             SetGuiLevel(reqGuiLevel);
         };
-        SetStatusText(_("Project opened"));
-        m_mruFiles.AddFileToHistory(fname.GetFullPath());
-        if(m_guiLevel==GUI_SIMPLE)
+        if (pano.getNrOfImages() > 0)
         {
-            if(gl_preview_frame)
+            SetStatusText(_("Project opened"));
+            m_mruFiles.AddFileToHistory(fname.GetFullPath());
+            if (m_guiLevel == GUI_SIMPLE)
             {
-                gl_preview_frame->SetTitle(fname.GetName() + wxT(".") + fname.GetExt() + wxT(" - ") + _("Hugin - Panorama Stitcher"));
+                if (gl_preview_frame)
+                {
+                    gl_preview_frame->SetTitle(fname.GetName() + wxT(".") + fname.GetExt() + wxT(" - ") + _("Hugin - Panorama Stitcher"));
+                };
+                SetTitle(fname.GetName() + wxT(".") + fname.GetExt() + wxT(" - ") + _("Panorama editor"));
+            }
+            else
+            {
+                SetTitle(fname.GetName() + wxT(".") + fname.GetExt() + wxT(" - ") + _("Hugin - Panorama Stitcher"));
             };
-            SetTitle(fname.GetName() + wxT(".") + fname.GetExt() + wxT(" - ") + _("Panorama editor"));
         }
         else
         {
-            SetTitle(fname.GetName() + wxT(".") + fname.GetExt() + wxT(" - ") + _("Hugin - Panorama Stitcher"));
+            SetStatusText(_("Loading canceled"));
+            m_filename = "";
+            if (m_guiLevel == GUI_SIMPLE)
+            {
+                if (gl_preview_frame)
+                {
+                    gl_preview_frame->SetTitle(_("Hugin - Panorama Stitcher"));
+                };
+                SetTitle(_("Panorama editor"));
+            }
+            else
+            {
+                SetTitle(_("Hugin - Panorama Stitcher"));
+            };
         };
         if (! (fname.GetExt() == wxT("pto"))) {
             // do not remember filename if its not a hugin project
@@ -939,7 +1108,7 @@ void MainFrame::LoadProjectFile(const wxString & filename)
 #ifdef __WXMAC__
 void MainFrame::MacOnOpenFile(const wxString & filename)
 {
-    if(!CloseProject(true)) return; //if closing old project is canceled do nothing.
+    if(!CloseProject(true, LOAD_NEW_PROJECT)) return; //if closing old project is canceled do nothing.
 
     ImageCache::getInstance().flush();
     LoadProjectFile(filename);
@@ -950,7 +1119,7 @@ void MainFrame::OnLoadProject(wxCommandEvent & e)
 {
     DEBUG_TRACE("");
 
-    if(CloseProject(true)) //if closing old project is canceled do nothing.
+    if(CloseProject(true, LOAD_NEW_PROJECT)) //if closing old project is canceled do nothing.
     {
         // get the global config object
         wxConfigBase* config = wxConfigBase::Get();
@@ -998,7 +1167,7 @@ void MainFrame::OnLoadProject(wxCommandEvent & e)
 
 void MainFrame::OnNewProject(wxCommandEvent & e)
 {
-    if(!CloseProject(true)) return; //if closing current project is canceled
+    if(!CloseProject(true, NEW_PROJECT)) return; //if closing current project is canceled
 
     m_filename = wxT("");
     PanoCommand::GlobalCmdHist::getInstance().addCommand(new PanoCommand::wxNewProjectCmd(pano));
@@ -1085,11 +1254,6 @@ void MainFrame::OnAddTimeImages( wxCommandEvent& event )
     };
 };
 
-void MainFrame::OnShowDonate(wxCommandEvent & e)
-{
-    wxLaunchDefaultBrowser(wxT("http://sourceforge.net/project/project_donations.php?group_id=77506"));
-}
-
 
 void MainFrame::OnShowPanel(wxCommandEvent & e)
 {
@@ -1136,6 +1300,47 @@ void MainFrame::OnShowPanel(wxCommandEvent & e)
                         m_notebook->SetSelection(0);
 }
 
+void MainFrame::OnLoadingFailed(wxCommandEvent & e)
+{
+    // check if file exists
+    if (wxFileExists(e.GetString()))
+    {
+        // file exists, but could not loaded
+        wxMessageBox(wxString::Format(_("Could not load image \"%s\".\nThis file is not a valid image.\nThis file will be removed from the project."), e.GetString()),
+#ifdef _WIN32
+            _("Hugin"),
+#else
+            wxT(""),
+#endif
+            wxOK | wxICON_ERROR);
+    }
+    else
+    {
+        // file does not exists
+        wxMessageBox(wxString::Format(_("Could not load image \"%s\".\nThis file was renamed, deleted or is on a non-accessible drive.\nThis file will be removed from the project."), e.GetString()),
+#ifdef _WIN32
+            _("Hugin"),
+#else
+            wxT(""),
+#endif
+            wxOK | wxICON_ERROR);
+    };
+    // now remove the file from the pano
+    const std::string filename(e.GetString().mb_str(HUGIN_CONV_FILENAME));
+    HuginBase::UIntSet imagesToRemove;
+    for (size_t i = 0; i < pano.getNrOfImages(); ++i)
+    {
+        if (pano.getImage(i).getFilename() == filename)
+        {
+            imagesToRemove.insert(i);
+        };
+    };
+    if (!imagesToRemove.empty())
+    {
+        PanoCommand::GlobalCmdHist::getInstance().addCommand(new PanoCommand::RemoveImagesCmd(pano, imagesToRemove));
+    };
+}
+
 
 void MainFrame::OnAbout(wxCommandEvent & e)
 {
@@ -1182,83 +1387,32 @@ void MainFrame::OnHelp(wxCommandEvent & e)
 
 void MainFrame::OnKeyboardHelp(wxCommandEvent & e)
 {
-    DisplayHelp(wxT("/Hugin_Keyboard_shortcuts.html"));
+    DisplayHelp(wxT("Hugin_Keyboard_shortcuts.html"));
 }
 
 void MainFrame::OnFAQ(wxCommandEvent & e)
 {
-    DisplayHelp(wxT("/Hugin_FAQ.html"));
+    DisplayHelp(wxT("Hugin_FAQ.html"));
 }
 
 
 void MainFrame::DisplayHelp(wxString section)
 {
-    // TODO:
-    // structure a frame with navigation on the left and content on the right
-    // always load the same navigation on the left and the section into the frame
-    // find a way to target always the same window rather than opening new window / tabs in the browser every time
-    // make it look nicer with some CSS styling
-
-    // section is the HTML document to be displayed, from inside the data folder
-
-    DEBUG_TRACE("");
-
-#ifdef __WXMSW__
     if (section.IsEmpty())
     {
-        // wxWidgets 3.x has a bug, that prevents DisplaySection to work on Win8/10 64 bit
-        // see: http://trac.wxwidgets.org/ticket/14888
-        // so using DisplayContents() and our own implementation of HuginCHMHelpController
         GetHelpController().DisplayContents();
     }
     else
     {
-#if wxCHECK_VERSION(3,1,1)
-        GetHelpController().DisplaySection(section);
-#else
+#if defined __wxMSW__ && !(wxCHECK_VERSION(3,1,1))
+        // wxWidgets 3.x has a bug, that prevents DisplaySection to work on Win8/10 64 bit
+        // see: http://trac.wxwidgets.org/ticket/14888
+        // so using DisplayContents() and our own implementation of HuginCHMHelpController
         GetHelpController().DisplayHelpPage(section);
+#else
+        GetHelpController().DisplaySection(section);
 #endif
     };
-#else
-    if (section.IsEmpty())
-    {
-        section = wxT("/Hugin.html");
-    }
-#if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
-    // On Mac, xrc/data/help_LOCALE should be in the bundle as LOCALE.lproj/help
-    // which we can rely on the operating sytem to pick the right locale's.
-    wxString strFile = MacGetPathToBundledResourceFile(CFSTR("help"));
-    if(strFile!=wxT(""))
-    {
-        strFile += section;
-    } else {
-        wxLogError(wxString::Format(wxT("Could not find help directory in the bundle"), strFile.c_str()));
-        return;
-    }
-#else
-    // find base filename
-    wxString helpFile = wxT("help_") + huginApp::Get()->GetLocale().GetCanonicalName() + section;
-    DEBUG_INFO("help file candidate: " << helpFile.mb_str(wxConvLocal));
-    //if the language is not default, load custom About file (if exists)
-    wxString strFile = GetXRCPath() + wxT("data/") + helpFile;
-    if(wxFile::Exists(strFile))
-    {
-        DEBUG_TRACE("Using About: " << strFile.mb_str(wxConvLocal));
-    } else {
-        strFile = GetXRCPath() + wxT("data/help_en_EN") + section;
-    }
-#endif
-    if(!wxFile::Exists(strFile))
-    {
-        wxLogError(wxString::Format(wxT("Could not open help file: %s"), strFile.c_str()));
-        return;
-    }
-    DEBUG_INFO("help file: " << strFile.mb_str(wxConvLocal));
-    if(!wxLaunchDefaultBrowser(strFile))
-    {
-        wxLogError(_("Can't start system's web browser"));
-    }
-#endif
 }
 
 void MainFrame::OnTipOfDay(wxCommandEvent& WXUNUSED(e))
@@ -1394,10 +1548,7 @@ void MainFrame::OnOptimize(wxCommandEvent & e)
 
 void MainFrame::OnOnlyActiveImages(wxCommandEvent &e)
 {
-    m_optOnlyActiveImages = GetMenuBar()->IsChecked(XRCID("action_optimize_only_active"));
-    opt_panel->SetOnlyActiveImages(m_optOnlyActiveImages);
-    // notify all observer so they can update their display
-    pano.changeFinished();
+    SetOptimizeOnlyActiveImages(GetMenuBar()->IsChecked(XRCID("action_optimize_only_active")));
 };
 
 void MainFrame::SetOptimizeOnlyActiveImages(const bool onlyActive)
@@ -1407,9 +1558,11 @@ void MainFrame::SetOptimizeOnlyActiveImages(const bool onlyActive)
     if (menubar)
     {
         menubar->Check(XRCID("action_optimize_only_active"), onlyActive);
-        // notify all observer so they can update their display
-        pano.changeFinished();
     };
+    opt_panel->SetOnlyActiveImages(m_optOnlyActiveImages);
+    opt_photo_panel->SetOnlyActiveImages(m_optOnlyActiveImages);
+    // notify all observer so they can update their display
+    pano.changeFinished();
 };
 
 const bool MainFrame::GetOptimizeOnlyActiveImages() const
@@ -1417,6 +1570,31 @@ const bool MainFrame::GetOptimizeOnlyActiveImages() const
     return m_optOnlyActiveImages;
 };
 
+void MainFrame::OnIgnoreLineCp(wxCommandEvent &e)
+{
+    m_optIgnoreLineCp = GetMenuBar()->IsChecked(XRCID("action_optimize_ignore_line_cp"));
+    opt_panel->SetIgnoreLineCP(m_optIgnoreLineCp);
+    // notify all observer so they can update their display
+    pano.changeFinished();
+};
+
+void MainFrame::SetOptimizeIgnoreLineCp(const bool ignoreLineCP)
+{
+    m_optIgnoreLineCp = ignoreLineCP;
+    wxMenuBar* menubar = GetMenuBar();
+    if (menubar)
+    {
+        menubar->Check(XRCID("action_optimize_ignore_line_cp"), ignoreLineCP);
+        // notify all observer so they can update their display
+        pano.changeFinished();
+    };
+};
+
+const bool MainFrame::GetOptimizeIgnoreLineCp() const
+{
+    return m_optIgnoreLineCp;
+};
+
 void MainFrame::OnPhotometricOptimize(wxCommandEvent & e)
 {
     wxCommandEvent dummy;
@@ -1435,6 +1613,19 @@ void MainFrame::OnUserDefinedStitch(wxCommandEvent & e)
     pano_panel->DoUserDefinedStitch();
 }
 
+void MainFrame::OnUserDefinedStitchSaved(wxCommandEvent & e)
+{
+    auto filename = m_userOutput.find(e.GetId());
+    if (filename != m_userOutput.end())
+    {
+        pano_panel->DoUserDefinedStitch(filename->second);
+    }
+    else
+    {
+        wxBell();
+    };
+}
+
 void MainFrame::OnMergeProject(wxCommandEvent & e)
 {
     // get the global config object
@@ -1817,6 +2008,16 @@ void MainFrame::enableTools(bool option)
     theMenuBar->Enable(XRCID("ID_SHOW_PREVIEW_FRAME"), option);
     theMenuBar->Enable(XRCID("action_stitch"), option);
     theMenuBar->Enable(XRCID("action_stitch_userdefined"), option);
+    if (m_outputUserMenu != nullptr)
+    {
+        m_outputUserMenu->Enable(option);
+    };
+    if (m_assistantUserMenu != nullptr)
+    {
+        m_assistantUserMenu->Enable(option);
+    };
+    theMenuBar->Enable(XRCID("action_assistant"), option);
+    theMenuBar->Enable(XRCID("action_batch_assistant"), option);
     m_menu_file_advanced->Enable(XRCID("action_import_papywizard"), option);
     //theMenuBar->Enable(XRCID("ID_SHOW_GL_PREVIEW_FRAME"), option);
 }
@@ -1891,8 +2092,17 @@ void MainFrame::OnMRUFiles(wxCommandEvent &e)
     if (!f.empty())
     {
         wxFileName fn(f);
-        if(fn.FileExists())
-            LoadProjectFile(f);
+        if (fn.FileExists())
+        {
+            // if closing old project was canceled do nothing
+            if (CloseProject(true, LOAD_NEW_PROJECT))
+            {
+                // remove old images from cache
+                ImageCache::getInstance().flush();
+                // finally load project
+                LoadProjectFile(f);
+            };
+        }
         else
         {
             m_mruFiles.RemoveFileFromHistory(index);
@@ -2116,14 +2326,8 @@ void MainFrame::DisableOpenGLTools()
     GetToolBar()->EnableTool(XRCID("ID_SHOW_GL_PREVIEW_FRAME"), false); 
 };
 
-void MainFrame::RunAssistant(wxWindow* mainWin)
+void MainFrame::RunAssistant(wxWindow* mainWin, const wxString& userdefinedAssistant)
 {
-    if (pano.getNrOfImages() < 2)
-    {
-        wxMessageBox(_("At least two images are required.\nPlease add more images."),_("Error"), wxOK, mainWin);
-        return;
-    }
-
     //save project into temp directory
     wxString tempDir= wxConfig::Get()->Read(wxT("tempDir"),wxT(""));
     if(!tempDir.IsEmpty())
@@ -2143,7 +2347,23 @@ void MainFrame::RunAssistant(wxWindow* mainWin)
 
     // get assistant queue
     const wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
-    HuginQueue::CommandQueue* commands = HuginQueue::GetAssistantCommandQueue(pano, exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR), scriptFileName.GetFullPath());
+    HuginQueue::CommandQueue* commands;
+    if (userdefinedAssistant.IsEmpty())
+    {
+        commands = HuginQueue::GetAssistantCommandQueue(pano, exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR), scriptFileName.GetFullPath());
+    }
+    else
+    {
+        commands = HuginQueue::GetAssistantCommandQueueUserDefined(pano, exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR), scriptFileName.GetFullPath(), userdefinedAssistant);
+        if (commands->empty())
+        {
+            wxMessageBox(_("The assistant queue is empty. This indicates an error in the user defined assistant file."),
+                _("Error"), wxOK | wxICON_ERROR, mainWin);
+            //delete temporary files
+            wxRemoveFile(scriptFileName.GetFullPath());
+            return;
+        };
+    };
     //execute queue
     int ret = MyExecuteCommandQueue(commands, mainWin, _("Running assistant"));
 
@@ -2158,22 +2378,38 @@ void MainFrame::RunAssistant(wxWindow* mainWin)
     //if return value is non-zero, an error occurred in the assistant
     if(ret!=0)
     {
-        //check for unconnected images
-        HuginGraph::ImageGraph graph(pano);
-        const HuginGraph::ImageGraph::Components comps = graph.GetComponents();
-        if(comps.size() > 1)
+        if (userdefinedAssistant.IsEmpty())
         {
-            // switch to images panel.
-            unsigned i1 = *(comps[0].rbegin());
-            unsigned i2 = *(comps[1].begin());
-            ShowCtrlPointEditor( i1, i2);
-            // display message box with 
-            wxMessageBox(wxString::Format(_("Warning %d unconnected image groups found:"), comps.size()) + Components2Str(comps) + wxT("\n")
-                + _("Please create control points between unconnected images using the Control Points tab in the panorama editor.\n\nAfter adding the points, press the \"Align\" button again"),_("Error"), wxOK , mainWin);
-            return;
+            if (pano.getNrOfImages() == 1)
+            {
+                wxMessageBox(_("The assistant could not find vertical lines. Please add vertical lines in the panorama editor and optimize project manually."),
+                    _("Warning"), wxOK | wxICON_INFORMATION, mainWin);
+            }
+            else
+            {
+                //check for unconnected images
+                HuginGraph::ImageGraph graph(pano);
+                const HuginGraph::ImageGraph::Components comps = graph.GetComponents();
+                if (comps.size() > 1)
+                {
+                    // switch to images panel.
+                    unsigned i1 = *(comps[0].rbegin());
+                    unsigned i2 = *(comps[1].begin());
+                    ShowCtrlPointEditor(i1, i2);
+                    // display message box with 
+                    wxMessageBox(wxString::Format(_("Warning %d unconnected image groups found:"), static_cast<int>(comps.size())) + Components2Str(comps) + wxT("\n")
+                        + _("Please create control points between unconnected images using the Control Points tab in the panorama editor.\n\nAfter adding the points, press the \"Align\" button again"), _("Error"), wxOK, mainWin);
+                    return;
+                };
+                wxMessageBox(_("The assistant did not complete successfully. Please check the resulting project file."),
+                    _("Warning"), wxOK | wxICON_INFORMATION, mainWin);
+            };
+        }
+        else
+        {
+            wxMessageBox(_("The assistant did not complete successfully. Please check the resulting project file."),
+                _("Warning"), wxOK | wxICON_INFORMATION, mainWin);
         };
-        wxMessageBox(_("The assistant did not complete successfully. Please check the resulting project file."),
-                     _("Warning"),wxOK | wxICON_INFORMATION, mainWin); 
     };
 };
 
@@ -2182,6 +2418,19 @@ void MainFrame::OnRunAssistant(wxCommandEvent & e)
     RunAssistant(this);
 };
 
+void MainFrame::OnRunAssistantUserdefined(wxCommandEvent & e)
+{
+    const auto filename = m_userAssistant.find(e.GetId());
+    if (filename != m_userAssistant.end())
+    {
+        RunAssistant(this, filename->second);
+    }
+    else
+    {
+        wxBell();
+    };
+};
+
 void MainFrame::OnSendToAssistantQueue(wxCommandEvent &e)
 {
     wxCommandEvent dummy;
