@@ -32,9 +32,13 @@
 #include "panodata/Panorama.h"
 
 #include "wx/docview.h"
-#ifdef __WXMSW__
-#include "wx/msw/helpchm.h"
+#include "wx/help.h"
+#if !wxUSE_HELP
+#error wxWidgets needs to be compiled with help support (wxUSE_HELP not set)
+#endif
+#if defined __WXMSW__ && !(wxCHECK_VERSION(3,1,1))
 #include "base_wx/wxPlatform.h"
+#define wxHelpController HuginCHMHelpController
 #endif
 
 #include <appbase/ProgressDisplay.h>
@@ -107,6 +111,12 @@ public:
     const wxString & GetXRCPath();
     /** get the path to data directory */
     const wxString & GetDataPath();
+    /** sets the status of the "optimize only active images" menu item */
+    void SetOptimizeOnlyActiveImages(const bool onlyActive);
+    const bool GetOptimizeOnlyActiveImages() const;
+    /** sets the status of the "ignore line cp" menu item */
+    void SetOptimizeIgnoreLineCp(const bool ignoreLineCP);
+    const bool GetOptimizeIgnoreLineCp() const;
 
     /// hack.. kind of a pseudo singleton...
     static MainFrame * Get();
@@ -116,21 +126,30 @@ public:
 
     // load a project
     void LoadProjectFile(const wxString & filename);
-    void RunAssistant(wxWindow* mainWin);
+    void RunAssistant(wxWindow* mainWin, const wxString& userdefinedAssistant=wxEmptyString);
 
     /** disables all OpenGL related menu items and toobar buttons */
     void DisableOpenGLTools();
 #ifdef __WXMAC__
     void MacOnOpenFile(const wxString & filename);
 #endif
-    bool CloseProject(bool cancelable);
+    enum CloseReason
+    {
+        CLOSE_PROGRAM,
+        LOAD_NEW_PROJECT,
+        NEW_PROJECT
+    };
+    bool CloseProject(bool cancelable, CloseReason reason);
 
     // TODO: create a nice generic optimisation & stitching function
     // instead of these gateway functions to the optimizer and pano panels.
     void OnOptimize(wxCommandEvent & e);
+    void OnOnlyActiveImages(wxCommandEvent &e);
+    void OnIgnoreLineCp(wxCommandEvent &e);
     void OnPhotometricOptimize(wxCommandEvent & e);
     void OnDoStitch(wxCommandEvent & e);
     void OnUserDefinedStitch(wxCommandEvent & e);
+    void OnUserDefinedStitchSaved(wxCommandEvent & e);
     void OnTogglePreviewFrame(wxCommandEvent & e);
     void OnToggleGLPreviewFrame(wxCommandEvent & e);
     void OnAddImages(wxCommandEvent & e);
@@ -164,9 +183,7 @@ public:
     struct celeste::svm_model* GetSVMModel();
     
     GLPreviewFrame * getGLPreview();
-#ifdef __WXMSW__
-    HuginCHMHelpController& GetHelpController() { return m_msHtmlHelp; }
-#endif
+    wxHelpController& GetHelpController() { return m_HelpController; }
     void SetGuiLevel(GuiLevel newLevel);
     const GuiLevel GetGuiLevel() const { return m_guiLevel; };
 
@@ -206,9 +223,11 @@ private:
     void OnNewProject(wxCommandEvent & e);
     void OnAddTimeImages(wxCommandEvent & e);
     void OnRunAssistant(wxCommandEvent & e);
+    void OnRunAssistantUserdefined(wxCommandEvent & e);
     void OnFineTuneAll(wxCommandEvent & e);
     void OnRemoveCPinMasks(wxCommandEvent & e);
     void OnMergeProject(wxCommandEvent & e);
+    void OnReadPapywizard(wxCommandEvent & e);
     void OnApplyTemplate(wxCommandEvent & e);
     void OnSendToBatch(wxCommandEvent & e);
     void OnSendToAssistantQueue(wxCommandEvent & e);
@@ -225,8 +244,9 @@ private:
     /** adds the given files to the projects, with checking for invalid filenames */
     void AddImages(wxArrayString& filenameArray);
 
-    void OnShowDonate(wxCommandEvent &e);
     void OnShowPanel(wxCommandEvent &e);
+    /** event handler called when loading of image file failed */
+    void OnLoadingFailed(wxCommandEvent& e);
 
     wxFileHistory m_mruFiles;
     wxNotebook * m_notebook;
@@ -264,17 +284,30 @@ private:
     // file menu
     wxMenu* m_menu_file_simple;
     wxMenu* m_menu_file_advanced;
-
-#ifdef __WXMSW__
-    HuginCHMHelpController     m_msHtmlHelp;
-#endif
+    wxMenuItem* m_outputUserMenu = nullptr;
+    wxMenuItem* m_assistantUserMenu = nullptr;
+    // sticky setting, to prevent reading to often
+    bool m_optOnlyActiveImages;
+    bool m_optIgnoreLineCp;
+    // help controller
+    wxHelpController m_HelpController;
 
 #ifdef HUGIN_HSI
     // list associating the wxID in the menu with a python script
     std::map<int, wxFileName> m_plugins;
 #endif
+    // list for user-defined output sequences
+    std::map<int, wxString> m_userOutput;
+    std::map<int, wxString> m_userAssistant;
 
     DECLARE_EVENT_TABLE()
 };
 
+// event used to signal invalid or missing image files
+#if defined _WIN32 && defined Hugin_shared
+DECLARE_LOCAL_EVENT_TYPE(EVT_LOADING_FAILED, -1)
+#else
+DECLARE_EVENT_TYPE(EVT_LOADING_FAILED, -1)
+#endif
+
 #endif // _MAINFRAME_H
