@@ -285,7 +285,7 @@ void MaskEditorPanel::setImage(unsigned int imgNr, bool updateListSelection)
         m_editImg->setImage(m_File,m_currentMasks,masksToDraw,GetRot(imgNr));
     else
         m_editImg->setNewMasks(m_currentMasks,masksToDraw);
-    if(m_currentMasks.size()==0)
+    if (m_currentMasks.empty() || m_MaskNr >= m_currentMasks.size())
         setMask(UINT_MAX);
     // enables or disables controls
     bool enableCtrl=(imgNr<UINT_MAX);
@@ -373,8 +373,17 @@ void MaskEditorPanel::panoramaImagesChanged(HuginBase::Panorama &pano, const Hug
     else
     {
         // select some other image if we deleted the current image
-        if ((GetImgNr()<UINT_MAX) && (GetImgNr() >= nrImages))
-            setImage(nrImages-1);
+        if ((GetImgNr() < UINT_MAX) && (GetImgNr() >= nrImages))
+        {
+            for (auto i : m_selectedImages)
+            {
+                if (i >= nrImages)
+                {
+                    m_selectedImages.erase(i);
+                };
+            };
+            setImage(nrImages - 1);
+        }
         else
             // update changed images
             if(set_contains(changed,GetImgNr()))
@@ -736,26 +745,33 @@ MaskImageCtrl::ImageRotation MaskEditorPanel::GetRot(const unsigned int imgNr)
 
     while (pitch > 180) pitch -= 360;
     while (pitch < -180) pitch += 360;
-    bool headOver = (pitch > 90 || pitch < -90);
+    const bool headOver = (pitch > 90 || pitch < -90);
 
-    if (roll >= 315 || roll < 45) 
+    if (wxConfig::Get()->Read("/CPEditorPanel/AutoRot", 1L))
     {
-        rot = headOver ? MaskImageCtrl::ROT180 : MaskImageCtrl::ROT0;
-    } 
-    else 
-        if (roll >= 45 && roll < 135) 
+        if (roll >= 315 || roll < 45)
         {
-            rot = headOver ? MaskImageCtrl::ROT270 : MaskImageCtrl::ROT90;
+            rot = headOver ? MaskImageCtrl::ROT180 : MaskImageCtrl::ROT0;
         }
-        else 
-            if (roll >= 135 && roll < 225) 
+        else
+        {
+            if (roll >= 45 && roll < 135)
             {
-                rot = headOver ? MaskImageCtrl::ROT0 : MaskImageCtrl::ROT180;
-            } 
-            else 
-            {
-                rot = headOver ? MaskImageCtrl::ROT90 : MaskImageCtrl::ROT270;
+                rot = headOver ? MaskImageCtrl::ROT270 : MaskImageCtrl::ROT90;
             }
+            else
+            {
+                if (roll >= 135 && roll < 225)
+                {
+                    rot = headOver ? MaskImageCtrl::ROT0 : MaskImageCtrl::ROT180;
+                }
+                else
+                {
+                    rot = headOver ? MaskImageCtrl::ROT90 : MaskImageCtrl::ROT270;
+                };
+            };
+        };
+    };
     return rot;
 }
 
