@@ -21,15 +21,17 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
 #include "panoinc_WX.h"
 #include "panoinc.h"
 #include "base_wx/platform.h"
+#include "base_wx/wxcms.h"
 #include "hugin/MainFrame.h"
+#include "hugin/huginApp.h"
 #include "hugin/config_defaults.h"
 #include "hugin/MaskImageCtrl.h"
 #include "hugin/MaskEditorPanel.h"
@@ -38,8 +40,6 @@
 #include <vigra/inspectimage.hxx>
 #endif
 
-using namespace hugin_utils;
-
 /** half size of markers */
 const int polygonPointSize=3;
 /** maximal distance for selection of one point */
@@ -58,6 +58,7 @@ BEGIN_EVENT_TABLE(MaskImageCtrl, wxScrolledWindow)
     EVT_KEY_UP(MaskImageCtrl::OnKeyUp)
     EVT_MOUSE_CAPTURE_LOST(MaskImageCtrl::OnCaptureLost)
     EVT_KILL_FOCUS(MaskImageCtrl::OnKillFocus)
+    EVT_SCROLLWIN(MaskImageCtrl::OnScroll)
 END_EVENT_TABLE()
 
 bool MaskImageCtrl::Create(wxWindow * parent, wxWindowID id,
@@ -75,6 +76,8 @@ bool MaskImageCtrl::Create(wxWindow * parent, wxWindowID id,
     m_activeMask = UINT_MAX;
     m_showActiveMasks = false;
     m_maskMode = true;
+    m_oldScrollPosX = -1;
+    m_oldScrollPosY = -1;
 
     return true;
 }
@@ -108,11 +111,35 @@ void MaskImageCtrl::SetMaskMode(bool newMaskMode)
 void MaskImageCtrl::setImage(const std::string & file, HuginBase::MaskPolygonVector newMask, HuginBase::MaskPolygonVector masksToDraw, ImageRotation rot)
 {
     DEBUG_TRACE("setting Image " << file);
-    m_imageFilename = file;
-    wxString fn(m_imageFilename.c_str(),HUGIN_CONV_FILENAME);
-    if (wxFileName::FileExists(fn))
+    if(!file.empty())
     {
-        m_img = ImageCache::getInstance().getImage(m_imageFilename);
+        try
+        {
+            m_img = ImageCache::getInstance().getImage(file);
+        }
+        catch (...)
+        {
+            // loading of image failed, set all to empty values
+            m_imageFilename = "";
+            m_maskEditState = NO_IMAGE;
+            m_bitmap = wxBitmap();
+            // delete the image (release shared_ptr)
+            // create an empty image.
+            m_img = ImageCache::EntryPtr(new ImageCache::Entry);
+            HuginBase::MaskPolygonVector mask;
+            m_imageMask = mask;
+            m_masksToDraw = mask;
+            m_imgRotation = ROT0;
+            setActiveMask(UINT_MAX, false);
+            SetVirtualSize(100, 100);
+            Refresh(true);
+            // now notify main frame to remove the image from project
+            wxCommandEvent e(EVT_LOADING_FAILED);
+            e.SetString(wxString(file.c_str(), HUGIN_CONV_FILENAME));
+            MainFrame::Get()->GetEventHandler()->AddPendingEvent(e);
+            return;
+        }
+        m_imageFilename = file;
         if(m_maskMode)
         {
             m_maskEditState = NO_MASK;
@@ -126,6 +153,7 @@ void MaskImageCtrl::setImage(const std::string & file, HuginBase::MaskPolygonVec
         m_imgRotation=rot;
         setActiveMask(UINT_MAX,false);
         rescaleImage();
+        Scroll(m_oldScrollPosX, m_oldScrollPosY);
     }
     else
     {
@@ -148,8 +176,14 @@ void MaskImageCtrl::setNewMasks(HuginBase::MaskPolygonVector newMasks, HuginBase
 {
     m_imageMask=newMasks;
     m_masksToDraw=masksToDraw;
-    if(m_activeMask>=m_imageMask.size())
+    if (m_activeMask >= m_imageMask.size())
+    {
         setActiveMask(UINT_MAX);
+    }
+    else
+    {
+        setActiveMask(m_activeMask);
+    };
     Refresh(false);
 };
 
@@ -220,7 +254,7 @@ void MaskImageCtrl::selectAllMarkers()
 MaskImageCtrl::ClickPos MaskImageCtrl::GetClickPos(vigra::Point2D pos)
 {
     vigra::Rect2D testRect(pos.x-maxSelectionDistance, pos.y-maxSelectionDistance, pos.x+maxSelectionDistance, pos.y+maxSelectionDistance);
-    if(m_cropMode==SrcPanoImage::CROP_CIRCLE)
+    if (m_cropMode == HuginBase::SrcPanoImage::CROP_CIRCLE)
     {
         double radius=std::min<int>(m_cropRect.width(), m_cropRect.height())/2.0;
         vigra::Point2D pos_center((m_cropRect.left()+m_cropRect.right())/2, (m_cropRect.top()+m_cropRect.bottom())/2);
@@ -258,7 +292,7 @@ MaskImageCtrl::ClickPos MaskImageCtrl::GetClickPos(vigra::Point2D pos)
 
 void MaskImageCtrl::UpdateCrop(hugin_utils::FDiff2D pos)
 {
-    FDiff2D delta=pos-applyRotInv(invtransform(m_currentPos));
+    hugin_utils::FDiff2D delta=pos-applyRotInv(invtransform(m_currentPos));
     int newLeft, newRight, newTop, newBottom;
     bool needsUpdate=false;
     switch (m_maskEditState)
@@ -332,7 +366,7 @@ void MaskImageCtrl::UpdateCrop(hugin_utils::FDiff2D pos)
             break;
         case CROP_CIRCLE_SCALING:
             {
-                double radius=sqrt(sqr(pos.x-m_dragStartPos.x)+sqr(pos.y-m_dragStartPos.y));
+                double radius=sqrt(hugin_utils::sqr(pos.x-m_dragStartPos.x)+hugin_utils::sqr(pos.y-m_dragStartPos.y));
                 newLeft=m_dragStartPos.x-radius;
                 newRight=m_dragStartPos.x+radius;
                 newTop=m_dragStartPos.y-radius;
@@ -340,6 +374,10 @@ void MaskImageCtrl::UpdateCrop(hugin_utils::FDiff2D pos)
                 needsUpdate=true;
             };
             break;
+        default:
+            // in all other cases the crop is not changed
+            // this should not happen
+            break;
     };
     if(needsUpdate)
     {
@@ -368,7 +406,7 @@ void MaskImageCtrl::OnMouseMove(wxMouseEvent& mouse)
     wxPoint mpos;
     CalcUnscrolledPosition(mouse.GetPosition().x, mouse.GetPosition().y,
                            &mpos.x, & mpos.y);
-    FDiff2D currentPos=applyRotInv(invtransform(mpos));
+    hugin_utils::FDiff2D currentPos=applyRotInv(invtransform(mpos));
     bool doUpdate = false;
     switch(m_maskEditState)
     {
@@ -389,7 +427,7 @@ void MaskImageCtrl::OnMouseMove(wxMouseEvent& mouse)
             doUpdate=true;
             m_editingMask=m_imageMask[m_activeMask];
             {
-                FDiff2D delta=currentPos-applyRotInv(invtransform(m_dragStartPos));
+                hugin_utils::FDiff2D delta=currentPos-applyRotInv(invtransform(m_dragStartPos));
                 for(HuginBase::UIntSet::const_iterator it=m_selectedPoints.begin();it!=m_selectedPoints.end();++it)
                     m_editingMask.movePointBy(*it,delta);
             };
@@ -461,6 +499,13 @@ void MaskImageCtrl::OnMouseMove(wxMouseEvent& mouse)
 #endif
             m_editPanel->UpdateCropFromImage();
             break;
+        case NO_IMAGE:
+        case NO_MASK:
+        case NO_SELECTION:
+        case POINTS_SELECTED:
+        case NEW_POLYGON_STARTED:
+            // in all other cases do nothing
+            break;
     };
     if(doUpdate)
         update();
@@ -473,7 +518,7 @@ void MaskImageCtrl::OnLeftMouseDown(wxMouseEvent& mouse)
     DEBUG_DEBUG("LEFT MOUSE DOWN");
     CalcUnscrolledPosition(mouse.GetPosition().x, mouse.GetPosition().y,
                            &m_dragStartPos.x, & m_dragStartPos.y);
-    FDiff2D currentPos=applyRotInv(invtransform(m_dragStartPos));
+    hugin_utils::FDiff2D currentPos=applyRotInv(invtransform(m_dragStartPos));
     m_currentPos=m_dragStartPos;
     if(!HasCapture())
         CaptureMouse();
@@ -565,6 +610,9 @@ void MaskImageCtrl::OnLeftMouseDown(wxMouseEvent& mouse)
         case CROP_SHOWING:
             switch(GetClickPos(vigra::Point2D(currentPos.x,currentPos.y)))
             {
+                case CLICK_OUTSIDE:
+                    // clicked outside, do nothing
+                    break;
                 case CLICK_INSIDE:
                     if(!m_cropCentered)
                     {
@@ -591,19 +639,22 @@ void MaskImageCtrl::OnLeftMouseDown(wxMouseEvent& mouse)
             };
             if(m_maskEditState!=CROP_SHOWING)
             {
-                if(m_cropMode==SrcPanoImage::NO_CROP && m_cropCircle)
+                if (m_cropMode == HuginBase::SrcPanoImage::NO_CROP && m_cropCircle)
                 {
 #if defined SUPPORTS_WXINVERT
                     DrawCrop();
-                    m_cropMode=SrcPanoImage::CROP_CIRCLE;
+                    m_cropMode = HuginBase::SrcPanoImage::CROP_CIRCLE;
                     DrawCrop();
 #else
-                    m_cropMode=SrcPanoImage::CROP_CIRCLE;
+                    m_cropMode=HuginBase::SrcPanoImage::CROP_CIRCLE;
                     update();
 #endif
                 };
             };
             break;
+        default:
+            // otherwise do nothing
+            break;
     };
 };
 
@@ -615,7 +666,7 @@ void MaskImageCtrl::OnLeftMouseUp(wxMouseEvent& mouse)
     wxPoint mpos;
     CalcUnscrolledPosition(mouse.GetPosition().x, mouse.GetPosition().y,
                            &mpos.x, & mpos.y);
-    FDiff2D currentPos=applyRotInv(invtransform(mpos));
+    hugin_utils::FDiff2D currentPos=applyRotInv(invtransform(mpos));
     bool doUpdate=false;
     switch(m_maskEditState)
     {
@@ -635,8 +686,8 @@ void MaskImageCtrl::OnLeftMouseUp(wxMouseEvent& mouse)
             if(HasCapture())
                 ReleaseMouse();
             {
-                FDiff2D delta=currentPos-applyRotInv(invtransform(m_dragStartPos));
-                if(sqr(delta.x)+sqr(delta.y)>sqr(maxSelectionDistance))
+                hugin_utils::FDiff2D delta=currentPos-applyRotInv(invtransform(m_dragStartPos));
+                if(hugin_utils::sqr(delta.x)+hugin_utils::sqr(delta.y)>hugin_utils::sqr(maxSelectionDistance))
                 {
                     for(HuginBase::UIntSet::const_iterator it=m_selectedPoints.begin();it!=m_selectedPoints.end();++it)
                         m_imageMask[m_activeMask].movePointBy(*it,delta);
@@ -691,7 +742,7 @@ void MaskImageCtrl::OnLeftMouseUp(wxMouseEvent& mouse)
                     //there were no points selected
                     if(!selectedPoints)
                     {
-                        //if there where no points selected before, we searching for an other polygon
+                        //if there where no points selected before, we searching for another polygon
                         hugin_utils::FDiff2D p;
                         p.x=invtransform(m_dragStartPos.x+(m_currentPos.x-m_dragStartPos.x)/2);
                         p.y=invtransform(m_dragStartPos.y+(m_currentPos.y-m_dragStartPos.y)/2);
@@ -745,10 +796,6 @@ void MaskImageCtrl::OnLeftMouseDblClick(wxMouseEvent &mouse)
 {
     if(m_previewOnly)
         return;
-    wxPoint mpos;
-    CalcUnscrolledPosition(mouse.GetPosition().x, mouse.GetPosition().y,
-                           &mpos.x, & mpos.y);
-    FDiff2D currentPos=applyRotInv(invtransform(mpos));
     switch(m_maskEditState)
     {
         case NEW_POLYGON_STARTED:
@@ -783,6 +830,9 @@ void MaskImageCtrl::OnLeftMouseDblClick(wxMouseEvent &mouse)
                 MainFrame::Get()->SetStatusText(wxT(""),0);
                 break;
             };
+        default:
+            // the other case do nothing here
+            break;
     };
 };
 
@@ -790,33 +840,29 @@ void MaskImageCtrl::OnRightMouseDown(wxMouseEvent& mouse)
 {
     if(m_previewOnly)
         return;
-    wxPoint mpos;
     CalcUnscrolledPosition(mouse.GetPosition().x, mouse.GetPosition().y,
                            &m_dragStartPos.x, & m_dragStartPos.y);
-    FDiff2D currentPos=applyRotInv(invtransform(m_dragStartPos));
+    hugin_utils::FDiff2D currentPos=applyRotInv(invtransform(m_dragStartPos));
     m_currentPos=m_dragStartPos;
     if(!HasCapture())
         CaptureMouse();
     SetFocus();
-    switch(m_maskEditState)
+    if(m_maskEditState==NO_SELECTION || m_maskEditState==POINTS_SELECTED)
     {
-        case NO_SELECTION:
-        case POINTS_SELECTED:
-            if(mouse.CmdDown())
+        if(mouse.CmdDown())
+        {
+            m_maskEditState=POINTS_DELETING;
+            DrawSelectionRectangle();
+        }
+        else
+        {
+            if (m_editingMask.isInside(currentPos))
             {
-                m_maskEditState=POINTS_DELETING;
-                DrawSelectionRectangle();
-            }
-            else
-            {
-                if (m_editingMask.isInside(currentPos))
-                {
-                    fill_set(m_selectedPoints,0,m_editingMask.getMaskPolygon().size()-1);
-                    m_maskEditState=POINTS_MOVING;
-                    update();
-                };
+                fill_set(m_selectedPoints,0,m_editingMask.getMaskPolygon().size()-1);
+                m_maskEditState=POINTS_MOVING;
+                update();
             };
-            break;
+        };
     };
 };
 
@@ -827,7 +873,7 @@ void MaskImageCtrl::OnRightMouseUp(wxMouseEvent& mouse)
     wxPoint mpos;
     CalcUnscrolledPosition(mouse.GetPosition().x, mouse.GetPosition().y,
                            &mpos.x, & mpos.y);
-    FDiff2D currentPos=applyRotInv(invtransform(mpos));
+    hugin_utils::FDiff2D currentPos=applyRotInv(invtransform(mpos));
     if(HasCapture())
         ReleaseMouse();
     switch(m_maskEditState)
@@ -907,8 +953,8 @@ void MaskImageCtrl::OnRightMouseUp(wxMouseEvent& mouse)
             };
         case POINTS_MOVING:
             {
-                FDiff2D delta=currentPos-applyRotInv(invtransform(m_dragStartPos));
-                if(sqr(delta.x)+sqr(delta.y)>sqr(maxSelectionDistance))
+                hugin_utils::FDiff2D delta=currentPos-applyRotInv(invtransform(m_dragStartPos));
+                if(hugin_utils::sqr(delta.x)+hugin_utils::sqr(delta.y)>hugin_utils::sqr(maxSelectionDistance))
                 {
                     for(HuginBase::UIntSet::const_iterator it=m_selectedPoints.begin();it!=m_selectedPoints.end();++it)
                         m_imageMask[m_activeMask].movePointBy(*it,delta);
@@ -922,6 +968,8 @@ void MaskImageCtrl::OnRightMouseUp(wxMouseEvent& mouse)
                 };
                 break;
             };
+        default:
+            break;
     };
 };
 
@@ -933,36 +981,36 @@ void MaskImageCtrl::OnKeyUp(wxKeyEvent &e)
     {
         if(m_activeMask<UINT_MAX)
         {
-            switch(m_maskEditState)
+            if (m_maskEditState == POINTS_SELECTED)
             {
-                case POINTS_SELECTED:
-                    if((m_selectedPoints.size()>0) && (m_editingMask.getMaskPolygon().size()-m_selectedPoints.size()>2))
-                    {
-                        for(HuginBase::UIntSet::const_reverse_iterator it=m_selectedPoints.rbegin();it!=m_selectedPoints.rend();++it)
-                            m_editingMask.removePoint(*it);
-                        m_imageMask[m_activeMask]=m_editingMask;
-                        processed=true;
-                        m_editPanel->UpdateMask();
-                    }
-                    else
-                    {
-                        if(m_editingMask.getMaskPolygon().size()==m_selectedPoints.size())
-                        {
-                            wxCommandEvent dummy;
-                            processed=true;
-                            m_editPanel->OnMaskDelete(dummy);
-                        }
-                        else
-                            wxBell();
-                    };
-                    break;
-                case NO_SELECTION:
+                if ((m_selectedPoints.size()>0) && (m_editingMask.getMaskPolygon().size() - m_selectedPoints.size() > 2))
+                {
+                    for (HuginBase::UIntSet::const_reverse_iterator it = m_selectedPoints.rbegin(); it != m_selectedPoints.rend(); ++it)
+                        m_editingMask.removePoint(*it);
+                    m_imageMask[m_activeMask] = m_editingMask;
+                    processed = true;
+                    m_editPanel->UpdateMask();
+                }
+                else
+                {
+                    if (m_editingMask.getMaskPolygon().size() == m_selectedPoints.size())
                     {
                         wxCommandEvent dummy;
-                        processed=true;
+                        processed = true;
                         m_editPanel->OnMaskDelete(dummy);
-                    };
-                    break;
+                    }
+                    else
+                        wxBell();
+                };
+            }
+            else
+            {
+                if(m_maskEditState==NO_SELECTION)
+                {
+                    wxCommandEvent dummy;
+                    processed=true;
+                    m_editPanel->OnMaskDelete(dummy);
+                };
             };
         };
     };
@@ -980,19 +1028,14 @@ void MaskImageCtrl::OnKillFocus(wxFocusEvent &e)
 {
     if(HasCapture())
         ReleaseMouse();
-    switch(m_maskEditState)
+    if(m_maskEditState==NEW_POLYGON_CREATING || m_maskEditState==NEW_POLYGON_STARTED)
     {
-        case NEW_POLYGON_CREATING:
-        case NEW_POLYGON_STARTED:
-            {
-                wxBell();
-                m_maskEditState=NO_SELECTION;
-                HuginBase::MaskPolygon mask;
-                m_editingMask=mask;
-                m_selectedPoints.clear();
-                update();
-                break;
-            };
+        wxBell();
+        m_maskEditState=NO_SELECTION;
+        HuginBase::MaskPolygon mask;
+        m_editingMask=mask;
+        m_selectedPoints.clear();
+        update();
     };
 };
 
@@ -1027,15 +1070,18 @@ void MaskImageCtrl::DrawPolygon(wxDC &dc, HuginBase::MaskPolygon poly, bool isSe
         polygonPoints[j]=transform(applyRot(poly.getMaskPolygon()[j]));
     };
     if(isSelected)
-        dc.SetPen(wxPen(m_colour_point_unselected,1,wxSOLID));
+        dc.SetPen(wxPen(m_colour_point_unselected, 1, wxPENSTYLE_SOLID));
     else
         switch(poly.getMaskType())
         {
             case HuginBase::MaskPolygon::Mask_negative:
-                dc.SetPen(wxPen(m_colour_polygon_negative,1,wxSOLID));
+            case HuginBase::MaskPolygon::Mask_Stack_negative:
+            case HuginBase::MaskPolygon::Mask_negative_lens:
+                dc.SetPen(wxPen(m_colour_polygon_negative, 1, wxPENSTYLE_SOLID));
                 break;
             case HuginBase::MaskPolygon::Mask_positive:
-                dc.SetPen(wxPen(m_colour_polygon_positive,1,wxSOLID));
+            case HuginBase::MaskPolygon::Mask_Stack_positive:
+                dc.SetPen(wxPen(m_colour_polygon_positive, 1, wxPENSTYLE_SOLID));
                  break;
         };
     dc.SetBrush(*wxTRANSPARENT_BRUSH);
@@ -1106,13 +1152,13 @@ void MaskImageCtrl::DrawCrop(wxDC & dc)
 
 void MaskImageCtrl::OnDraw(wxDC & dc)
 {
-    if(m_maskEditState!=NO_IMAGE)
+    if(m_maskEditState!=NO_IMAGE && m_bitmap.IsOk())
     {
         int offset=scale(HuginBase::maskOffset);
         //draw border around image to allow drawing mask over boudaries of image
         //don't draw as one complete rectangle to prevent flickering
-        dc.SetPen(wxPen(GetBackgroundColour(), 1, wxSOLID));
-        dc.SetBrush(wxBrush(GetBackgroundColour(),wxSOLID));
+        dc.SetPen(wxPen(GetBackgroundColour(), 1, wxPENSTYLE_SOLID));
+        dc.SetBrush(wxBrush(GetBackgroundColour(), wxBRUSHSTYLE_SOLID));
         dc.DrawRectangle(0,0,offset,m_bitmap.GetHeight()+2*offset);
         dc.DrawRectangle(0,0,m_bitmap.GetWidth()+2*offset,offset);
         dc.DrawRectangle(m_bitmap.GetWidth()+offset,0,m_bitmap.GetWidth()+2*offset,m_bitmap.GetHeight()+2*offset);
@@ -1131,13 +1177,13 @@ void MaskImageCtrl::OnDraw(wxDC & dc)
                 dc.DrawRectangle(0,m_bitmap.GetHeight()+2*offset,clientSize.GetWidth(),clientSize.GetHeight()-m_bitmap.GetHeight()+2*offset);
             };
         };
-        if(m_maskMode && m_showActiveMasks && (m_cropMode!=SrcPanoImage::NO_CROP || m_masksToDraw.size()>0))
+        if (m_maskMode && m_showActiveMasks && (m_cropMode != HuginBase::SrcPanoImage::NO_CROP || m_masksToDraw.size()>0))
         {
             //whole image, we need it several times
             wxRegion wholeImage(transform(applyRot(hugin_utils::FDiff2D(0,0))),
                                 transform(applyRot(hugin_utils::FDiff2D(m_realSize.GetWidth(),m_realSize.GetHeight()))));
             wxRegion region;
-            if(m_cropMode!=SrcPanoImage::NO_CROP)
+            if (m_cropMode != HuginBase::SrcPanoImage::NO_CROP)
             {
                 region.Union(wholeImage);
                 //now the crop
@@ -1148,17 +1194,21 @@ void MaskImageCtrl::OnDraw(wxDC & dc)
                             transform(applyRot(m_cropRect.lowerRight()))));
                         break;
                     case HuginBase::SrcPanoImage::CROP_CIRCLE:
-                        unsigned int nrOfPoints=dc.GetSize().GetWidth()*2;
-                        wxPoint* circlePoints=new wxPoint[nrOfPoints];
-                        vigra::Point2D middle=(m_cropRect.lowerRight()+m_cropRect.upperLeft())/2;
-                        double radius=std::min<int>(m_cropRect.width(),m_cropRect.height())/2;
-                        double interval=2*PI/nrOfPoints;
-                        for(unsigned int i=0;i<nrOfPoints;i++)
                         {
-                            circlePoints[i]=transform(applyRot(hugin_utils::FDiff2D(middle.x+radius*cos(i*interval),middle.y+radius*sin(i*interval))));
-                        };
-                        region.Subtract(wxRegion(nrOfPoints,circlePoints));
-                        delete []circlePoints;
+                            unsigned int nrOfPoints = dc.GetSize().GetWidth() * 2;
+                            wxPoint* circlePoints = new wxPoint[nrOfPoints];
+                            vigra::Point2D middle = (m_cropRect.lowerRight() + m_cropRect.upperLeft()) / 2;
+                            double radius = std::min<int>(m_cropRect.width(), m_cropRect.height()) / 2;
+                            double interval = 2 * PI / nrOfPoints;
+                            for (unsigned int i = 0; i < nrOfPoints; i++)
+                            {
+                                circlePoints[i] = transform(applyRot(hugin_utils::FDiff2D(middle.x + radius*cos(i*interval), middle.y + radius*sin(i*interval))));
+                            };
+                            region.Subtract(wxRegion(nrOfPoints, circlePoints));
+                            delete[]circlePoints;
+                        }
+                        break;
+                    case HuginBase::BaseSrcPanoImage::NO_CROP:
                         break;
                 };
             };
@@ -1221,8 +1271,8 @@ void MaskImageCtrl::OnDraw(wxDC & dc)
     else
     {
         // clear the rectangle and exit
-        dc.SetPen(wxPen(GetBackgroundColour(), 1, wxSOLID));
-        dc.SetBrush(wxBrush(GetBackgroundColour(),wxSOLID));
+        dc.SetPen(wxPen(GetBackgroundColour(), 1, wxPENSTYLE_SOLID));
+        dc.SetBrush(wxBrush(GetBackgroundColour(), wxBRUSHSTYLE_SOLID));
         dc.Clear();
         return;
     };
@@ -1239,6 +1289,13 @@ void MaskImageCtrl::OnSize(wxSizeEvent &e)
     }
 };
 
+void MaskImageCtrl::OnScroll(wxScrollWinEvent &e)
+{
+    m_oldScrollPosX = GetScrollPos(wxHORIZONTAL);
+    m_oldScrollPosY = GetScrollPos(wxVERTICAL);
+    e.Skip();
+}
+
 void MaskImageCtrl::rescaleImage()
 {
     if (m_maskEditState == NO_IMAGE)
@@ -1300,30 +1357,15 @@ void MaskImageCtrl::rescaleImage()
         default:
             break;
     }
+    // do color correction only if input image has icc profile or if we found a monitor profile
+    if (!m_img->iccProfile->empty() || huginApp::Get()->HasMonitorProfile())
+    {
+        HuginBase::Color::CorrectImage(img, *(m_img->iccProfile), huginApp::Get()->GetMonitorProfile());
+    };
     m_bitmap=wxBitmap(img);
 
     //create disabled m_bitmap for drawing active masks
-#if wxCHECK_VERSION(2,9,0)
     img = img.ConvertToDisabled(192);
-#else
-    {
-        int width = img.GetWidth();
-        int height = img.GetHeight();
-        for (int y = height-1; y >= 0; --y)
-        {
-            for (int x = width-1; x >= 0; --x)
-            {
-                unsigned char* data = img.GetData() + (y*(width*3))+(x*3);
-                unsigned char* r = data;
-                unsigned char* g = data+1;
-                unsigned char* b = data+2;
-                *r=(unsigned char)wxMin(0.6*(*r)+77,255);
-                *b=(unsigned char)wxMin(0.6*(*b)+77,255);
-                *g=(unsigned char)wxMin(0.6*(*g)+77,255);
-            }
-        }
-    }
-#endif
     m_disabledBitmap=wxBitmap(img);
     if (m_imgRotation == ROT90 || m_imgRotation == ROT270)
     {
@@ -1333,7 +1375,7 @@ void MaskImageCtrl::rescaleImage()
     {
         SetVirtualSize(m_imageSize.GetWidth(), m_imageSize.GetHeight());
     };
-    SetScrollRate(1,1);
+    SetScrollRate(std::max<int>(1, m_bitmap.GetWidth() / 75), std::max<int>(1, m_bitmap.GetHeight() / 75));
     Refresh(true);
 };
 
@@ -1343,10 +1385,10 @@ void MaskImageCtrl::DrawSelectionRectangle()
     PrepareDC(dc);
 #if defined SUPPORTS_WXINVERT
     dc.SetLogicalFunction(wxINVERT);
-    dc.SetPen(wxPen(*wxWHITE,1,wxDOT));
+    dc.SetPen(wxPen(*wxWHITE, 1, wxPENSTYLE_DOT));
 #else
     OnDraw(dc);
-    dc.SetPen(wxPen(m_color_selection, scale(1), wxDOT));
+    dc.SetPen(wxPen(m_color_selection, scale(1), wxPENSTYLE_DOT));
 #endif
     dc.SetBrush(*wxTRANSPARENT_BRUSH);
     dc.DrawRectangle(m_dragStartPos.x,m_dragStartPos.y,
