@@ -18,8 +18,8 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -35,8 +35,14 @@
 // this approach is already used for the polygon editor also on wxMSW and wxGTK
 #undef SUPPORTS_WXINVERT
 #else
+#ifdef __WXGTK3__
+// wxINVERT is currently also not supported on GTK+3
+// see ticket http://trac.wxwidgets.org/ticket/16890
+#undef SUPPORTS_WXINVERT
+#else
 #define SUPPORTS_WXINVERT 1
 #endif
+#endif
 
 class MaskEditorPanel;
 
@@ -50,7 +56,7 @@ public:
     /** ctor.
      */
     MaskImageCtrl()
-        : m_scaleFactor(1),m_fitToWindow(false),m_maskEditState(NO_IMAGE)
+        : m_maskEditState(NO_IMAGE), m_scaleFactor(1), m_fitToWindow(false)
         { }
 
     bool Create(wxWindow* parent, wxWindowID id = wxID_ANY, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = wxTAB_TRAVERSAL, const wxString& name = wxT("panel"));
@@ -99,6 +105,8 @@ public:
     void OnCaptureLost(wxMouseCaptureLostEvent &e);
     /** event handler, when editor lost focus, mainly cancels creating new polygon */
     void OnKillFocus(wxFocusEvent &e);
+    /** event handler for remember scroll position */
+    void OnScroll(wxScrollWinEvent &e);
 
     /** starts creating a new polygon */
     void startNewPolygon();
@@ -132,9 +140,9 @@ public:
     void SetUserColourPointSelected(wxColour newColour) { m_colour_point_selected=newColour; };
     void SetUserColourPointUnselected(wxColour newColour) { m_colour_point_unselected=newColour; };
 
-protected:
     /** drawing routine */
-    void OnDraw(wxDC& dc);
+    virtual void OnDraw(wxDC& dc);
+protected:
     /** handler called when size of control was changed */
     void OnSize(wxSizeEvent & e);
 
@@ -284,7 +292,7 @@ protected:
         POINTS_MOVING, // dragging points
         POINTS_DELETING,  // remove points inside rect
         POINTS_ADDING,  // adding new points add mouse position
-        POLYGON_SELECTING, // selecting an region to select an other polygon
+        POLYGON_SELECTING, // selecting an region to select another polygon
         REGION_SELECTING, // currently selecting an region
         NEW_POLYGON_STARTED, // modus is new polygon, but no point setted yet
         NEW_POLYGON_CREATING,  // currently creating new polygon
@@ -325,6 +333,7 @@ protected:
 #ifndef SUPPORTS_WXINVERT
     wxColour m_color_selection;
 #endif
+    int m_oldScrollPosX, m_oldScrollPosY;
 
     DECLARE_EVENT_TABLE();
     DECLARE_DYNAMIC_CLASS(MaskImageCtrl)
