@@ -24,7 +24,7 @@
  *
  */
 
-#include <config.h>
+#include "hugin_config.h"
 #include "panoinc_WX.h"
 
 #include "panoinc.h"
@@ -54,6 +54,7 @@ BEGIN_EVENT_TABLE(OptimizePhotometricPanel, wxPanel)
     EVT_CLOSE(OptimizePhotometricPanel::OnClose)
     EVT_BUTTON(XRCID("optimize_photo_panel_optimize"), OptimizePhotometricPanel::OnOptimizeButton)
     EVT_BUTTON(XRCID("optimize_photo_panel_reset"), OptimizePhotometricPanel::OnReset)
+    EVT_CHECKBOX(XRCID("optimize_photo_panel_only_active_images"), OptimizePhotometricPanel::OnCheckOnlyActiveImages)
 END_EVENT_TABLE()
 
 OptimizePhotometricPanel::OptimizePhotometricPanel() : m_pano(0)
@@ -78,7 +79,6 @@ bool OptimizePhotometricPanel::Create(wxWindow *parent, wxWindowID id, const wxP
 
     m_only_active_images_cb = XRCCTRL(*this, "optimize_photo_panel_only_active_images", wxCheckBox);
     DEBUG_ASSERT(m_only_active_images_cb);
-    m_only_active_images_cb->SetValue(wxConfigBase::Get()->Read(wxT("/OptimizeOptimizePhotometricPanelPanel/OnlyActiveImages"),1l) != 0);
 
     m_images_tree = XRCCTRL(*this, "optimize_photo_panel_images", ImagesTreeCtrl);
     DEBUG_ASSERT(m_images_tree);
@@ -87,17 +87,6 @@ bool OptimizePhotometricPanel::Create(wxWindow *parent, wxWindowID id, const wxP
 
     XRCCTRL(*this, "optimize_photo_panel_splitter", wxSplitterWindow)->SetSashGravity(0.66);
 
-    wxString text(_("Any variables below which are bold and underlined will be optimized."));
-    text.Append(wxT(" "));
-#if defined __WXMAC__ || defined __WXOSX_COCOA__
-    text.Append(_("Use command + left mouse click to toggle state of variables."));
-#else
-    text.Append(_("Use control + left mouse click to toggle state of variables."));
-#endif
-    text.Append(wxT(" "));
-    text.Append(_("Variables which shown in normal font will act as references or anchors."));
-    XRCCTRL(*this, "optimize_photo_panel_information_text", wxStaticText)->SetLabel(text);
-
     return true;
 }
 
@@ -126,12 +115,23 @@ void OptimizePhotometricPanel::SetGuiLevel(GuiLevel newGuiLevel)
 OptimizePhotometricPanel::~OptimizePhotometricPanel()
 {
     DEBUG_TRACE("dtor, writing config");
-    wxConfigBase::Get()->Write(wxT("/OptimizePhotometricPanel/OnlyActiveImages"),m_only_active_images_cb->IsChecked() ? 1l : 0l);
 
     m_pano->removeObserver(this);
     DEBUG_TRACE("dtor end");
 }
 
+void OptimizePhotometricPanel::OnCheckOnlyActiveImages(wxCommandEvent & e)
+{
+    MainFrame::Get()->SetOptimizeOnlyActiveImages(e.IsChecked());
+};
+
+void OptimizePhotometricPanel::SetOnlyActiveImages(const bool onlyActive)
+{
+    m_only_active_images_cb->SetValue(onlyActive);
+    m_images_tree->MarkActiveImages(onlyActive);
+    m_lens_tree->MarkActiveImages(onlyActive);
+};
+
 void OptimizePhotometricPanel::OnOptimizeButton(wxCommandEvent & e)
 {
     DEBUG_TRACE("");
@@ -264,6 +264,8 @@ void OptimizePhotometricPanel::runOptimizer(const HuginBase::UIntSet & imgs)
         nPoints = nPoints * optPano.getNrOfImages();
         // get the small images
         std::vector<vigra::FRGBImage *> srcImgs;
+        HuginBase::LimitIntensityVector limits;
+        float imageStepSize = 1 / 255.0f;
         for (size_t i=0; i < optPano.getNrOfImages(); i++)
         {
             ImageCache::EntryPtr e = ImageCache::getInstance().getSmallImage(optPano.getImage(i).getFilename());
@@ -272,34 +274,55 @@ void OptimizePhotometricPanel::runOptimizer(const HuginBase::UIntSet & imgs)
                 wxMessageBox(_("Error: could not load all images"), _("Error"));
                 return;
             }
+            HuginBase::LimitIntensity limit;
             vigra::FRGBImage * img = new vigra::FRGBImage;
-            if (e->image8 && e->image8->width() > 0)
+            if (e->imageFloat && e->imageFloat->size().area() > 0)
             {
-                vigra_ext::reduceToNextLevel(*(e->image8), *img);
-                vigra::omp::transformImage(vigra::srcImageRange(*img), vigra::destImage(*img),
-                                vigra::functor::Arg1()/vigra::functor::Param(255.0));
-            }
-            else
-            {
-                if (e->image16 && e->image16->width() > 0)
+                if (e->mask->size().area() > 0)
                 {
-                    vigra_ext::reduceToNextLevel(*(e->image16), *img);
-                    vigra::omp::transformImage(vigra::srcImageRange(*img), vigra::destImage(*img),
-                                   vigra::functor::Arg1()/vigra::functor::Param(65535.0));
+                    vigra::BImage maskSmall;
+                    vigra_ext::reduceToNextLevel(*(e->imageFloat), *(e->mask), *img, maskSmall);
+                    vigra_ext::FindComponentsMinMax<float> minmax;
+                    vigra::inspectImageIf(srcImageRange(*img), srcImage(maskSmall), minmax);
+                    imageStepSize = std::min(imageStepSize, (minmax.max - minmax.min) / 16384.0f);
                 }
                 else
                 {
                     vigra_ext::reduceToNextLevel(*(e->imageFloat), *img);
+                    vigra_ext::FindComponentsMinMax<float> minmax;
+                    vigra::inspectImage(srcImageRange(*img), minmax);
+                    imageStepSize = std::min(imageStepSize, (minmax.max - minmax.min) / 16384.0f);
+                };
+                limit = HuginBase::LimitIntensity(HuginBase::LimitIntensity::LIMIT_FLOAT);
+            }
+            else
+            {
+                if (e->image16 && e->image16->size().area() > 0)
+                {
+                    vigra_ext::reduceToNextLevel(*(e->image16), *img);
+                    vigra::omp::transformImage(vigra::srcImageRange(*img), vigra::destImage(*img),
+                        vigra::functor::Arg1() / vigra::functor::Param(65535.0));
+                    limit = HuginBase::LimitIntensity(HuginBase::LimitIntensity::LIMIT_UINT16);
+                    imageStepSize = std::min(imageStepSize, 1 / 65536.0f);
                 }
+                else
+                {
+                    vigra_ext::reduceToNextLevel(*(e->get8BitImage()), *img);
+                    vigra::omp::transformImage(vigra::srcImageRange(*img), vigra::destImage(*img),
+                        vigra::functor::Arg1() / vigra::functor::Param(255.0));
+                    limit = HuginBase::LimitIntensity(HuginBase::LimitIntensity::LIMIT_UINT8);
+                    imageStepSize = std::min(imageStepSize, 1 / 255.0f);
+                };
             };
             srcImgs.push_back(img);
+            limits.push_back(limit);
             if (!progress.updateDisplayValue())
             {
                 // check if user pressed cancel
                 return;
             };
         }   
-        HuginBase::PointSampler::extractPoints(optPano, srcImgs, nPoints, true, &progress, points);
+        points= HuginBase::RandomPointSampler(optPano, &progress, srcImgs, limits, nPoints).execute().getResultPoints();
 
         if (!progress.updateDisplayValue())
         {
@@ -344,12 +367,12 @@ void OptimizePhotometricPanel::runOptimizer(const HuginBase::UIntSet & imgs)
                         //invalid combination
                         return;
                 };
-                HuginBase::SmartPhotometricOptimizer::smartOptimizePhotometric(optPano, optMode, points, &progress, error);
+                HuginBase::SmartPhotometricOptimizer::smartOptimizePhotometric(optPano, optMode, points, imageStepSize, &progress, error);
             }
             else
             {
                 // optimize selected parameters
-                HuginBase::PhotometricOptimizer::optimizePhotometric(optPano, optvars, points, &progress, error);
+                HuginBase::PhotometricOptimizer::optimizePhotometric(optPano, optvars, points, imageStepSize, &progress, error);
             }
             if (progress.wasCancelled())
             {
