@@ -14,8 +14,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -42,9 +42,7 @@ void PanosphereOverviewCameraTool::MouseMoveEvent(double x, double y, wxMouseEve
 {
     if (down) {
         hugin_utils::FDiff2D pos = helper->GetMouseScreenPosition();
-        PanosphereOverviewVisualizationState*  state = (PanosphereOverviewVisualizationState*) helper->GetVisualizationStatePtr();
-        double b_angx = state->getAngX();
-        double b_angy = state->getAngY();
+        PanosphereOverviewVisualizationState*  state = static_cast<PanosphereOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
         //FIXME: include a scale factor for the panosphere
         double scale = (state->getR() - state->getSphereRadius()) / 40000.0;
         state->setAngX((pos.x - start_x) * scale + start_angx);
@@ -64,7 +62,7 @@ void PanosphereOverviewCameraTool::MouseButtonEvent(wxMouseEvent &e)
         hugin_utils::FDiff2D pos = helper->GetMouseScreenPosition();
         start_x = pos.x;
         start_y = pos.y;
-        PanosphereOverviewVisualizationState*  state = (PanosphereOverviewVisualizationState*) helper->GetVisualizationStatePtr();
+        PanosphereOverviewVisualizationState*  state = static_cast<PanosphereOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
         start_angx = state->getAngX();
         start_angy = state->getAngY();
     }
@@ -77,7 +75,7 @@ void PanosphereOverviewCameraTool::MouseButtonEvent(wxMouseEvent &e)
 
 
 void PanosphereOverviewCameraTool::ChangeZoomLevel(bool zoomIn, double scale) {
-    PanosphereOverviewVisualizationState*  state = (PanosphereOverviewVisualizationState*) helper->GetVisualizationStatePtr();
+    PanosphereOverviewVisualizationState*  state = static_cast<PanosphereOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
     double radius = state->getSphereRadius();
     if (zoomIn) {
         if (state->getR() > limit_low * radius) {
@@ -128,8 +126,7 @@ void PlaneOverviewCameraTool::Activate()
 void PlaneOverviewCameraTool::MouseMoveEvent(double x, double y, wxMouseEvent & e)
 {
     if (down) {
-        PlaneOverviewToolHelper * thelper = (PlaneOverviewToolHelper*) helper;
-        PlaneOverviewVisualizationState*  state = (PlaneOverviewVisualizationState*) helper->GetVisualizationStatePtr();
+        PlaneOverviewVisualizationState*  state = static_cast<PlaneOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
 //
         //same code as in tool helper to get position on the z-plane but with initial position
         double d = state->getR();
@@ -172,8 +169,8 @@ void PlaneOverviewCameraTool::MouseMoveEvent(double x, double y, wxMouseEvent &
 
 void PlaneOverviewCameraTool::MouseButtonEvent(wxMouseEvent &e)
 {
-    PlaneOverviewToolHelper * thelper = (PlaneOverviewToolHelper*) helper;
-    PlaneOverviewVisualizationState*  state = (PlaneOverviewVisualizationState*) helper->GetVisualizationStatePtr();
+    PlaneOverviewToolHelper * thelper = static_cast<PlaneOverviewToolHelper*>(helper);
+    PlaneOverviewVisualizationState*  state = static_cast<PlaneOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
 //    DEBUG_DEBUG("mouse ov drag button");
     if (((e.CmdDown() || e.AltDown()) && e.LeftDown()) || e.MiddleDown()) {
         down = true;
@@ -190,7 +187,7 @@ void PlaneOverviewCameraTool::MouseButtonEvent(wxMouseEvent &e)
 }
 
 void PlaneOverviewCameraTool::ChangeZoomLevel(bool zoomIn, double scale) {
-    PlaneOverviewVisualizationState*  state = (PlaneOverviewVisualizationState*) helper->GetVisualizationStatePtr();
+    PlaneOverviewVisualizationState*  state = static_cast<PlaneOverviewVisualizationState*>(helper->GetVisualizationStatePtr());
     if (zoomIn) {
         state->setR(state->getR() / scale);
     } else {
