@@ -40,12 +40,12 @@
 const double OverviewOutlinesTool::res=10;
 const double OverviewOutlinesTool::mindist=2;
 
-OverviewOutlinesTool::OverviewOutlinesTool(ToolHelper * helper, GLViewer * viewer) : preview(viewer), thelper(helper),
+OverviewOutlinesTool::OverviewOutlinesTool(ToolHelper * helper, GLViewer * viewer) : thelper(helper),
+    dirty_meshes(true), preview(viewer),
     display_list_number_canvas(glGenLists(1)),
     display_list_number_crop(glGenLists(1)),
     display_list_number_canvas_outline(glGenLists(1)),
-    display_list_number_crop_outline(glGenLists(1)),
-    dirty_meshes(true)
+    display_list_number_crop_outline(glGenLists(1))
 {
     thelper->GetPanoramaPtr()->addObserver(this);
 }
@@ -65,7 +65,7 @@ void OverviewOutlinesTool::panoramaChanged(HuginBase::Panorama &pano)
 
 struct Rec {
     Rec(double left, double top, double right, double bottom) : left(left), top(top), right(right), bottom(bottom) {}
-    Rec() {}
+    Rec() : left(0), top(0), right(0), bottom(0) {}
     double left;
     double top;
     double right;
@@ -79,12 +79,14 @@ void PanosphereOverviewOutlinesTool::Activate()
     static_cast<PanosphereOverviewToolHelper*>(helper)->NotifyMe(PanosphereOverviewToolHelper::DRAW_OVER_IMAGES_FRONT, this);
     static_cast<PanosphereOverviewToolHelper*>(helper)->NotifyMe(PanosphereOverviewToolHelper::DRAW_OVER_IMAGES_BACK, this);
 //    helper->NotifyMe(ToolHelper::DRAW_OVER_IMAGES, this);
+    helper->NotifyMe(ToolHelper::MARK_DIRTY, this);
 }
 
 
 void PlaneOverviewOutlinesTool::Activate()
 {
     (helper)->NotifyMe(ToolHelper::DRAW_OVER_IMAGES, this);
+    helper->NotifyMe(ToolHelper::MARK_DIRTY, this);
 }
 
 void PlaneOverviewOutlinesTool::AfterDrawImagesEvent()
@@ -111,6 +113,11 @@ void PanosphereOverviewOutlinesTool::drawBackground()
 
 }
 
+void PanosphereOverviewOutlinesTool::MarkDirty()
+{
+    dirty_meshes = true;
+}
+
 void PlaneOverviewOutlinesTool::drawBackground()
 {
 
@@ -127,6 +134,11 @@ void PlaneOverviewOutlinesTool::drawBackground()
 
 }
 
+void PlaneOverviewOutlinesTool::MarkDirty()
+{
+    dirty_meshes = true;
+}
+
 void OverviewOutlinesTool::draw()
 {
 
@@ -249,6 +261,9 @@ void OverviewOutlinesTool::DrawRect(double left, double top, double right, doubl
         case HuginBase::PanoramaOptions::RECTILINEAR:
             image.setProjection(HuginBase::BaseSrcPanoImage::RECTILINEAR);
             break;
+        default:
+            DEBUG_ERROR("OverviewOutlinesTools: unknown projection")
+            break;
     }
     
     transform.createTransform(image, *(preview->m_visualization_state->GetOptions()));
@@ -455,7 +470,7 @@ void OverviewOutlinesTool::DrawRect(double left, double top, double right, doubl
                 if (
                         (edge1 > ressq || edge3 > ressq) 
                             && 
-                        abs(top_rec.top - top_rec.bottom) > tmindist
+                        std::abs(top_rec.top - top_rec.bottom) > tmindist
                     ) {
 
                         divide_ver = true;
@@ -463,7 +478,7 @@ void OverviewOutlinesTool::DrawRect(double left, double top, double right, doubl
                 } else if (
                             (edge2 > ressq || edge4 > ressq) 
                                 && 
-                            abs(top_rec.left - top_rec.right) > tmindist
+                            std::abs(top_rec.left - top_rec.right) > tmindist
                         ) {
 
                         divide_hor = true;
