@@ -37,6 +37,7 @@
 #include "base_wx/LensTools.h"
 #include "base_wx/wxLensDB.h"
 #include "hugin/ResetDialog.h"
+#include "hugin/ChangeImageVariableDialog.h"
 #include "hugin/MainFrame.h"
 #include <vigra_ext/openmp_vigra.h>
 #include <vigra_ext/cms.h>
@@ -75,7 +76,7 @@ bool PanoSingleImageOperation::IsEnabled(HuginBase::Panorama& pano, HuginBase::U
 
 bool PanoMultiImageOperation::IsEnabled(HuginBase::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
-    return images.size()>0;
+    return !images.empty();
 };
 
 /** small function to show add image dialog
@@ -379,6 +380,30 @@ PanoCommand::PanoCommand* AddImagesSeriesOperation::GetInternalCommand(wxWindow*
     };
 };
 
+wxString ImageVariablesExpressionOperation::GetLabel()
+{
+    return _("Manipulate image variables...");
+}
+
+PanoCommand::PanoCommand * ImageVariablesExpressionOperation::GetInternalCommand(wxWindow * parent, HuginBase::Panorama & pano, HuginBase::UIntSet images)
+{
+    ImageVariablesExpressionDialog dlg(parent, &pano);
+    if (dlg.ShowModal() == wxID_OK)
+    {
+        const std::string expression = dlg.GetExpression();
+        if (!expression.empty())
+        {
+            return new PanoCommand::UpdateVariablesByParseExpression(pano, expression);
+        };
+    };
+    return NULL;
+}
+
+bool ImageVariablesExpressionOperation::IsEnabled(HuginBase::Panorama & pano, HuginBase::UIntSet images, GuiLevel guiLevel)
+{
+    return pano.getNrOfImages() > 0 && guiLevel >= GuiLevel::GUI_ADVANCED;
+}
+
 wxString RemoveImageOperation::GetLabel()
 {
     return _("Remove selected image(s)");
@@ -454,7 +479,7 @@ bool ChangeLensOperation::IsEnabled(HuginBase::Panorama& pano, HuginBase::UIntSe
     }
     else
     {
-        //project must have more than 1 lens before you can assign an other lens number
+        //project must have more than 1 lens before you can assign another lens number
         HuginBase::StandardImageVariableGroups variableGroups(pano);
         return variableGroups.getLenses().getNumberOfParts() > 1;
     };
@@ -505,19 +530,14 @@ wxString LoadLensOperation::GetLabel()
 PanoCommand::PanoCommand* LoadLensOperation::GetInternalCommand(wxWindow* parent, HuginBase::Panorama& pano, HuginBase::UIntSet images)
 {
     HuginBase::StandardImageVariableGroups variable_groups(pano);
-    if(images.size()==1)
+    HuginBase::UIntSet lensImages = variable_groups.getLenses().getPartsSet()[variable_groups.getLenses().getPartNumber(*images.begin())];
+    if (!m_fromDatabase && images.size() == 1 && lensImages.size() > 1)
     {
+        // database is always linking the parameters, so no need to ask user
         if(wxMessageBox(_("You selected only one image.\nShould the loaded parameters be applied to all images with the same lens?"),_("Question"), wxICON_QUESTION | wxYES_NO)==wxYES)
         {
-            unsigned int lensNr = variable_groups.getLenses().getPartNumber(*images.begin());
             // get all images with the current lens.
-            for (size_t i = 0; i < pano.getNrOfImages(); i++)
-            {
-                if (variable_groups.getLenses().getPartNumber(i) == lensNr)
-                {
-                    images.insert(i);
-                };
-            };
+            std::copy(lensImages.begin(), lensImages.end(), std::inserter(images, images.end()));
         };
     };
     vigra::Size2D sizeImg0=pano.getImage(*(images.begin())).getSize();
@@ -811,9 +831,10 @@ ResetOperation::ResetOperation(ResetMode newResetMode)
     m_resetExposure=0;
     if(m_resetMode==RESET_PHOTOMETRICS)
     {
-        m_resetExposure=1;
+        m_resetExposure=3;
     };
     m_resetVignetting=(m_resetMode==RESET_PHOTOMETRICS);
+    m_resetColor = 0;
     if(m_resetMode==RESET_PHOTOMETRICS)
     {
         m_resetColor=1;
@@ -935,7 +956,7 @@ PanoCommand::PanoCommand* ResetOperation::GetInternalCommand(wxWindow* parent, H
         };
         if(m_resetExposure>0)
         {
-            if(m_resetExposure==1)
+            if(m_resetExposure==1 || m_resetExposure==3)
             {
                 if (pano.getImage(imgNr).ExposureValueisLinked())
                 {
@@ -945,7 +966,7 @@ PanoCommand::PanoCommand* ResetOperation::GetInternalCommand(wxWindow* parent, H
                 }
                 //reset to exif value
                 double eV=srcImg.calcExifExposureValue();
-                if(eV!=0)
+                if ((m_resetExposure == 1 && eV != 0) || m_resetExposure == 3)
                 {
                     map_get(ImgVars,"Eev").setValue(eV);
                 }
@@ -1089,6 +1110,7 @@ bool ResetOperation::ShowDialog(wxWindow* parent)
             reset_dlg.LimitToPhotometric();
             checkGeometric=false;
             checkPhotometric=true;
+            break;
         case RESET_DIALOG:
         default:
             checkGeometric=true;
@@ -1178,7 +1200,7 @@ bool ChangeStackOperation::IsEnabled(HuginBase::Panorama& pano, HuginBase::UIntS
     }
     else
     {
-        //project must have more than 1 stack before you can assign an other stack number
+        //project must have more than 1 stack before you can assign another stack number
         HuginBase::StandardImageVariableGroups variableGroups(pano);
         return variableGroups.getStacks().getNumberOfParts() > 1;
     };
@@ -1331,6 +1353,7 @@ void GeneratePanoOperationVector()
     PanoOpImages.push_back(new RemoveImageOperation());
     PanoOpImages.push_back(new ChangeAnchorImageOperation());
     PanoOpImages.push_back(new ChangeColorAnchorImageOperation());
+    PanoOpImages.push_back(new ImageVariablesExpressionOperation());
 
     PanoOpLens.push_back(new NewLensOperation());
     PanoOpLens.push_back(new ChangeLensOperation());
