@@ -25,7 +25,7 @@
  *
  */
 
-#include <config.h>
+#include "hugin_config.h"
 #include <wx/stdpaths.h>
 
 #include "panoinc_WX.h"
@@ -366,9 +366,9 @@ void PanoPanel::UpdateDisplay(const HuginBase::PanoramaOptions & opt, const bool
 
     std::string val;
     val = hugin_utils::doubleToString(opt.getHFOV(),1);
-    m_HFOVText->SetValue(wxString(val.c_str(), wxConvLocal));
+    m_HFOVText->ChangeValue(wxString(val.c_str(), wxConvLocal));
     val = hugin_utils::doubleToString(opt.getVFOV(), 1);
-    m_VFOVText->SetValue(wxString(val.c_str(), wxConvLocal));
+    m_VFOVText->ChangeValue(wxString(val.c_str(), wxConvLocal));
 
     // disable VFOV edit field, due to bugs in setHeight(), setWidth()
     bool hasImages = pano->getActiveImages().size() > 0;
@@ -377,13 +377,65 @@ void PanoPanel::UpdateDisplay(const HuginBase::PanoramaOptions & opt, const bool
     m_CalcHFOVButton->Enable(m_keepViewOnResize && hasImages);
     m_CalcOptROIButton->Enable(hasImages);
 
-    m_WidthTxt->SetValue(wxString::Format(wxT("%d"), opt.getWidth()));
-    m_HeightTxt->SetValue(wxString::Format(wxT("%d"), opt.getHeight()));
+    m_WidthTxt->ChangeValue(wxString::Format(wxT("%d"), opt.getWidth()));
+    m_HeightTxt->ChangeValue(wxString::Format(wxT("%d"), opt.getHeight()));
 
-    m_ROILeftTxt->SetValue(wxString::Format(wxT("%d"), opt.getROI().left() ));
-    m_ROIRightTxt->SetValue(wxString::Format(wxT("%d"), opt.getROI().right() ));
-    m_ROITopTxt->SetValue(wxString::Format(wxT("%d"), opt.getROI().top() ));
-    m_ROIBottomTxt->SetValue(wxString::Format(wxT("%d"), opt.getROI().bottom() ));
+    m_ROILeftTxt->ChangeValue(wxString::Format(wxT("%d"), opt.getROI().left() ));
+    m_ROIRightTxt->ChangeValue(wxString::Format(wxT("%d"), opt.getROI().right() ));
+    m_ROITopTxt->ChangeValue(wxString::Format(wxT("%d"), opt.getROI().top() ));
+    m_ROIBottomTxt->ChangeValue(wxString::Format(wxT("%d"), opt.getROI().bottom() ));
+    {
+        // format text for display of canvas dimension
+        wxString label = wxString::Format(wxT("%d x %d"), opt.getROI().width(), opt.getROI().height());
+        if (opt.getROI().area() >= 20000000)
+        {
+            label.Append(wxString::Format(wxT("=%.0f MP"), opt.getROI().area() / 1000000.0));
+        }
+        else
+        {
+            label.Append(wxString::Format(wxT("=%.1f MP"), opt.getROI().area() / 1000000.0));
+        };
+        if (opt.getROI().area() > 0)
+        {
+            float ratio = 1.0f*opt.getROI().width() / opt.getROI().height();
+            if (ratio > 1.0f)
+            {
+                bool handled = false;
+                for (unsigned int i = 1; i < 10; ++i)
+                {
+                    if (fabs(i*ratio - hugin_utils::roundi(i*ratio)) < 1e-2)
+                    {
+                        label.Append(wxString::Format(wxT(", %d:%d"), hugin_utils::roundi(i*ratio), i));
+                        handled = true;
+                        break;
+                    }
+                };
+                if (!handled)
+                {
+                    label.Append(wxString::Format(wxT(", %.2f:1"), ratio));
+                };
+            }
+            else
+            {
+                ratio = 1.0f / ratio;
+                bool handled = false;
+                for (unsigned int i = 1; i < 10; ++i)
+                {
+                    if (fabs(i*ratio - hugin_utils::roundi(i*ratio)) < 1e-2)
+                    {
+                        label.Append(wxString::Format(wxT(", %d:%d"), i, hugin_utils::roundi(i*ratio)));
+                        handled = true;
+                        break;
+                    }
+                };
+                if (!handled)
+                {
+                    label.Append(wxString::Format(wxT(", 1:%.2f"), ratio));
+                };
+            };
+        };
+        XRCCTRL(*this, "pano_size_label", wxStaticText)->SetLabel(label);
+    };
 
     // output types
     XRCCTRL(*this, "pano_cb_ldr_output_blended", wxCheckBox)->SetValue(opt.outputLDRBlended);
@@ -525,7 +577,7 @@ void PanoPanel::UpdateDisplay(const HuginBase::PanoramaOptions & opt, const bool
         m_FileFormatOptionsLabel->SetLabel(_("Quality:"));
         m_FileFormatJPEGQualityText->Show();
         m_FileFormatTIFFCompChoice->Hide();
-        m_FileFormatJPEGQualityText->SetValue(wxString::Format(wxT("%d"), opt.quality));
+        m_FileFormatJPEGQualityText->ChangeValue(wxString::Format(wxT("%d"), opt.quality));
     } else if (opt.outputImageType == "png") {
         m_FileFormatOptionsLabel->Hide();
         m_FileFormatJPEGQualityText->Hide();
@@ -835,7 +887,8 @@ void PanoPanel::OnBlenderOptions(wxCommandEvent & e)
         wxDialog dlg;
         wxXmlResource::Get()->LoadDialog(&dlg, this, wxT("enblend_options_dialog"));
         wxTextCtrl * enblend_opts_text = XRCCTRL(dlg, "blender_arguments_text", wxTextCtrl);
-        enblend_opts_text->SetValue(wxString(opt.enblendOptions.c_str(), wxConvLocal));
+        enblend_opts_text->ChangeValue(wxString(opt.enblendOptions.c_str(), wxConvLocal));
+        dlg.Bind(wxEVT_COMMAND_BUTTON_CLICKED, [](wxCommandEvent &) {MainFrame::Get()->DisplayHelp(wxT("Enblend.html")); }, wxID_HELP);
         dlg.CentreOnParent();
 
         if (dlg.ShowModal() == wxID_OK) {
@@ -900,7 +953,8 @@ void PanoPanel::OnFusionOptions(wxCommandEvent & e)
     wxDialog dlg;
     wxXmlResource::Get()->LoadDialog(&dlg, this, wxT("enfuse_options_dialog"));
     wxTextCtrl * enfuse_opts_text = XRCCTRL(dlg, "enfuse_arguments_text", wxTextCtrl);
-    enfuse_opts_text->SetValue(wxString(opt.enfuseOptions.c_str(), wxConvLocal));
+    enfuse_opts_text->ChangeValue(wxString(opt.enfuseOptions.c_str(), wxConvLocal));
+    dlg.Bind(wxEVT_COMMAND_BUTTON_CLICKED, [](wxCommandEvent &) {MainFrame::Get()->DisplayHelp(wxT("Enfuse.html")); }, wxID_HELP);
     dlg.CentreOnParent();
 
     if (dlg.ShowModal() == wxID_OK) {
@@ -972,11 +1026,7 @@ void PanoPanel::DoCalcOptimalWidth(wxCommandEvent & e)
 
     HuginBase::PanoramaOptions opt = pano->getOptions();
     double sizeFactor = 1.0;
-#if wxCHECK_VERSION(2,9,4)
     if (wxGetKeyState(WXK_COMMAND))
-#else
-    if (wxGetKeyState(WXK_CONTROL))
-#endif
     {
         wxConfigBase::Get()->Read(wxT("/Assistant/panoDownsizeFactor"), &sizeFactor, HUGIN_ASS_PANO_DOWNSIZE_FACTOR);
     };
@@ -1187,7 +1237,7 @@ void PanoPanel::DoSendToBatch()
         if(showDlg)
         {
             wxDialog dlg;
-            wxXmlResource::Get()->LoadDialog(&dlg, NULL, wxT("stitch_message_dlg"));
+            wxXmlResource::Get()->LoadDialog(&dlg, this, wxT("stitch_message_dlg"));
             if(dlg.ShowModal())
             {
                 if(XRCCTRL(dlg, "stitch_dont_show_checkbox", wxCheckBox)->IsChecked())
@@ -1275,7 +1325,7 @@ void PanoPanel::DoSendToBatch()
     }
 };
 
-void PanoPanel::DoUserDefinedStitch()
+void PanoPanel::DoUserDefinedStitch(const wxString& settings)
 {
     if (pano->getNrOfImages() == 0)
     {
@@ -1292,19 +1342,35 @@ void PanoPanel::DoUserDefinedStitch()
         // output ROI contains no images
         return;
     };
-    // create a copy, if we need to update the crop setting
-    wxConfigBase* config = wxConfigBase::Get();
-    wxString path = config->Read(wxT("/userDefinedOutputPath"), MainFrame::Get()->GetDataPath());
-    wxFileDialog userOutputDlg(this, _("Select user defined output"),
-        path, wxT(""), _("User defined output|*.executor"),
-        wxFD_OPEN | wxFD_MULTIPLE | wxFD_FILE_MUST_EXIST, wxDefaultPosition);
-    if (userOutputDlg.ShowModal() != wxID_OK)
+    wxFileName userOutputSequence;
+    if (settings.IsEmpty())
     {
-        return;
+        // no filename given, ask user
+        wxConfigBase* config = wxConfigBase::Get();
+        wxString path = config->Read(wxT("/userDefinedOutputPath"), MainFrame::Get()->GetDataPath());
+        wxFileDialog userOutputDlg(this, _("Select user defined output"),
+            path, wxT(""), _("User defined output|*.executor"),
+            wxFD_OPEN | wxFD_MULTIPLE | wxFD_FILE_MUST_EXIST, wxDefaultPosition);
+        if (userOutputDlg.ShowModal() != wxID_OK)
+        {
+            return;
+        };
+        // remember path for later
+        config->Write(wxT("/userDefinedOutputPath"), userOutputDlg.GetDirectory());
+        userOutputSequence = userOutputDlg.GetPath();
+    }
+    else
+    {
+        //filename given, check existance
+        userOutputSequence = settings;
+        if (!userOutputSequence.Exists())
+        {
+            wxMessageBox(wxString::Format(wxT("User defined output %s not found.\nStopping processing."), userOutputSequence.GetFullPath()), _("Warning"), wxOK | wxICON_INFORMATION);
+            return;
+        };
     };
-    // remember path for later
-    config->Write(wxT("/userDefinedOutputPath"), userOutputDlg.GetDirectory());
 
+    // create a copy, if we need to update the crop setting
     // save project
     // copy pto file to temporary file
     wxString tempDir = wxConfigBase::Get()->Read(wxT("tempDir"), wxT(""));
@@ -1398,7 +1464,7 @@ void PanoPanel::DoUserDefinedStitch()
         return;
     };
 
-    wxString switches(wxT(" --user-defined-output=") + hugin_utils::wxQuoteFilename(userOutputDlg.GetPath()) + wxT(" --delete -o "));
+    wxString switches(wxT(" --user-defined-output=") + hugin_utils::wxQuoteFilename(userOutputSequence.GetFullPath()) + wxT(" --delete -o "));
     if (wxConfigBase::Get()->Read(wxT("/Processor/overwrite"), HUGIN_PROCESSOR_OVERWRITE) == 1)
         switches = wxT(" --overwrite") + switches;
     wxString command = hugin_stitch_project + switches + hugin_utils::wxQuoteFilename(dlg.GetPath()) + wxT(" ") + hugin_utils::wxQuoteFilename(currentPTOfn);
@@ -1422,11 +1488,7 @@ void PanoPanel::DoUserDefinedStitch()
 void PanoPanel::OnDoStitch ( wxCommandEvent & e )
 {
     long t;
-#if wxCHECK_VERSION(2,9,4)
     if(wxGetKeyState(WXK_COMMAND))
-#else
-    if(wxGetKeyState(WXK_CONTROL))
-#endif
     {
         t=1;
     }
@@ -1636,7 +1698,6 @@ bool PanoPanel::CheckGoodSize()
     {
         // Tell the user the stitch will be really big, and give them a
         // chance to reduce the size.
-#if wxCHECK_VERSION(2,9,0)
         wxMessageDialog dialog(this,
                 _("Are you sure you want to stitch such a large panorama?"),
 #ifdef _WIN32
@@ -1647,31 +1708,6 @@ bool PanoPanel::CheckGoodSize()
                 wxICON_EXCLAMATION | wxYES_NO);
         dialog.SetExtendedMessage(message);
         dialog.SetYesNoLabels(_("Stitch anyway"), _("Let me fix that"));
-#else // replacement for old wxWidgets versions.
-        // wxMessageDialog derives from wxDialog, but I don't understand
-        // why because on most platforms wxMessageDialog uses the native
-        // message box, and trying to make descriptive buttons through
-        // wxDialog::CreateStdButtonSizer causes a crash on wxGTK.
-        // Descriptive buttons are recommended by the Windows, Gnome, KDE,
-        // and Apple user interface guidelines.
-        // Due to this wxWidgets WTF, the buttons will are labeled Yes and
-        // No on wxWidgets 2.8 and earlier. This makes it a little
-        // confusing, and it is more likely someone will just click yes
-        // without reading the message and then wonder why their computer
-        // has ground to a halt.
-        /** @todo (Possibly) make a dialog manually with properly labelled
-         * buttons.
-         */
-        message.Prepend(wxT("\n\n"));
-        message=_("Are you sure you want to stitch such a large panorama?")+message;
-        wxMessageDialog dialog(this, message,
-#ifdef _WIN32
-                _("Hugin"),
-#else
-                wxT(""),
-#endif
-                wxICON_EXCLAMATION | wxYES_NO);
-#endif
         switch (dialog.ShowModal())
         {
             case wxID_OK:
@@ -1718,9 +1754,8 @@ bool PanoPanel::CheckFreeSpace(const wxString& folder)
         // 4 channels, 16 bit per channel, assuming the we need the 10 fold space for all temporary space
         if (pano->getOptions().getROI().area() * 80 > freeSpace)
         {
-#if wxCHECK_VERSION(2,9,0)
             wxMessageDialog dialog(this,
-                wxString::Format(_("The folder \"%s\" has only %.1f MiB free. This is not enough for stitching the current panorama. Decrease the output size or select another output folder.\nAre you sure that you still want to stitch it?"), folder.c_str(), freeSpace / 1048576.0f),
+                wxString::Format(_("The folder \"%s\" has only %.1f MiB free. This is not enough for stitching the current panorama. Decrease the output size or select another output folder.\nAre you sure that you still want to stitch it?"), folder.c_str(), freeSpace.ToDouble() / 1048576.0),
 #ifdef _WIN32
                 _("Hugin"),
 #else
@@ -1728,16 +1763,6 @@ bool PanoPanel::CheckFreeSpace(const wxString& folder)
 #endif
                 wxICON_EXCLAMATION | wxYES_NO);
             dialog.SetYesNoLabels(_("Stitch anyway"), _("Let me fix that"));
-#else // replacement for old wxWidgets versions.
-            wxMessageDialog dialog(this,
-                wxString::Format(_("The folder \"%s\" has only %.1f MiB free. This is not enough for stitching the current panorama. Decrease the output size or select another output folder.\nAre you sure that you still want to stitch it?"), folder.c_str(), freeSpace / 1048576.0f),
-#ifdef _WIN32
-                _("Hugin"),
-#else
-                wxT(""),
-#endif
-                wxICON_EXCLAMATION | wxYES_NO);
-#endif
             if (dialog.ShowModal() == wxID_NO)
             {
                 // bring the user towards the approptiate controls.
