@@ -29,7 +29,6 @@
 #include "hugin/MainFrame.h"
 #include "GuiLevel.h"
 
-//using namespace PT;
 class PanoDialog;
 class wxSpinCtrl;
 class wxTextCtrl;
@@ -72,15 +71,12 @@ public:
     virtual void panoramaChanged(HuginBase::Panorama &pano);
     virtual void panoramaImagesChanged(HuginBase::Panorama &pano, const HuginBase::UIntSet & imgNr) {};
 
-    /** set the image */
-// TODO remove
-//    void previewSingleChanged(wxCommandEvent & e);
-
-
     /** stitching using hugin_stitch_project */
     void DoStitch();
     /** stitching with PTBatcherGUI */
     void DoSendToBatch();
+    /** stitching with user defined file */
+    void DoUserDefinedStitch(const wxString& settings = wxString());
 
     void SetGuiLevel(GuiLevel newGuiLevel);
 
