@@ -24,8 +24,7 @@
  *
  */
 
-#include <config.h>
-
+#include "hugin_config.h"
 #include "panoinc_WX.h"
 #include "panoinc.h"
 
@@ -301,7 +300,7 @@ void PreviewPanel::updatePreview()
                 double min = std::max(minmax.min, 1e-6f);
                 double max = minmax.max;
 
-                int mapping = wxConfigBase::Get()->Read(wxT("/ImageCache/MappingFloat"), HUGIN_IMGCACHE_MAPPING_FLOAT);
+                int mapping = wxConfigBase::Get()->Read(wxT("/ImageCache/Mapping"), HUGIN_IMGCACHE_MAPPING_FLOAT);
                 vigra_ext::applyMapping(vigra::srcImageRange(panoImg), vigra::destImage(panoImg8), min, max, mapping);
 
             } else {
@@ -401,7 +400,13 @@ void PreviewPanel::updatePreview()
     } catch (std::exception & e) {
         m_state_rendering = false;
         DEBUG_ERROR("error during stitching: " << e.what());
-        wxMessageBox(wxString(e.what(), wxConvLocal), _("Error during Stitching"));
+        wxMessageBox(wxString::Format(_("Could not stitch preview.\nError: %s\nOne cause could be an invalid or missing image file."), wxString(e.what(), wxConvLocal)),
+#ifdef __WXMSW__
+            wxT("Hugin"),
+#else
+            wxT(""),
+#endif
+            wxOK | wxICON_INFORMATION);
     }
 
 
@@ -448,13 +453,8 @@ void PreviewPanel::DrawPreview(wxDC & dc)
         offsetY = (sz.GetHeight() - m_panoImgSize.y) / 2;
     }
 
-#if wxCHECK_VERSION(3,0,0)
     dc.SetPen(wxPen(GetBackgroundColour(), 1, wxPENSTYLE_SOLID));
     dc.SetBrush(wxBrush(GetBackgroundColour(), wxBRUSHSTYLE_SOLID));
-#else
-    dc.SetPen(wxPen(GetBackgroundColour(), 1, wxSOLID));
-    dc.SetBrush(wxBrush(GetBackgroundColour(),wxSOLID));
-#endif
     dc.DrawRectangle(0, 0, offsetX, sz.GetHeight());
     dc.DrawRectangle(offsetX, 0, sz.GetWidth(), offsetY);
     dc.DrawRectangle(offsetX, sz.GetHeight() - offsetY,
@@ -467,13 +467,8 @@ void PreviewPanel::DrawPreview(wxDC & dc)
     dc.SetClippingRegion(offsetX, offsetY,
                          m_panoImgSize.x, m_panoImgSize.y);
 
-#if wxCHECK_VERSION(3,0,0)
     dc.SetPen(wxPen(wxT("BLACK"), 1, wxPENSTYLE_SOLID));
     dc.SetBrush(wxBrush(wxT("BLACK"), wxBRUSHSTYLE_SOLID));
-#else
-    dc.SetPen(wxPen(wxT("BLACK"), 1, wxSOLID));
-    dc.SetBrush(wxBrush(wxT("BLACK"),wxSOLID));
-#endif
     dc.DrawRectangle(offsetX, offsetY, m_panoImgSize.x, m_panoImgSize.y);
 
 
@@ -548,11 +543,7 @@ void PreviewPanel::DrawPreview(wxDC & dc)
                          m_panoImgSize.x, m_panoImgSize.y);
 
             // draw boundaries
-#if wxCHECK_VERSION(3,0,0)
             dc.SetPen(wxPen(wxT("WHITE"), 1, wxPENSTYLE_SOLID));
-#else
-            dc.SetPen(wxPen(wxT("WHITE"), 1, wxSOLID));
-#endif
             dc.SetLogicalFunction(wxINVERT);
 
             DEBUG_DEBUG("ROI scale factor: " << scale << " screen ROI: " << screenROI);
@@ -575,11 +566,7 @@ void PreviewPanel::DrawPreview(wxDC & dc)
                     m_panoImgSize.x, m_panoImgSize.y);
 
     // draw center lines over display
-#if wxCHECK_VERSION(3,0,0)
     dc.SetPen(wxPen(wxT("WHITE"), 1, wxPENSTYLE_SOLID));
-#else
-    dc.SetPen(wxPen(wxT("WHITE"), 1, wxSOLID));
-#endif
     dc.SetLogicalFunction(wxINVERT);
     dc.DrawLine(offsetX + w/2, offsetY,
                 offsetX + w/2, offsetY + h);
