@@ -24,7 +24,7 @@
  *
  */
 
-#include <config.h>
+#include "hugin_config.h"
 #include "panoinc_WX.h"
 #include "panoinc.h"
 #include "hugin/TextKillFocusHandler.h"
