@@ -23,7 +23,7 @@
 #include <math.h>
 #include <iostream>
 
-#include <config.h>
+#include "hugin_config.h"
 
 #ifdef __APPLE__
 #include "panoinc.h"
@@ -755,10 +755,19 @@ void TextureManager::TextureInfo::DefineLevels(int min,
         }
         if (hasPreview)
         {
-            image->readMetadata();
-            // read all thumbnails
-            Exiv2::PreviewManager previews(*image);
-            Exiv2::PreviewPropertiesList lists = previews.getPreviewProperties();
+            std::shared_ptr<Exiv2::PreviewManager> previews;
+            Exiv2::PreviewPropertiesList lists;
+            try
+            {
+                // read all thumbnails
+                image->readMetadata();
+                previews = std::make_shared<Exiv2::PreviewManager>(*image);
+                lists = previews->getPreviewProperties();
+            }
+            catch (const Exiv2::Error&)
+            {
+                hasPreview = false;
+            };
             if (lists.empty())
             {
                 // no preview found
@@ -774,7 +783,7 @@ void TextureManager::TextureInfo::DefineLevels(int min,
                 };
                 // load preview image to wxImage
                 wxImage rawImage;
-                Exiv2::PreviewImage previewImage = previews.getPreviewImage(lists[previewIndex]);
+                Exiv2::PreviewImage previewImage = previews->getPreviewImage(lists[previewIndex]);
                 wxMemoryInputStream stream(previewImage.pData(), previewImage.size());
                 rawImage.LoadFile(stream, wxString(previewImage.mimeType().c_str(), wxConvLocal), -1);
                 placeholderWidth = rawImage.GetWidth();
@@ -1012,7 +1021,7 @@ void TextureManager::TextureInfo::DefineLevels(int min,
     error = glGetError();
     if (error != GL_NO_ERROR)
     {
-        DEBUG_ERROR("GL Error when bulding mipmap levels: "
+        DEBUG_ERROR("GL Error when building mipmap levels: "
                   << gluErrorString(error) << ".");
     }
     SetParameters();
