@@ -75,11 +75,9 @@ void ToolHelper::MouseMoved(int x, int y, wxMouseEvent & e)
     mouse_screen_x = x;
     mouse_screen_y = y;
     // now tell tools that want notification.
-    std::set<Tool *>::iterator iterator;
-    for (iterator = mouse_move_notified_tools.begin();
-         iterator != mouse_move_notified_tools.end(); ++iterator)
+    for (auto& tool : mouse_move_notified_tools)
     {
-        (*iterator)->MouseMoveEvent(mouse_screen_x, mouse_screen_y, e);
+        tool->MouseMoveEvent(mouse_screen_x, mouse_screen_y, e);
     }
     // If the mouse has moved, then we don't know what is underneath it anoymore
     InvalidateImagesUnderMouse();
@@ -98,12 +96,9 @@ void ToolHelper::InvalidateImagesUnderMouse()
         if (old_images_under_mouse != images_under_mouse)
         {
             // The list has changed. Notifiy all tools that requested it.
-            std::set<Tool *>::iterator iterator;
-            for (iterator = images_under_mouse_notified_tools.begin();
-                 iterator != images_under_mouse_notified_tools.end();
-                 ++iterator)
+            for (auto& tool : images_under_mouse_notified_tools)
             {
-                (*iterator)->ImagesUnderMouseChangedEvent();
+                tool->ImagesUnderMouseChangedEvent();
             }
         }
     }
@@ -111,55 +106,35 @@ void ToolHelper::InvalidateImagesUnderMouse()
 
 void ToolHelper::MouseButtonEvent(wxMouseEvent &e)
 {
-//    // if there is a tool monitoring mouse button presses, notify it
-//    if (mouse_button_notified_tool)
-//    {
-//        mouse_button_notified_tool->MouseButtonEvent(e);
-//    }
-    std::set<Tool *>::iterator iterator;
-    for (iterator = mouse_button_notified_tools.begin();
-         iterator != mouse_button_notified_tools.end(); ++iterator)
+    for (auto& tool : mouse_button_notified_tools)
     {
-        (*iterator)->MouseButtonEvent(e);
+        tool->MouseButtonEvent(e);
     }
-
 }
 
 void ToolHelper::MouseWheelEvent(wxMouseEvent &e)
 {
-    std::set<Tool *>::iterator iterator;
-    for (iterator = mouse_wheel_notified_tools.begin();
-         iterator != mouse_wheel_notified_tools.end(); ++iterator)
+    for (auto& tool : mouse_wheel_notified_tools)
     {
-        (*iterator)->MouseWheelEvent(e);
+        tool->MouseWheelEvent(e);
     }
-
 }
 
 
 void ToolHelper::KeypressEvent(int keycode, int modifiers, bool pressed)
 {
-//    if (keypress_notified_tool)
-//    {
-//        keypress_notified_tool->KeypressEvent(keycode, modifiers, pressed);
-//    }
-    std::set<Tool *>::iterator iterator;
-    for (iterator = keypress_notified_tools.begin();
-         iterator != keypress_notified_tools.end(); ++iterator)
+    for (auto& tool : keypress_notified_tools)
     {
-        (*iterator)->KeypressEvent(keycode, modifiers, pressed);
+        tool->KeypressEvent(keycode, modifiers, pressed);
     }
-
 }
 
 void ToolHelper::BeforeDrawImages()
 {
     // let all tools that want to draw under the images do so.
-    std::set<Tool *>::iterator iterator;
-    for (iterator = draw_under_notified_tools.begin();
-         iterator != draw_under_notified_tools.end(); ++iterator)
+    for (auto& tool : draw_under_notified_tools)
     {
-        (*iterator)->BeforeDrawImagesEvent();
+        tool->BeforeDrawImagesEvent();
     }
     // Since we are drawing a new frame, lets assume something has changed,
     // however we want to keep with no images under the mouse if the mouse is
@@ -172,38 +147,43 @@ void ToolHelper::BeforeDrawImages()
 
 void ToolHelper::AfterDrawImages()
 {
-//    std::cerr << "begin" << std::endl;
     // let all tools that want to draw on top of the images do so.
-    std::set<Tool *>::iterator iterator;
-    for (iterator = draw_over_notified_tools.begin();
-         iterator != draw_over_notified_tools.end(); ++iterator)
+    for (auto& tool : draw_over_notified_tools)
     {
-//        std::cerr << "tool after draw" << std::endl;
-        (*iterator)->AfterDrawImagesEvent();
+        tool->AfterDrawImagesEvent();
     }
-//    std::cerr << "after draw images" << std::endl;
     // The overlays are done separetly to avoid errors with blending order.
-    for (iterator = really_draw_over_notified_tools.begin();
-         iterator != really_draw_over_notified_tools.end(); ++iterator)
+    for (auto& tool : really_draw_over_notified_tools)
     {
-        (*iterator)->ReallyAfterDrawImagesEvent();
+        tool->ReallyAfterDrawImagesEvent();
+    }
+}
+
+void ToolHelper::MarkDirty()
+{
+    // let all tools that want to draw on top of the images do so.
+    for (auto& tool : m_tools_need_dirty_flag)
+    {
+        tool->MarkDirty();
     }
-//    std::cerr << "really after draw images" << std::endl;
 }
 
 bool ToolHelper::BeforeDrawImageNumber(unsigned int image)
 {
     if (image_draw_begin_tools.size() > image)
     {
-        if (image_draw_begin_tools[image].size() > 0)
+        if (!image_draw_begin_tools[image].empty())
         {
             bool result = true;
-            std::set<Tool *>::iterator it;
-            for(it = image_draw_begin_tools[image].begin() ; it != image_draw_begin_tools[image].end() ; ++it) {
-                result &= (*it)->BeforeDrawImageEvent(image);
-            }
+            // BeforeDrawImageEvent can change image_draw_begin_tools[image]
+            // so we create a copy before to process all dependent tools, also 
+            // when the set is modified in the BeforeDrawImageEvent function
+            const auto tools = image_draw_begin_tools[image];
+            for (auto tool : tools)
+            {
+                result &= tool->BeforeDrawImageEvent(image);
+            };
             return result;
-//            return image_draw_begin_tools[image]->BeforeDrawImageEvent(image);
         }
     }
     return true;
@@ -213,13 +193,13 @@ void ToolHelper::AfterDrawImageNumber(unsigned int image)
 {
     if (image_draw_end_tools.size() > image)
     {
-        if (image_draw_end_tools[image].size() > 0)
+        if (!image_draw_end_tools[image].empty())
         {
-            std::set<Tool *>::iterator it;
-            for(it = image_draw_end_tools[image].begin() ; it != image_draw_end_tools[image].end() ; ++it) {
-                (*it)->BeforeDrawImageEvent(image);
+            const auto tools = image_draw_end_tools[image];
+            for (auto tool : tools)
+            {
+                tool->BeforeDrawImageEvent(image);
             }
-//            image_draw_end_tools[image]->AfterDrawImageEvent(image);
         }
     }
 }
@@ -249,12 +229,9 @@ void ToolHelper::MouseLeave()
     if (!images_under_mouse_notified_tools.empty())
     {
         // notify tools that the set has changed.
-        std::set<Tool *>::iterator iterator;
-        for (iterator = images_under_mouse_notified_tools.begin();
-             iterator != images_under_mouse_notified_tools.end();
-             ++iterator)
+        for (auto& tool : images_under_mouse_notified_tools)
         {
-            (*iterator)->ImagesUnderMouseChangedEvent();
+            tool->ImagesUnderMouseChangedEvent();
         }        
     }
 }
@@ -322,6 +299,9 @@ void ToolHelper::NotifyMe(Event event, Tool *tool)
         case REALLY_DRAW_OVER_IMAGES:
             AddTool(tool, &really_draw_over_notified_tools);
             break;
+        case MARK_DIRTY:
+            AddTool(tool, &m_tools_need_dirty_flag);
+            break;
     }   
 }
 
@@ -364,6 +344,12 @@ void ToolHelper::DoNotNotifyMe(Event event, Tool *tool)
         case IMAGES_UNDER_MOUSE_CHANGE:
             RemoveTool(tool, &images_under_mouse_notified_tools);
             break;
+        case REALLY_DRAW_OVER_IMAGES:
+            RemoveTool(tool, &really_draw_over_notified_tools);
+            break;
+        case MARK_DIRTY:
+            RemoveTool(tool, &m_tools_need_dirty_flag);
+            break;
     }   
 }
 
@@ -401,10 +387,10 @@ void ToolHelper::RemoveTool(Tool *tool, Tool **single)
 void ToolHelper::RemoveTool(Tool *tool,
                                    std::set<Tool *> *set)
 {
-    std::set<Tool *>::iterator iterator = set->find(tool);
-    if (iterator != set->end())
+    auto foundTool = set->find(tool);
+    if (foundTool != set->end())
     {
-        set->erase(iterator);
+        set->erase(foundTool);
     }
 }
 
@@ -415,10 +401,6 @@ void ToolHelper::RemoveTool(Tool *tool,
     for (unsigned int image = 0; image < vector->size(); image++)
     {
         (*vector)[image].erase(tool);
-//        if ((*vector)[image] == tool)
-//        {
-//            (*vector)[image] = 0;
-//        }
     }
 }
 
@@ -426,13 +408,9 @@ void ToolHelper::RemoveTool(Tool *tool,
                                   std::vector<std::set<Tool *> > *vector,
                                   unsigned int index)
 {
-    if ((*vector).size() > index)
+    if (vector->size() > index)
     {
         (*vector)[index].erase(tool);
-//        if ((*vector)[index] == tool)
-//        {
-//            (*vector)[index] = 0;
-//        }
     }
 }
 
@@ -480,11 +458,9 @@ void PreviewToolHelper::MouseMoved(int x, int y, wxMouseEvent &e)
     mouse_pano_x = (double) x / visualization_state->GetScale() + (double) visible.left();
     mouse_pano_y = (double) y / visualization_state->GetScale() + (double) visible.top();
     // now tell tools that want notification.
-    std::set<Tool *>::iterator iterator;
-    for (iterator = mouse_move_notified_tools.begin();
-         iterator != mouse_move_notified_tools.end(); ++iterator)
+    for (auto& tool : mouse_move_notified_tools)
     {
-        (*iterator)->MouseMoveEvent(mouse_pano_x, mouse_pano_y, e);
+        tool->MouseMoveEvent(mouse_pano_x, mouse_pano_y, e);
     }
     // If the mouse has moved, then we don't know what is underneath it anoymore
     InvalidateImagesUnderMouse();
@@ -552,7 +528,7 @@ void PanosphereOverviewToolHelper::UpdateImagesUnderMouse()
 
 void PanosphereOverviewToolHelper::MouseMoved(int x, int y, wxMouseEvent & e)
 {
-    PanosphereOverviewVisualizationState * panostate = (PanosphereOverviewVisualizationState*) visualization_state;
+    PanosphereOverviewVisualizationState * panostate = static_cast<PanosphereOverviewVisualizationState*>(visualization_state);
 
     double d = panostate->getR();
     double r = panostate->getSphereRadius();
@@ -694,41 +670,33 @@ void PanosphereOverviewToolHelper::DoNotNotifyMe(PanosphereOverviewEvent event,
 
 void PanosphereOverviewToolHelper::BeforeDrawImagesBack()
 {
-    std::set<Tool *>::iterator iterator;
-    for (iterator = draw_under_notified_tools_back.begin();
-         iterator != draw_under_notified_tools_back.end(); ++iterator)
+    for (auto& tool : draw_under_notified_tools_back)
     {
-        ((PanosphereOverviewTool*)(*iterator))->BeforeDrawImagesBackEvent();
+        static_cast<PanosphereOverviewTool*>(tool)->BeforeDrawImagesBackEvent();
     }
 }
 
 void PanosphereOverviewToolHelper::BeforeDrawImagesFront()
 {
-    std::set<Tool *>::iterator iterator;
-    for (iterator = draw_under_notified_tools_front.begin();
-         iterator != draw_under_notified_tools_front.end(); ++iterator)
+    for (auto& tool : draw_under_notified_tools_front)
     {
-        ((PanosphereOverviewTool*)(*iterator))->BeforeDrawImagesFrontEvent();
+        static_cast<PanosphereOverviewTool*>(tool)->BeforeDrawImagesFrontEvent();
     }
 }
 
 void PanosphereOverviewToolHelper::AfterDrawImagesBack()
 {
-    std::set<Tool *>::iterator iterator;
-    for (iterator = draw_over_notified_tools_back.begin();
-         iterator != draw_over_notified_tools_back.end(); ++iterator)
+    for (auto& tool : draw_over_notified_tools_back)
     {
-        ((PanosphereOverviewTool*)(*iterator))->AfterDrawImagesBackEvent();
+        static_cast<PanosphereOverviewTool*>(tool)->AfterDrawImagesBackEvent();
     }
 }
 
 void PanosphereOverviewToolHelper::AfterDrawImagesFront()
 {
-    std::set<Tool *>::iterator iterator;
-    for (iterator = draw_over_notified_tools_front.begin();
-         iterator != draw_over_notified_tools_front.end(); ++iterator)
+    for (auto& tool : draw_over_notified_tools_front)
     {
-        ((PanosphereOverviewTool*)(*iterator))->AfterDrawImagesFrontEvent();
+        static_cast<PanosphereOverviewTool*>(tool)->AfterDrawImagesFrontEvent();
     }
 }
 
@@ -752,7 +720,7 @@ PlaneOverviewToolHelper::~PlaneOverviewToolHelper() {}
 void PlaneOverviewToolHelper::MouseMoved(int x, int y, wxMouseEvent & e)
 {
 
-    PlaneOverviewVisualizationState * panostate = (PlaneOverviewVisualizationState*) visualization_state;
+    PlaneOverviewVisualizationState * panostate = static_cast<PlaneOverviewVisualizationState*>(visualization_state);
 
     double d = panostate->getR();
 
