@@ -63,7 +63,7 @@
 #ifndef __VIEWSTATE_H
 #define __VIEWSTATE_H
 
-#include "hugin_utils/utils.h"
+#include "base_wx/wxutils.h"
 #include <panodata/PanoramaData.h>
 #include <panodata/Panorama.h>
 #include "OutputProjectionInfo.h"
@@ -263,7 +263,10 @@ protected:
     ViewState *m_view_state;
 
     GLViewer * m_viewer;
-
+private:
+    // don't copy this class
+    VisualizationState(const VisualizationState& other);
+    VisualizationState& operator=(const VisualizationState& other);
 };
 
 class OverviewVisualizationState : public VisualizationState
