@@ -24,7 +24,7 @@
  *
  */
 
-#include <config.h>
+#include "hugin_config.h"
 
 #include "panoinc_WX.h"
 
@@ -56,17 +56,14 @@
 
 #include "base_wx/platform.h"
 #include "base_wx/huginConfig.h"
+#include <wx/cshelp.h>
 #ifdef __WXMSW__
 #include <wx/dir.h>
-#include <wx/cshelp.h>
 #include <wx/stdpaths.h>
 #if wxCHECK_VERSION(3,1,0)
 #include <wx/taskbarbutton.h>
 #endif
 #endif
-#ifdef __WXGTK3__
-#include <wx/platinfo.h>
-#endif
 
 #include <tiffio.h>
 
@@ -135,7 +132,24 @@ BEGIN_EVENT_TABLE(huginApp, wxApp)
 END_EVENT_TABLE()
 
 // make wxwindows use this class as the main application
-IMPLEMENT_APP(huginApp)
+#if defined USE_GDKBACKEND_X11
+// wxWidgets does not support wxGLCanvas on Wayland
+// so until it is fixed upstream enforce using x11 backend
+// see ticket http://trac.wxwidgets.org/ticket/17702
+#warning Using Hugin with hard coded GDK_BACKEND=x11
+wxIMPLEMENT_WX_THEME_SUPPORT
+wxIMPLEMENT_APP_NO_MAIN(huginApp);
+#include <stdlib.h>
+int main(int argc, char **argv)
+{   
+    wxDISABLE_DEBUG_SUPPORT();
+    char backend[]="GDK_BACKEND=x11";
+    putenv(backend);
+    return wxEntry(argc, argv);
+};
+#else
+wxIMPLEMENT_APP(huginApp);
+#endif
 
 huginApp::huginApp()
 {
@@ -186,12 +200,11 @@ bool huginApp::OnInit()
     // required by wxHtmlHelpController
     wxFileSystem::AddHandler(new wxZipFSHandler);
 
-
-#if defined __WXMSW__
     // initialize help provider
     wxHelpControllerHelpProvider* provider = new wxHelpControllerHelpProvider;
     wxHelpProvider::Set(provider);
 
+#if defined __WXMSW__
     wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
     m_utilsBinDir = exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
     exePath.RemoveLastDir();
@@ -251,10 +264,9 @@ bool huginApp::OnInit()
 
     config->Flush();
 
+    // need to explicitly initialize locale for C++ library/runtime
+    setlocale(LC_ALL, "");
     // initialize i18n
-#if defined _MSC_VER && defined Hugin_shared
-    setlocale(LC_NUMERIC, "");
-#endif
     int localeID = config->Read(wxT("language"), (long) HUGIN_LANGUAGE);
     DEBUG_TRACE("localeID: " << localeID);
     {
@@ -296,11 +308,7 @@ bool huginApp::OnInit()
     wxXmlResource::Get()->AddHandler(new PanoPanelXmlHandler());
     wxXmlResource::Get()->AddHandler(new PreviewPanelXmlHandler());
     wxXmlResource::Get()->AddHandler(new HtmlWindowXmlHandler());
-#if wxCHECK_VERSION(2,9,0)
     wxXmlResource::Get()->AddHandler(new wxcode::wxTreeListCtrlXmlHandler());
-#else
-    wxXmlResource::Get()->AddHandler(new wxTreeListCtrlXmlHandler());
-#endif
     wxXmlResource::Get()->AddHandler(new ImagesTreeCtrlXmlHandler());
     wxXmlResource::Get()->AddHandler(new CPListCtrlXmlHandler());
 
@@ -339,31 +347,8 @@ bool huginApp::OnInit()
     SetTopWindow(frame);
 
     // setup main frame size, after it has been created.
-#ifdef __WXGTK3__
-    if(wxPlatformInfo::Get().CheckToolkitVersion(3,20))
-    {
-        // workaround for wxWidgets bug http://trac.wxwidgets.org/ticket/17585
-        // with GTK3+ 3.20 the initial position/size of the sizer is not
-        // correctly calculated, if works when manually resizing the window
-        // so we need manually call the resizing function, but the sizes are
-        // only refreshed when before outstanding calculations are done in
-        // wxYield()
-        wxYield();
-        RestoreFramePosition(frame, wxT("MainFrame"));
-        wxYield();
-        frame->PostSizeEvent();
-        wxYield();
-    }
-    else
-    {
-        RestoreFramePosition(frame, wxT("MainFrame"));
-    }
-#else
     RestoreFramePosition(frame, wxT("MainFrame"));
-#endif
 #ifdef __WXMSW__
-    provider->SetHelpController(&frame->GetHelpController());
-    frame->GetHelpController().Initialize(m_xrcPrefix+wxT("data/hugin_help_en_EN.chm"));
     frame->SendSizeEvent();
 #if wxCHECK_VERSION(3,1,0)
     wxTaskBarJumpList jumpList;
@@ -381,6 +366,34 @@ bool huginApp::OnInit()
         exeFile.GetFullPath(), 0);
     jumpList.GetTasks().Append(item2);
 #endif
+#endif
+    // init help system
+    provider->SetHelpController(&frame->GetHelpController());
+#ifdef __WXMSW__
+    frame->GetHelpController().Initialize(m_xrcPrefix + wxT("data/hugin_help_en_EN.chm"));
+#else
+#if wxUSE_WXHTML_HELP
+    // using wxHtmlHelpController
+#if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
+    // On Mac, xrc/data/help_LOCALE should be in the bundle as LOCALE.lproj/help
+    // which we can rely on the operating sytem to pick the right locale's.
+    wxString strFile = MacGetPathToBundledResourceFile(CFSTR("help"));
+    if (!strFile.IsEmpty())
+    {
+        frame->GetHelpController().AddBook(wxFileName(strFile + wxT("/hugin_help_en_EN.hhp")));
+    }
+    else
+    {
+        wxLogError(wxString::Format(wxT("Could not find help directory in the bundle"), strFile.c_str()));
+        return false;
+    }
+#else
+    frame->GetHelpController().AddBook(wxFileName(m_xrcPrefix + wxT("data/help_en_EN/hugin_help_en_EN.hhp")));
+#endif
+#else
+    // using wxExtHelpController
+    frame->GetHelpController().Initialize(Initialize(m_xrcPrefix + wxT("data/help_en_EN")));
+#endif
 #endif
 
     // we are closing Hugin, if the top level window is deleted
@@ -555,11 +568,8 @@ bool huginApp::OnInit()
 int huginApp::OnExit()
 {
     DEBUG_TRACE("");
-#ifdef __WXMSW__    
     delete wxHelpProvider::Set(NULL);
-#endif
-
-    return wxApp::OnExit();
+    return 0;
 }
 
 huginApp * huginApp::Get()
@@ -584,7 +594,19 @@ MainFrame* huginApp::getMainFrame()
 
 void huginApp::relayImageLoaded(ImageReadyEvent & event)
 {
-    ImageCache::getInstance().postEvent(event.request, event.entry);
+    if (event.entry.get())
+    {
+        ImageCache::getInstance().postEvent(event.request, event.entry);
+    }
+    else
+    {
+        // loading failed, first remove request from image cache list
+        ImageCache::getInstance().removeRequest(event.request);
+        // now notify main frame to remove the failed image from project
+        wxCommandEvent e(EVT_LOADING_FAILED);
+        e.SetString(wxString(event.request->getFilename().c_str(), HUGIN_CONV_FILENAME));
+        frame->GetEventHandler()->AddPendingEvent(e);
+    };
 }
 
 void huginApp::imageLoadedAsync(ImageCache::RequestPtr request, ImageCache::EntryPtr entry)
