@@ -22,7 +22,7 @@
  *
  */
 
-#include <config.h>
+#include "hugin_config.h"
 
 #include "panoinc_WX.h"
 #include "panoinc.h"
