@@ -14,8 +14,8 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -27,8 +27,7 @@
 
 #include <hugin_shared.h>
 #include "CPDetectorConfig.h"
-#include "PT/Panorama.h"
-#include "PT/PanoramaMemento.h"
+#include "panodata/Panorama.h"
 #include "panodata/ControlPoint.h"
 #include "panoinc_WX.h"
 
@@ -50,18 +49,16 @@ public:
     /** Do cp matching, calles the right routines, based
      *  on the matcher selected
      */
-    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, int & ret_value, wxWindow *parent=NULL);
-    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, wxWindow *parent=NULL);
-    virtual void Cleanup(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual void Cleanup(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            std::vector<wxString> &keyFiles, wxWindow *parent=NULL);
 
 protected:
     HuginBase::CPVector readUpdatedControlPoints(const std::string & file,
-                                  PT::Panorama & pano);
-    HuginBase::CPVector readUpdatedControlPoints(const std::string & file,
-                                  PT::Panorama & pano, const PT::UIntSet & imgs);
+                                  HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs, bool reordered);
 };
 
 /** A matcher that uses Sebastians Nowozin's excellent sift matcher */
@@ -77,9 +74,9 @@ public:
      */
     virtual ~AutoPanoSift() {} ;
 
-    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, int & ret_value, wxWindow *parent=NULL);
-    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, std::vector<wxString> &keyFiles, int & ret_value, wxWindow *parent=NULL);
 };
 
@@ -96,7 +93,7 @@ public:
      */
     virtual ~AutoPanoKolor() {} ;
 
-    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, int & ret_value, wxWindow *parent=NULL);
 };
 
@@ -113,7 +110,7 @@ public:
      */
     virtual ~AutoPanoSiftStack() {} ;
 
-    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, int & ret_value, wxWindow *parent=NULL);
 };
 
@@ -130,7 +127,7 @@ public:
      */
     virtual ~AutoPanoSiftMultiRow() {} ;
 
-    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, int & ret_value, wxWindow *parent=NULL);
 };
 
@@ -147,7 +144,7 @@ public:
      */
     virtual ~AutoPanoSiftMultiRowStack() {} ;
 
-    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, int & ret_value, wxWindow *parent=NULL);
 };
 
@@ -164,9 +161,9 @@ public:
      */
     virtual ~AutoPanoSiftPreAlign() {} ;
 
-    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, int & ret_value, wxWindow *parent=NULL);
-    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, PT::Panorama & pano, const PT::UIntSet & imgs,
+    virtual HuginBase::CPVector automatch(CPDetectorSetting &setting, HuginBase::Panorama & pano, const HuginBase::UIntSet & imgs,
                            int nFeatures, std::vector<wxString> &keyFiles, int & ret_value, wxWindow *parent=NULL);
 };
 
