@@ -19,8 +19,8 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -118,7 +118,7 @@ private:
     bool option;
 };
 
-#if _WINDOWS && defined Hugin_shared 
+#if defined _WIN32 && defined Hugin_shared 
 WX_DECLARE_USER_EXPORTED_OBJARRAY(CPDetectorSetting,ArraySettings,ICPIMPEX);
 #else
 WX_DECLARE_OBJARRAY(CPDetectorSetting,ArraySettings);
