@@ -31,9 +31,13 @@
 #include "Batch.h"
 #include "ProjectListBox.h"
 #include "DirTraverser.h"
-#ifdef __WXMSW__
-#include "wx/msw/helpchm.h"
+#include "wx/help.h"
+#if !wxUSE_HELP
+#error wxWidgets needs to be compiled with help support (wxUSE_HELP not set)
+#endif
+#if defined __WXMSW__ && !(wxCHECK_VERSION(3,1,1))
 #include "base_wx/wxPlatform.h"
+#define wxHelpController HuginCHMHelpController
 #endif
 #include "BatchTrayIcon.h"
 //#include <wx/app.h>
@@ -113,7 +117,7 @@ public:
     //Sets locale and XRC prefix pointers from main app
     void SetLocaleAndXRC(wxLocale* locale, wxString xrc);
     //Swaps the project entry at index in the list with the next (at index+1).
-    void SwapProject(int index);
+    void SwapProject(int index, bool down);
     //PanoramaOptions readOptions(wxString projectFile);
     /** return which task should be executed at end*/
     Batch::EndTask GetEndTask();
@@ -137,8 +141,8 @@ public:
     bool IsPaused();
     /** sets status message, also updates tooltip of taskbar icon
      *  @param status text for status bar
-     *  @param showBalloon true if the status text should also shown in balloon */
-    void SetStatusInformation(wxString status,bool showBalloon);
+     */
+    void SetStatusInformation(wxString status);
     /** update visibility of verbose output window depending on status of verbose checkbox */
     void UpdateBatchVerboseStatus();
     /** returns true, if last session was finished minimized */
@@ -151,20 +155,8 @@ public:
     /** update the progress bar in the task bar */
     void UpdateTaskBarProgressBar();
 
-#ifdef __WXMSW__
     /** return help controller for open help */
-#if wxCHECK_VERSION(3,1,1)
-    wxCHMHelpController& GetHelpController()
-    {
-        return m_msHtmlHelp;
-    }
-#else
-    HuginCHMHelpController& GetHelpController()
-    {
-        return m_msHtmlHelp;
-    }
-#endif
-#endif
+    wxHelpController& GetHelpController() { return m_HelpController; }
 
     //wxMutex* projListMutex;
     ProjectListBox* projListBox;
@@ -179,15 +171,8 @@ private:
     wxChoice* m_endChoice;
     //TO-DO: include a batch or project progress gauge? Test initialization commented out in constructor
     //wxGauge* m_gauge;
-#ifdef __WXMSW__
-#if wxCHECK_VERSION(3,1,1)
-    wxCHMHelpController m_msHtmlHelp;
-#else
-    HuginCHMHelpController m_msHtmlHelp;
-#endif
-#else
-    wxHtmlHelpController* m_help;
-#endif
+    // help controller
+    wxHelpController m_HelpController;
     BatchTaskBarIcon* m_tray;
     ProgressStatusBar* m_progStatusBar;
     wxIcon m_iconNormal;
