@@ -25,14 +25,31 @@
  */
 
 #include "PTBatcherGUI.h"
-#ifdef __WXMSW__
 #include <wx/cshelp.h>
+#ifdef __WXMSW__
 #include <wx/stdpaths.h>
 #endif
 #include "lensdb/LensDB.h"
 
 // make wxwindows use this class as the main application
-IMPLEMENT_APP(PTBatcherGUI)
+#if defined USE_GDKBACKEND_X11
+// wxWidgets does not support wxTaskBarIcon::IsAvailable on Wayland
+// so until it is fixed upstream enforce using x11 backendj
+// see ticket http://trac.wxwidgets.org/ticket/17779
+#warning Using Hugin with hard coded GDK_BACKEND=x11
+wxIMPLEMENT_WX_THEME_SUPPORT
+wxIMPLEMENT_APP_NO_MAIN(PTBatcherGUI);
+#include <stdlib.h>
+int main(int argc, char **argv)
+{   
+    wxDISABLE_DEBUG_SUPPORT();
+    char backend[]="GDK_BACKEND=x11";
+    putenv(backend);
+    return wxEntry(argc, argv);
+};
+#else
+wxIMPLEMENT_APP(PTBatcherGUI);
+#endif
 
 BEGIN_EVENT_TABLE(PTBatcherGUI, wxApp)
     EVT_LIST_ITEM_ACTIVATED(XRCID("project_listbox"),PTBatcherGUI::OnItemActivated)
@@ -41,22 +58,23 @@ END_EVENT_TABLE()
 
 bool PTBatcherGUI::OnInit()
 {
-    // Required to access the preferences of hugin
 #if wxUSE_ON_FATAL_EXCEPTION
     wxHandleFatalExceptions();
 #endif
+    // Required to access the preferences of hugin
     SetAppName(wxT("hugin"));
 
+    // need to explicitly initialize locale for C++ library/runtime
+    setlocale(LC_ALL, "");
 #if defined __WXMSW__
     int localeID = wxConfigBase::Get()->Read(wxT("language"), (long) wxLANGUAGE_DEFAULT);
     m_locale.Init(localeID);
-    // initialize help provider
-    wxHelpControllerHelpProvider* provider = new wxHelpControllerHelpProvider;
-    wxHelpProvider::Set(provider);
-
 #else
     m_locale.Init(wxLANGUAGE_DEFAULT);
 #endif
+    // initialize help provider
+    wxHelpControllerHelpProvider* provider = new wxHelpControllerHelpProvider;
+    wxHelpProvider::Set(provider);
 
     // setup the environment for the different operating systems
 #if defined __WXMSW__
@@ -80,16 +98,6 @@ bool PTBatcherGUI::OnInit()
             return false;
         }
 
-        wxString thePath = MacGetPathToBundledResourceFile(CFSTR("locale"));
-        if(thePath != wxT(""))
-        {
-            m_locale.AddCatalogLookupPathPrefix(thePath);
-        }
-        else
-        {
-            wxMessageBox(_("Translations not found in bundle"), _("Fatal Error"));
-            return false;
-        }
     }
 #else
     // add the locale directory specified during configure
@@ -128,9 +136,6 @@ bool PTBatcherGUI::OnInit()
     // parse arguments
     static const wxCmdLineEntryDesc cmdLineDesc[] =
     {
-        //On wxWidgets 2.9, wide characters don't work here.
-        //On previous versions, the wxT macro is required for unicode builds.
-#if wxCHECK_VERSION(2,9,0)
         {
             wxCMD_LINE_SWITCH, "h", "help", "show this help message",
             wxCMD_LINE_VAL_NONE, wxCMD_LINE_OPTION_HELP
@@ -145,22 +150,6 @@ bool PTBatcherGUI::OnInit()
             wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL + wxCMD_LINE_PARAM_MULTIPLE
         },
         { wxCMD_LINE_NONE }
-#else
-        {
-            wxCMD_LINE_SWITCH, wxT("h"), wxT("help"), wxT("show this help message"),
-            wxCMD_LINE_VAL_NONE, wxCMD_LINE_OPTION_HELP
-        },
-        { wxCMD_LINE_SWITCH, wxT("b"), wxT("batch"),  wxT("run batch immediately") },
-        { wxCMD_LINE_SWITCH, wxT("o"), wxT("overwrite"),  wxT("overwrite previous files without asking") },
-        { wxCMD_LINE_SWITCH, wxT("s"), wxT("shutdown"),  wxT("shutdown computer after batch is complete") },
-        { wxCMD_LINE_SWITCH, wxT("v"), wxT("verbose"),  wxT("show verbose output when processing projects") },
-        { wxCMD_LINE_SWITCH, wxT("a"), wxT("assistant"), wxT("run the assistant on the given projects") },
-        {
-            wxCMD_LINE_PARAM,  NULL, NULL, _("stitch_project.pto [output prefix]|assistant_project.pto"),
-            wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL + wxCMD_LINE_PARAM_MULTIPLE
-        },
-        { wxCMD_LINE_NONE }
-#endif
     };
     wxCmdLineParser parser(cmdLineDesc, argc, argv);
 
@@ -180,7 +169,7 @@ bool PTBatcherGUI::OnInit()
     wxClient client;
     wxConnectionBase* conn;
     wxString servername;
-#ifdef __WINDOWS__
+#ifdef _WIN32
     servername=name;
 #else
     servername=wxFileName::GetTempDir()+wxFileName::GetPathSeparator()+name+wxT(".ipc");
@@ -189,10 +178,35 @@ bool PTBatcherGUI::OnInit()
     {
         m_frame = new BatchFrame(&m_locale,m_xrcPrefix);
         m_frame->RestoreSize();
-#ifdef __WXMSW__
+        // init help system
         provider->SetHelpController(&m_frame->GetHelpController());
-        m_frame->GetHelpController().Initialize(m_xrcPrefix+wxT("data/hugin_help_en_EN.chm"));
+#ifdef __WXMSW__
+        m_frame->GetHelpController().Initialize(m_xrcPrefix + wxT("data/hugin_help_en_EN.chm"));
+#else
+#if wxUSE_WXHTML_HELP
+        // using wxHtmlHelpController
+#if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
+        // On Mac, xrc/data/help_LOCALE should be in the bundle as LOCALE.lproj/help
+        // which we can rely on the operating sytem to pick the right locale's.
+        wxString strFile = MacGetPathToBundledResourceFile(CFSTR("help"));
+        if (!strFile.IsEmpty())
+        {
+            m_frame->GetHelpController().AddBook(wxFileName(strFile + wxT("/hugin_help_en_EN.hhp")));
+        }
+        else
+        {
+            wxLogError(wxString::Format(wxT("Could not find help directory in the bundle"), strFile.c_str()));
+            return false;
+        }
+#else
+        m_frame->GetHelpController().AddBook(wxFileName(m_xrcPrefix + wxT("data/help_en_EN/hugin_help_en_EN.hhp")));
 #endif
+#else
+        // using wxExtHelpController
+        m_frame->GetHelpController().Initialize(Initialize(m_xrcPrefix + wxT("data/help_en_EN")));
+#endif
+#endif
+
         SetTopWindow(m_frame);
         if(!(m_frame->IsStartedMinimized()))
         {
@@ -200,7 +214,7 @@ bool PTBatcherGUI::OnInit()
         }
         else
         {
-            m_frame->SetStatusInformation(_("PTBatcherGUI started"), true);
+            m_frame->SetStatusInformation(_("PTBatcherGUI started"));
         };
         m_server = new BatchIPCServer();
         if (!m_server->Create(servername))
@@ -217,30 +231,29 @@ bool PTBatcherGUI::OnInit()
             return false;
         }
     };
-    //m_frame->SetLocaleAndXRC(&m_locale,m_xrcPrefix);
-    //projectsRunning=0;
-    unsigned int count = 0;
-    if(parser.Found(wxT("a")))
+
+    size_t count = 0;
+    if (parser.Found(wxT("a")))
     {
         //added assistant files
-        while(parser.GetParamCount()>count)
+        while (parser.GetParamCount() > count)
         {
             wxString param = parser.GetParam(count);
             count++;
             wxFileName name(param);
             name.MakeAbsolute();
-            if(name.FileExists())
+            if (name.FileExists())
             {
                 //only add existing pto files
-                if(name.GetExt().CmpNoCase(wxT("pto"))==0)
+                if (name.GetExt().CmpNoCase(wxT("pto")) == 0)
                 {
-                    if(IsFirstInstance)
+                    if (IsFirstInstance)
                     {
-                        m_frame->AddToList(name.GetFullPath(),Project::DETECTING);
+                        m_frame->AddToList(name.GetFullPath(), Project::DETECTING);
                     }
                     else
                     {
-                        conn->Request(wxT("D ")+name.GetFullPath());
+                        conn->Request(wxT("D ") + name.GetFullPath());
                     };
                 };
             };
@@ -250,21 +263,21 @@ bool PTBatcherGUI::OnInit()
     {
         bool projectSpecified = false;
         //we collect all parameters - all project files <and their output prefixes>
-        while(parser.GetParamCount()>count)
+        while (parser.GetParamCount() > count)
         {
             wxString param = parser.GetParam(count);
             count++;
-            if(!projectSpecified)	//next parameter must be new script file
+            if (!projectSpecified)	//next parameter must be new script file
             {
                 wxFileName name(param);
                 name.MakeAbsolute();
-                if(IsFirstInstance)
+                if (IsFirstInstance)
                 {
                     m_frame->AddToList(name.GetFullPath());
                 }
                 else
                 {
-                    conn->Request(wxT("A ")+name.GetFullPath());
+                    conn->Request(wxT("A ") + name.GetFullPath());
                 }
                 projectSpecified = true;
             }
@@ -272,15 +285,15 @@ bool PTBatcherGUI::OnInit()
             {
                 wxFileName fn(param);
                 fn.MakeAbsolute();
-                if(!fn.HasExt())	//if there is no extension we have a prefix
+                if (!fn.HasExt())	//if there is no extension we have a prefix
                 {
-                    if(IsFirstInstance)
+                    if (IsFirstInstance)
                     {
-                        m_frame->ChangePrefix(-1,fn.GetFullPath());
+                        m_frame->ChangePrefix(-1, fn.GetFullPath());
                     }
                     else
                     {
-                        conn->Request(wxT("P ")+fn.GetFullPath());
+                        conn->Request(wxT("P ") + fn.GetFullPath());
                     }
                     projectSpecified = false;
                 }
@@ -288,50 +301,39 @@ bool PTBatcherGUI::OnInit()
                 {
                     wxString ext = fn.GetExt();
                     //we may still have a prefix, but with added image extension
-                    if (ext.CmpNoCase(wxT("jpg")) == 0 || ext.CmpNoCase(wxT("jpeg")) == 0||
-                            ext.CmpNoCase(wxT("tif")) == 0|| ext.CmpNoCase(wxT("tiff")) == 0 ||
-                            ext.CmpNoCase(wxT("png")) == 0 || ext.CmpNoCase(wxT("exr")) == 0 ||
-                            ext.CmpNoCase(wxT("pnm")) == 0 || ext.CmpNoCase(wxT("hdr")) == 0)
+                    if (ext.CmpNoCase(wxT("jpg")) == 0 || ext.CmpNoCase(wxT("jpeg")) == 0 ||
+                        ext.CmpNoCase(wxT("tif")) == 0 || ext.CmpNoCase(wxT("tiff")) == 0 ||
+                        ext.CmpNoCase(wxT("png")) == 0 || ext.CmpNoCase(wxT("exr")) == 0 ||
+                        ext.CmpNoCase(wxT("pnm")) == 0 || ext.CmpNoCase(wxT("hdr")) == 0)
                     {
                         //extension will be removed before stitch, so there is no need to do it now
-                        if(IsFirstInstance)
+                        if (IsFirstInstance)
                         {
-                            m_frame->ChangePrefix(-1,fn.GetFullPath());
+                            m_frame->ChangePrefix(-1, fn.GetFullPath());
                         }
                         else
                         {
-                            conn->Request(wxT("P ")+fn.GetFullPath());
+                            conn->Request(wxT("P ") + fn.GetFullPath());
                         }
                         projectSpecified = false;
                     }
                     else //if parameter has a different extension we presume it is a new script file
                     {
                         //we add the new project
-                        if(IsFirstInstance)
+                        if (IsFirstInstance)
                         {
                             m_frame->AddToList(fn.GetFullPath());
                         }
                         else
                         {
-                            conn->Request(wxT("A ")+fn.GetFullPath());
+                            conn->Request(wxT("A ") + fn.GetFullPath());
                         }
                         projectSpecified = true;
                     }
                 } //else of if(!fn.HasExt())
             }
         }
-    }
-
-#if 0 //ifdef __WXMAC__
-    // see PTBatcherGUI::MacOpenFile for explanation
-    m_macFileNameToOpenOnStart = wxT("");
-    wxYield();
-    if(m_macFileNameToOpenOnStart != wxT(""))
-    {
-        wxFileName fn(m_macFileNameToOpenOnStart);
-        m_frame->AddToList(fn.GetFullPath());
-    }
-#endif
+    };
 
     if(IsFirstInstance)
     {
@@ -392,6 +394,20 @@ bool PTBatcherGUI::OnInit()
     {
         m_frame->RunBatch();
     }
+#ifdef __WXMAC__
+    // if there are command line parameters they are handled all by the code above
+    // but wxMac calls also MacOpenFiles after OnInit with the command line
+    // parameters again, so the files get added twice. To prevent this we
+    // reset the internal file list for MacOpenFiles here
+    // but we need to process the files when PTBatcherGUI is called from finder
+    // with an open files AppleEvent, in this case the argv is empty (except argc[0])
+    // and we don't want to skip the MacOpenFile function
+    if (argc > 1)
+    {
+        wxArrayString emptyFiles;
+        OSXStoreOpenFiles(emptyFiles);
+    };
+#endif
     return true;
 }
 
@@ -400,6 +416,7 @@ int PTBatcherGUI::OnExit()
     HuginBase::LensDB::LensDB::Clean();
     delete m_checker;
     delete m_server;
+    delete wxHelpProvider::Set(NULL);
     return 0;
 }
 
@@ -437,53 +454,39 @@ void PTBatcherGUI::OnKeyDown(wxKeyEvent& event)
 
 }
 
-#if 0 //ifdef __WXMAC__
-// wx calls this method when the app gets "Open file" AppleEvent
-// this does not work with wxWidgets 2.9.3, Cocoa variant. The project is added twice.
-// From the doc it is recommended to react only on MacOpenFile
-// So we should  to skip to code concerning command line parsing in OnInit, and parse it here
-// But this does not work. MacOpenFile is not called when PTBatcherGUI is already running
-// So for the moment I leave the code in OnInit also for Mac
-void PTBatcherGUI::MacOpenFile(const wxString& fileName)
+#ifdef __WXMAC__
+// wx calls this method when the app gets "Open files" AppleEvent
+void PTBatcherGUI::MacOpenFiles(const wxArrayString &fileNames) 
 {
-    if(!m_frame)
+    if(m_frame)
     {
-        m_macFileNameToOpenOnStart = fileName;
-    }
-    else
-    {
-        wxFileName fn(fileName);
-        m_frame->AddToList(fn.GetFullPath());
-    }
+        for (int i = 0; i < fileNames.GetCount(); ++i)
+        {
+            wxFileName fn(fileNames[i]);
+            m_frame->AddToList(fn.GetFullPath());
+        };
+    };
 }
 #endif
 
-#if wxCHECK_VERSION(2,9,0)
-#define RETURNEMPTYSTRING return wxEmptyString
 const void* BatchIPCConnection::OnRequest(const wxString& topic, const wxString& item, size_t* size, wxIPCFormat format)
 {
     *size=wxNO_LEN;
-#else
-#define RETURNEMPTYSTRING return ((wxChar*) "")
-wxChar* BatchIPCConnection::OnRequest(const wxString& topic, const wxString& item, int* size, wxIPCFormat format)
-{
-    *size=-1;
-#endif
     BatchFrame* MyBatchFrame=wxGetApp().GetFrame();
     if(item.Left(1)==wxT("A"))
     {
         MyBatchFrame->AddToList(item.Mid(2));
-        RETURNEMPTYSTRING;
+        return wxEmptyString;
     };
     if(item.Left(1)==wxT("D"))
     {
         MyBatchFrame->AddToList(item.Mid(2),Project::DETECTING);
-        RETURNEMPTYSTRING;
+        return wxEmptyString;
     };
     if(item.Left(1)==wxT("P"))
     {
         MyBatchFrame->ChangePrefix(-1,item.Mid(2));
-        RETURNEMPTYSTRING;
+        return wxEmptyString;
     };
     wxCommandEvent event;
     event.SetInt(1);
@@ -519,7 +522,7 @@ wxChar* BatchIPCConnection::OnRequest(const wxString& topic, const wxString& ite
         wxCommandEvent myEvent(wxEVT_COMMAND_TOOL_CLICKED ,XRCID("tool_start"));
         MyBatchFrame->GetEventHandler()->AddPendingEvent(myEvent);
     };
-    RETURNEMPTYSTRING;
+    return wxEmptyString;
 };
 
 wxConnectionBase* BatchIPCServer::OnAcceptConnection (const wxString& topic)
