@@ -266,6 +266,9 @@ bool stitchApp::OnInit()
     // Required to access the preferences of hugin
     SetAppName(wxT("hugin"));
 
+    // need to explicitly initialize locale for C++ library/runtime
+    setlocale(LC_ALL, "");
+    // initialize i18n
 #if defined __WXMSW__
     int localeID = wxConfigBase::Get()->Read(wxT("language"), (long) wxLANGUAGE_DEFAULT);
     m_locale.Init(localeID);
@@ -285,18 +288,6 @@ bool stitchApp::OnInit()
     m_locale.AddCatalogLookupPathPrefix(wxT(INSTALL_LOCALE_DIR));
 #endif
 
-#if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
-    {
-        wxString thePath = MacGetPathToBundledResourceFile(CFSTR("locale"));
-        if(thePath != wxT(""))
-            m_locale.AddCatalogLookupPathPrefix(thePath);
-        else {
-            wxMessageBox(_("Translations not found in bundle"), _("Fatal Error"));
-            return false;
-        }
-    }
-#endif
-    
     // set the name of locale recource to look for
     m_locale.AddCatalog(wxT("hugin"));
 
@@ -305,7 +296,6 @@ bool stitchApp::OnInit()
     {
         //On wxWidgets 2.9, wide characters don't work here.
         //On previous versions, the wxT macro is required for unicode builds.
-#if wxCHECK_VERSION(2,9,0)
       { wxCMD_LINE_SWITCH, "h", "help", "show this help message",
         wxCMD_LINE_VAL_NONE, wxCMD_LINE_OPTION_HELP },
       { wxCMD_LINE_OPTION, "o", "output",  "output prefix" },
@@ -315,17 +305,6 @@ bool stitchApp::OnInit()
       { wxCMD_LINE_PARAM,  NULL, NULL, "<project>",
         wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
       { wxCMD_LINE_NONE }
-#else 
-      { wxCMD_LINE_SWITCH, wxT("h"), wxT("help"), wxT("show this help message"),
-        wxCMD_LINE_VAL_NONE, wxCMD_LINE_OPTION_HELP },
-      { wxCMD_LINE_OPTION, wxT("o"), wxT("output"),  wxT("output prefix") },
-      { wxCMD_LINE_SWITCH, wxT("d"), wxT("delete"),  wxT("delete pto file after stitching") },
-      { wxCMD_LINE_SWITCH, wxT("w"), wxT("overwrite"), wxT("overwrite existing files") },
-      { wxCMD_LINE_OPTION, wxT("u"), wxT("user-defined-output"), wxT("use user defined output") },
-      { wxCMD_LINE_PARAM,  NULL, NULL, wxT("<project>"),
-        wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
-      { wxCMD_LINE_NONE }
-#endif 
     };
 
     wxCmdLineParser parser(cmdLineDesc, argc, argv);
