@@ -30,8 +30,6 @@
 
 namespace HuginBase {
 
-using namespace hugin_utils;
-
 CalculateImageOverlap::CalculateImageOverlap(const HuginBase::PanoramaData *pano):m_pano(pano)
 {
     m_nrImg=pano->getNrOfImages();
@@ -105,7 +103,7 @@ void CalculateImageOverlap::calculate(unsigned int steps)
                     double xi,yi;
                     if (m_invTransform[imgNr]->transformImgCoord(xi, yi, xc, yc))
                     {
-                        //now, check if point is inside an other image
+                        //now, check if point is inside another image
                         for(unsigned int j=0;j<m_nrImg;j++)
                         {
                             if (imgNr == j)
@@ -142,7 +140,7 @@ void CalculateImageOverlap::calculate(unsigned int steps)
     };
 };
 
-double CalculateImageOverlap::getOverlap(unsigned int i, unsigned int j)
+double CalculateImageOverlap::getOverlap(unsigned int i, unsigned int j) const
 {
     if(i==j)
     {
@@ -154,7 +152,7 @@ double CalculateImageOverlap::getOverlap(unsigned int i, unsigned int j)
     };
 };
 
-UIntSet CalculateImageOverlap::getOverlapForImage(unsigned int i)
+UIntSet CalculateImageOverlap::getOverlapForImage(unsigned int i) const
 {
     UIntSet overlapImgs;
     for(unsigned int j=0;j<m_nrImg;j++)
@@ -173,7 +171,7 @@ UIntSet CalculateImageOverlap::getOverlapForImage(unsigned int i)
 void CalculateImageOverlap::limitToImages(UIntSet img)
 {
     m_testImages.clear();
-    for (UIntSet::const_iterator it = img.begin(); it != img.end(); it++)
+    for (UIntSet::const_iterator it = img.begin(); it != img.end(); ++it)
     {
         m_testImages.push_back(*it);
     };
