@@ -331,8 +331,8 @@ template<class DistImgType>
 void RemappedPanoImage<RemapImage,AlphaImage>::calcSrcCoordImgs(DistImgType & imgX, DistImgType & imgY)
 {
     if (Base::boundingBox().isEmpty()) return;
-    imgX.resize(Base::boundingBox().size());
-    imgY.resize(Base::boundingBox().size());
+    imgX.resize(Base::boundingBox().size().width(), Base::boundingBox().size().height(), vigra::NumericTraits<typename DistImgType::value_type>::max());
+    imgY.resize(Base::boundingBox().size().width(), Base::boundingBox().size().height(), vigra::NumericTraits<typename DistImgType::value_type>::max());
     // calculate the alpha channel,
     int xstart = Base::boundingBox().left();
     int xend   = Base::boundingBox().right();
@@ -353,9 +353,14 @@ void RemappedPanoImage<RemapImage,AlphaImage>::calcSrcCoordImgs(DistImgType & im
         for(int x=xstart; x < xend; ++x, ++xImgY.x, ++xImgX.x)
         {
             double sx,sy;
-            m_transf.transformImgCoord(sx,sy,x,y);
-            accX.set(sx, xImgX);
-            accY.set(sy, xImgY);
+            if (m_transf.transformImgCoord(sx, sy, x, y))
+            {
+                if (m_srcImg.isInside(vigra::Point2D(hugin_utils::roundi(sx), hugin_utils::roundi(sy))))
+                {
+                    accX.set(sx, xImgX);
+                    accY.set(sy, xImgY);
+                };
+            };
         }
     }
 }
@@ -381,13 +386,13 @@ void RemappedPanoImage<RemapImage,AlphaImage>::calcAlpha()
     int ystart = Base::boundingBox().top();
     int yend   = Base::boundingBox().bottom();
 
-// DGSW FIXME - Unreferenced
-//		int interpolHalfWidth=0;
-    // create dist y iterator
-    typename AlphaImage::Iterator yalpha(Base::m_mask.upperLeft());
     // loop over the image and transform
-    for(int y=ystart; y < yend; ++y, ++yalpha.y)
+#pragma omp parallel for schedule(dynamic, 10)
+    for(int y=ystart; y < yend; ++y)
     {
+        // create dist y iterator
+        typename AlphaImage::Iterator yalpha(Base::m_mask.upperLeft());
+        yalpha.y += y - ystart;
         // create x iterators
         typename AlphaImage::Iterator xalpha(yalpha);
         for(int x=xstart; x < xend; ++x, ++xalpha.x)
@@ -432,14 +437,15 @@ void RemappedPanoImage<RemapImage,AlphaImage>::remapImage(vigra::triple<ImgIter,
     vigra::Diff2D srcImgSize = srcImg.second - srcImg.first;
 
     vigra::Size2D expectedSize = m_srcImg.getSize();
-    if (useGPU) {
+    if (useGPU)
+    {
         const int r = expectedSize.width() % 8;
         if (r != 0) expectedSize += vigra::Diff2D(8 - r, 0);
     }
 
     DEBUG_DEBUG("srcImgSize: " << srcImgSize << " m_srcImgSize: " << m_srcImg.getSize());
     vigra_precondition(srcImgSize == expectedSize, 
-                       "RemappedPanoImage<RemapImage,AlphaImage>::remapImage(): image sizes not consistent");
+                       "RemappedPanoImage<RemapImage,AlphaImage>::remapImage(): image unexpectedly changed dimensions.");
 
     typedef typename ImgAccessor::value_type input_value_type;
     typedef typename vigra_ext::ValueTypeTraits<input_value_type>::value_type input_component_type;
@@ -452,7 +458,10 @@ void RemappedPanoImage<RemapImage,AlphaImage>::remapImage(vigra::triple<ImgIter,
     if (m_destImg.outputMode == PanoramaOptions::OUTPUT_LDR) {
         // select exposure and response curve for LDR output
         std::vector<double> outLut;
-        vigra_ext::EMoR::createEMoRLUT(m_destImg.outputEMoRParams, outLut);
+        if (!m_destImg.outputEMoRParams.empty())
+        {
+            vigra_ext::EMoR::createEMoRLUT(m_destImg.outputEMoRParams, outLut);
+        };
         double maxVal = vigra_ext::LUTTraits<input_value_type>::max();
         if (m_destImg.outputPixelType.size() > 0) {
             maxVal = vigra_ext::getMaxValForPixelType(m_destImg.outputPixelType);
@@ -618,13 +627,13 @@ void RemappedPanoImage<RemapImage,AlphaImage>::remapImage(vigra::triple<ImgIter,
     vigra::Diff2D srcImgSize = srcImg.second - srcImg.first;
 
     vigra::Size2D expectedSize = m_srcImg.getSize();
-    if (useGPU) {
+    if (useGPU)
+    {
         const int r = expectedSize.width() % 8;
         if (r != 0) expectedSize += vigra::Diff2D(8 - r, 0);
     }
-
-    vigra_precondition(srcImgSize == expectedSize, 
-                       "RemappedPanoImage<RemapImage,AlphaImage>::remapImage(): image sizes not consistent");
+    vigra_precondition(srcImgSize == expectedSize,
+                       "RemappedPanoImage<RemapImage,AlphaImage>::remapImage(): image unexpectedly changed dimensions.");
 
     typedef typename ImgAccessor::value_type input_value_type;
     typedef typename vigra_ext::ValueTypeTraits<input_value_type>::value_type input_component_type;
@@ -641,8 +650,11 @@ void RemappedPanoImage<RemapImage,AlphaImage>::remapImage(vigra::triple<ImgIter,
         if (m_destImg.outputPixelType.size() > 0) {
             maxVal = vigra_ext::getMaxValForPixelType(m_destImg.outputPixelType);
         }
-        vigra_ext::EMoR::createEMoRLUT(m_destImg.outputEMoRParams, outLut);
-		vigra_ext::enforceMonotonicity(outLut);
+        if (!m_destImg.outputEMoRParams.empty())
+        {
+            vigra_ext::EMoR::createEMoRLUT(m_destImg.outputEMoRParams, outLut);
+            vigra_ext::enforceMonotonicity(outLut);
+        };
         invResponse.setOutput(1.0/pow(2.0,m_destImg.outputExposureValue), outLut,
                               maxVal);
     } else {
@@ -771,11 +783,6 @@ void remapImage(SrcImgType & srcImg,
                 RemappedPanoImage<DestImgType, MaskImgType> & remapped,
                 AppBase::ProgressDisplay* progress)
 {
-    typedef typename SrcImgType::value_type SrcPixelType;
-    typedef typename DestImgType::value_type DestPixelType;
-
-    typedef typename vigra::NumericTraits<SrcPixelType>::RealPromote RSrcPixelType;
-
 #ifdef DEBUG_REMAP
     {
         vigra::ImageExportInfo exi( DEBUG_FILE_PREFIX "hugin03_BeforeRemap.tif");
