@@ -26,16 +26,12 @@
 
 #include "Lens.h"
 
-#include <vigra/impex.hxx>
 #include <hugin_utils/utils.h>
 #include <hugin_utils/stl_utils.h>
 
 
 namespace HuginBase {
 
-using namespace hugin_utils;
-
-
 Lens::Lens()
     : m_hasExif(false), m_projectionFormat(BaseSrcPanoImage::RECTILINEAR),
       m_imageSize(0,0), m_cropFactor(1.0)
