@@ -106,6 +106,7 @@ public:
     ///
     virtual PanoramaData* getNewCopy() const =0;
     
+    virtual PanoramaData* getUnlinkedSubset(UIntSetVector& imageGroups) const = 0;
     
 // -- Data Access --
     
@@ -394,7 +395,7 @@ public:
     virtual void updateMasks(bool convertPosMaskToNeg=false)=0;
     /** transfers given mask from image imgNr to all targetImgs
         */
-    virtual void transferMask(MaskPolygon mask,unsigned int imgNr, const UIntSet targetImgs)=0;
+    virtual void transferMask(MaskPolygon mask,unsigned int imgNr, const UIntSet& targetImgs)=0;
     /** updates the optimize vector according to master switches */
     virtual void updateOptimizeVector()=0;
     /** returns set of reference image and images linked with reference images */
