@@ -19,8 +19,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  Revised 16JAN2010 by TKSharpless 
  to support default projection  parameters and dynamic FOV limits.
@@ -59,10 +59,6 @@
 
 namespace HuginBase {
 
-using namespace hugin_utils;
-using namespace vigra;
-
-
 const std::string & PanoramaOptions::getFormatName(FileFormat f)
 {
     assert((int)f <= (int)FILEFORMAT_NULL);
@@ -133,7 +129,7 @@ void PanoramaOptions::printScriptLine(std::ostream & o, bool forPTOptimizer) con
         o << "\"";
     }
     o << " n\"" << getFormatName(outputFormat);
-    if ( outputFormat == JPEG ) {
+    if ( outputFormat == JPEG || outputFormat == JPEG_m) {
         o << " q" << quality;
     } else if ( outputFormat == TIFF ||
                 outputFormat == TIFF_m ||
@@ -164,8 +160,6 @@ void PanoramaOptions::printScriptLine(std::ostream & o, bool forPTOptimizer) con
 
     // options for photometric estimation.
     o << " p" << photometricHuberSigma;
-    if (photometricSymmetricError) 
-        o << " s1";
 
     o << std::endl;
 }
@@ -264,8 +258,8 @@ void PanoramaOptions::setWidth(unsigned int w, bool keepView)
         m_roi = vigra::Rect2D(m_size);
     } else {
         // for now, do a simple proportional scaling
-        m_roi.setUpperLeft(vigra::Point2D(roundi(scale*m_roi.left()), m_roi.top()));
-        m_roi.setLowerRight(vigra::Point2D(roundi(scale*m_roi.right()), m_roi.bottom()));
+        m_roi.setUpperLeft(vigra::Point2D(hugin_utils::roundi(scale*m_roi.left()), m_roi.top()));
+        m_roi.setLowerRight(vigra::Point2D(hugin_utils::roundi(scale*m_roi.right()), m_roi.bottom()));
         // ensure ROI is inside the panorama
         m_roi &= vigra::Rect2D(m_size);
     }
@@ -275,10 +269,10 @@ void PanoramaOptions::setWidth(unsigned int w, bool keepView)
         if (nocrop) {
             m_roi = vigra::Rect2D(m_size);
         } else {
-            m_roi.setUpperLeft(vigra::Point2D(m_roi.left(), roundi(scale*m_roi.top())));
-            m_roi.setLowerRight(vigra::Point2D(m_roi.right(), roundi(scale*m_roi.bottom())));
+            m_roi.setUpperLeft(vigra::Point2D(m_roi.left(), hugin_utils::roundi(scale*m_roi.top())));
+            m_roi.setLowerRight(vigra::Point2D(m_roi.right(), hugin_utils::roundi(scale*m_roi.bottom())));
             // ensure ROI is inside the panorama
-            m_roi &= Rect2D(m_size);
+            m_roi &= vigra::Rect2D(m_size);
         }
         if (fovCalcSupported(m_projectionFormat)) {
             if (getVFOV() > getMaxVFOV()) {
@@ -352,13 +346,13 @@ void PanoramaOptions::setVFOV(double VFOV)
     src.setSize(vigra::Size2D(360,180));
     transf.createInvTransform(src, *this);
 
-    FDiff2D pmiddle;
+    hugin_utils::FDiff2D pmiddle;
 
     if (VFOV>180 && getMaxVFOV() > 180) {
         // we have crossed the pole
-        transf.transform(pmiddle, FDiff2D(180, 180-VFOV/2 - 0.01));
+        transf.transform(pmiddle, hugin_utils::FDiff2D(180, 180 - VFOV / 2 - 0.01));
     } else {
-        transf.transform(pmiddle, FDiff2D(0, VFOV/2));
+        transf.transform(pmiddle, hugin_utils::FDiff2D(0, VFOV / 2));
     }
     // try to keep the same ROI
     vigra::Size2D oldSize = m_size;
@@ -388,9 +382,9 @@ double PanoramaOptions::getVFOV() const
     src.setSize(vigra::Size2D(360,180));
     transf.createTransform(src, *this);
 
-    FDiff2D pmiddle;
-    FDiff2D pcorner;
-    transf.transform(pmiddle, FDiff2D(0, m_size.y/2.0));
+    hugin_utils::FDiff2D pmiddle;
+    hugin_utils::FDiff2D pcorner;
+    transf.transform(pmiddle, hugin_utils::FDiff2D(0, m_size.y / 2.0));
 //    transf.transform(pcorner, FDiff2D(m_size.x/2.0, m_size.y/2.0));
     double VFOV;
     if (pmiddle.x > 90 ||pmiddle.y < -90) {
@@ -435,7 +429,9 @@ double PanoramaOptions::getVFOV() const
 const std::string PanoramaOptions::fileformatNames[] =
 {
     "JPEG",
+    "JPEG_m",
     "PNG",
+    "PNG_m",
     "TIFF",
     "TIFF_m",
     "TIFF_mask",
@@ -460,6 +456,8 @@ const std::string PanoramaOptions::fileformatNames[] =
 const std::string PanoramaOptions::fileformatExt[] =
 {
     "jpg",
+    "jpg",
+    "png",
     "png",
     "tif",
     "tif",
