@@ -54,8 +54,6 @@
 
 namespace HuginBase {
 
-using namespace hugin_utils;
-    
 void SrcPanoImage::resize(const vigra::Size2D & sz)
 {
         // TODO: check if images have the same orientation.
@@ -90,7 +88,7 @@ void SrcPanoImage::resize(const vigra::Size2D & sz)
                 break;
         }
         
-        m_Size = sz;
+        m_Size.setData(sz);
         // vignetting correction
         m_RadialVigCorrCenterShift.setData(m_RadialVigCorrCenterShift.getData() *scale);
         // resize masks
@@ -156,12 +154,12 @@ bool SrcPanoImage::isInside(vigra::Point2D p, bool ignoreMasks) const
                 // outside image
                 return false;
             }
-            FDiff2D cropCenter;
+            hugin_utils::FDiff2D cropCenter;
             cropCenter.x = m_CropRect.getData().left() + m_CropRect.getData().width()/2.0;
             cropCenter.y = m_CropRect.getData().top() + m_CropRect.getData().height()/2.0;
             double radius2 = std::min(m_CropRect.getData().width()/2.0, m_CropRect.getData().height()/2.0);
             radius2 = radius2 * radius2;
-            FDiff2D pf = FDiff2D(p) - cropCenter;
+            hugin_utils::FDiff2D pf = hugin_utils::FDiff2D(p) - cropCenter;
             insideCrop = (radius2 > pf.x*pf.x+pf.y*pf.y );
         }
     }
@@ -187,12 +185,16 @@ bool SrcPanoImage::getCorrectTCA() const
 }
 
 
-FDiff2D SrcPanoImage::getRadialDistortionCenter() const
-{ return FDiff2D(m_Size.getData())/2.0 + m_RadialDistortionCenterShift.getData(); }
+hugin_utils::FDiff2D SrcPanoImage::getRadialDistortionCenter() const
+{
+    return hugin_utils::FDiff2D(m_Size.getData()) / 2.0 + m_RadialDistortionCenterShift.getData();
+}
 
 
-FDiff2D SrcPanoImage::getRadialVigCorrCenter() const
-{ return (FDiff2D(m_Size.getData())-FDiff2D(1,1))/2.0 + m_RadialVigCorrCenterShift.getData(); }
+hugin_utils::FDiff2D SrcPanoImage::getRadialVigCorrCenter() const
+{
+    return (hugin_utils::FDiff2D(m_Size.getData()) - hugin_utils::FDiff2D(1, 1)) / 2.0 + m_RadialVigCorrCenterShift.getData();
+}
 
 void SrcPanoImage::setCropMode(CropMode val)
 {
@@ -214,7 +216,7 @@ double SrcPanoImage::getExposure() const
 { return 1.0/pow(2.0, m_ExposureValue.getData()); }
 
 void SrcPanoImage::setExposure(const double & val)
-{ m_ExposureValue = log2(1/val); }
+{ m_ExposureValue.setData(log2(1/val)); }
 
 
 bool BaseSrcPanoImage::operator==(const BaseSrcPanoImage & other) const
@@ -349,7 +351,15 @@ bool SrcPanoImage::readEXIF()
         return false;
     }
 
-    image->readMetadata();
+    try
+    {
+        image->readMetadata();
+    }
+    catch (const Exiv2::Error& e)
+    {
+        std::cerr << "Caught Exiv2 exception '" << e.what() << "' for file " << filename << std::endl;
+        return false;
+    }
 
     // look into XMP metadata
     Exiv2::XmpData& xmpData = image->xmpData();
@@ -432,7 +442,7 @@ bool SrcPanoImage::readEXIF()
                 };
             };
         }
-        catch (std::exception e)
+        catch (std::exception& e)
         {
             // just to catch error when image contains no GPano tags
             std::cerr << "Error reading GPano tags from " << filename << "(" << e.what() << ")" << std::endl;
@@ -528,6 +538,21 @@ bool SrcPanoImage::readEXIF()
             };
         };
     };
+    // check results, if 35 mm focal length is too small reset crop factor to 0
+    if (focalLength > 0 && cropFactor > 0 && focalLength*cropFactor < 8)
+    {
+        cropFactor = 0;
+        // check alternative way to calculate crop factor, e.g. when focal length and focal length in 35 mm are given
+        // and are the same, but not a full frame camera
+        const double newCropFactor = Exiv2Helper::getCropFactor(exifData, getWidth(), getHeight());
+        if (newCropFactor > 0)
+        {
+            if (focalLength*newCropFactor > 8)
+            {
+                cropFactor = newCropFactor;
+            }
+        };
+    };
  
     setExifFocalLength(focalLength);
     setExifFocalLength35(eFocalLength35);
@@ -670,10 +695,15 @@ bool SrcPanoImage::readProjectionFromDB()
             double fov;
             if (lensDB.GetFov(lensname, focal, fov))
             {
-                // calculate FOV for given image, take different aspect ratios into account
-                const double newFocal = calcFocalLength(getProjection(), fov, getCropFactor(), vigra::Size2D(3000,2000));
-                const double newFov = calcHFOV(getProjection(), newFocal, getCropFactor(), getSize());
-                setHFOV(newFov);
+                // ignore values if fov is bigger than 120 deg
+                // then probably an invalid value was written earlier
+                if (getProjection() == RECTILINEAR && fov < 120)
+                {
+                    // calculate FOV for given image, take different aspect ratios into account
+                    const double newFocal = calcFocalLength(getProjection(), fov, getCropFactor(), vigra::Size2D(3000, 2000));
+                    const double newFov = calcHFOV(getProjection(), newFocal, getCropFactor(), getSize());
+                    setHFOV(newFov);
+                };
             };
             vigra::Rect2D dbCropRect;
             if (lensDB.GetCrop(lensname, focal, getSize(), dbCropRect))
@@ -735,7 +765,7 @@ double SrcPanoImage::calcHFOV(SrcPanoImage::Projection proj, double fl, double c
     
     // calculate the sensor width and height that fit the ratio
     // the ratio is determined by the size of our image.
-    FDiff2D sensorSize;
+    hugin_utils::FDiff2D sensorSize;
     sensorSize.x = d / sqrt(1 + 1/(r*r));
     sensorSize.y = sensorSize.x / r;
     
@@ -786,7 +816,7 @@ double SrcPanoImage::calcFocalLength(SrcPanoImage::Projection proj, double hfov,
     
     // calculate the sensor width and height that fit the ratio
     // the ratio is determined by the size of our image.
-    FDiff2D sensorSize;
+    hugin_utils::FDiff2D sensorSize;
     sensorSize.x = d / sqrt(1 + 1/(r*r));
     sensorSize.y = sensorSize.x / r;
     
