@@ -22,8 +22,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -46,10 +46,7 @@
 #include "PanoramaVariable.h"
 #include "ImageVariable.h"
 #include "Mask.h"
-
-#ifdef HUGIN_USE_EXIV2
-#include <exiv2/exif.hpp>
-#endif
+#include <map>
 
 #endif // _HSI_IGNORE_SECTION
 
@@ -57,6 +54,9 @@ namespace HuginBase {
 
 class Panorama;
 
+/** typedef for general map for storing metadata in files */
+typedef std::map<std::string, std::string> FileMetaData;
+
 /** Base class containing all the variables, but missing some of the other
  * important functions and with some daft accessors.
  *
@@ -368,22 +368,25 @@ public:
     /** updates the crop factor, the hfov is calculates so that focal length remains the same */
     void updateCropFactor(double focalLength, double newCropFactor);
 
-    /** tries to read cropfactor from lensfun database
+    /** tries to read cropfactor from lens database
         you need to call SrcPanoImage::readEXIF before to fill some values 
         @return true, if information could be read from database */
     bool readCropfactorFromDB();
-    /** tries to read projection and crop area from lensfun database
+    /** tries to read projection and crop area from lens database
         you need to call SrcPanoImage::readEXIF before to fill some values 
         @return true, if information could be read from database */
     bool readProjectionFromDB();
-    /** tries to read distortion data from lensfun database
+    /** tries to read distortion data from lens database
         you need to call SrcPanoImage::readEXIF before to fill some values 
         @return true, if information could be read from database */
     bool readDistortionFromDB();
-    /** tries to read vignetting data from lensfun database
+    /** tries to read vignetting data from lens database
         you need to call SrcPanoImage::readEXIF before to fill some values 
         @return true, if information could be read from database */
     bool readVignettingFromDB();
+    /** constructs the lens name for the database
+        it is the lensname if known, for compact cameras it is constructed from camera maker and camera model */
+    std::string getDBLensName() const;
 
     /** returns true, if image has masks associated */
     bool hasMasks() const;
