@@ -27,19 +27,7 @@
 #include <vector>
 #include <functional>
 #include "hugin_config.h"
-#ifdef HAVE_CXX11
 #include <random>
-#define RANDOMGENERATOR std::mt19937
-#else
-#include <boost/version.hpp>
-#if BOOST_VERSION>104700
-#include <boost/random/taus88.hpp>
-#define RANDOMGENERATOR boost::random::taus88
-#else
-#include <boost/random/mersenne_twister.hpp>
-#define RANDOMGENERATOR boost::mt19937
-#endif
-#endif
 
 #include <vigra/stdimage.hxx>
 #include <vigra/numerictraits.hxx>
@@ -184,10 +172,10 @@ class InvResponseTransform : public ResponseTransform<VTIn>
         
 		void enforceMonotonicity()
 		{
-		    if (Base::m_lutR.size()) {
+		    if (!Base::m_lutR.empty()) {
 				vigra_ext::enforceMonotonicity(Base::m_lutR);
-		        // todo: invert lut, instead of using this functor?
-		        m_lutRInvFunc = vigra_ext::InvLUTFunctor<VT1, LUT>(Base::m_lutR);
+                invertLUT();
+		        m_lutRInvFunc = vigra_ext::LUTFunctor<VT1, LUT>(m_lutRInv);
 			}
 		}
 
@@ -237,9 +225,24 @@ class InvResponseTransform : public ResponseTransform<VTIn>
         
         void emitGLSL(std::ostringstream& oss, std::vector<double>& invLut, std::vector<double>& destLut) const;
 
+    private:
+        void invertLUT()
+        {
+            m_lutRInv.clear();
+            if (!Base::m_lutR.empty())
+            {
+                m_lutRInv.reserve(Base::m_lutR.size());
+                vigra_ext::InvLUTFunctor<VT1, LUT> slowRInvFunc = vigra_ext::InvLUTFunctor<VT1, LUT>(Base::m_lutR);
+                for (int i = 0; i < Base::m_lutR.size(); i++)
+                {
+                    const double f = static_cast<double>(i) / (Base::m_lutR.size() - 1);
+                    m_lutRInv.push_back(slowRInvFunc(f));
+                };
+            };
+        };
     protected: // needs be public?
-        //LUT m_lutRInv;
-        vigra_ext::InvLUTFunctor<VT1, LUT> m_lutRInvFunc;
+        LUT m_lutRInv;
+        vigra_ext::LUTFunctor<VT1, LUT> m_lutRInvFunc;
         LUTD m_destLut;
         vigra_ext::LUTFunctor<VTInCompReal, LUTD> m_destLutFunc;
         double m_destExposure;
@@ -247,7 +250,7 @@ class InvResponseTransform : public ResponseTransform<VTIn>
         double m_intScale;
         
     private:
-        RANDOMGENERATOR Twister;
+        std::mt19937 Twister;
 };
 
 
@@ -370,7 +373,7 @@ ResponseTransform<VTIn>::apply(typename ResponseTransform<VTIn>::VT1 v, const hu
     // first, apply vignetting
 
     ret = ret*calcVigFactor(pos)*m_srcExposure;
-    if (m_lutR.size()) {
+    if (!m_lutR.empty()) {
         return m_lutRFunc(ret);
     } else {
         return ret;
@@ -389,7 +392,7 @@ ResponseTransform<VTIn>::apply(vigra::RGBValue<typename ResponseTransform<VTIn>:
     ret.red() = ret.red() * m_WhiteBalanceRed;
     ret.blue() = ret.blue() * m_WhiteBalanceBlue;
     // apply response curve
-    if (m_lutR.size()) {
+    if (!m_lutR.empty()) {
         return m_lutRFunc(ret);
     } else {
         return ret;
@@ -426,9 +429,9 @@ InvResponseTransform<VTIn,VTOut>::InvResponseTransform(const HuginBase::SrcPanoI
 {
     m_destExposure = 1.0;
     m_intScale = 1;
-    if (Base::m_lutR.size()) {
-        // todo: invert lut, instead of using this functor?
-        m_lutRInvFunc = vigra_ext::InvLUTFunctor<VT1, LUT>(Base::m_lutR);
+    if (!Base::m_lutR.empty()) {
+        invertLUT();
+        m_lutRInvFunc = vigra_ext::LUTFunctor<VT1, LUT>(m_lutRInv);
     }
 }
 
@@ -438,9 +441,9 @@ void InvResponseTransform<VTIn,VTOut>::init(const HuginBase::SrcPanoImage & src)
     m_destExposure = 1.0;
     m_intScale = 1;
     Base::init(src);
-    if (Base::m_lutR.size()) {
-        // todo: invert lut, instead of using this functor?
-        m_lutRInvFunc = vigra_ext::InvLUTFunctor<VT1, LUT>(Base::m_lutR);
+    if (!Base::m_lutR.empty()) {
+        invertLUT();
+        m_lutRInvFunc = vigra_ext::LUTFunctor<VT1, LUT>(m_lutRInv);
     }
 }
 
@@ -458,7 +461,7 @@ void InvResponseTransform<VTIn,VTOut>::setOutput(double destExposure, const LUTD
 {
     m_hdrMode = false;
     m_destLut = destLut;
-    if (m_destLut.size() > 0) {
+    if (!m_destLut.empty()) {
         m_destLutFunc = vigra_ext::LUTFunctor<VTInCompReal, LUTD>(m_destLut);
     }
     m_destExposure = destExposure;
@@ -469,7 +472,7 @@ void InvResponseTransform<VTIn,VTOut>::setOutput(double destExposure, const LUTD
 template <class VTIn, class VTOut>
 double InvResponseTransform<VTIn,VTOut>::dither(const double &v) const
 {
-    RANDOMGENERATOR &mt = const_cast<RANDOMGENERATOR &>(Twister);
+    std::mt19937 &mt = const_cast<std::mt19937 &>(Twister);
     double vFraction = v - floor(v);
     // Only dither values within a certain range of the rounding cutoff point.
     if (vFraction > 0.25 && vFraction <= 0.75) {
@@ -492,7 +495,7 @@ InvResponseTransform<VTIn,VTOut>::apply(VT1 v, const hugin_utils::FDiff2D & pos,
 {
     // inverse response
     typename vigra::NumericTraits<VT1>::RealPromote ret(v);
-    if (Base::m_lutR.size()) {
+    if (!Base::m_lutR.empty()) {
         ret = m_lutRInvFunc(v);
     } else {
         ret /= vigra_ext::LUTTraits<VT1>::max();
@@ -500,7 +503,7 @@ InvResponseTransform<VTIn,VTOut>::apply(VT1 v, const hugin_utils::FDiff2D & pos,
     // inverse vignetting and exposure
     ret *= m_destExposure / (Base::calcVigFactor(pos) * Base::m_srcExposure);
     // apply output transform if required
-    if (m_destLut.size() > 0) {
+    if (!m_destLut.empty()) {
         ret = m_destLutFunc(ret);
     }
     // dither all integer images
@@ -516,7 +519,7 @@ typename vigra::NumericTraits<vigra::RGBValue<typename InvResponseTransform<VTIn
 InvResponseTransform<VTIn,VTOut>::apply(vigra::RGBValue<VT1> v, const hugin_utils::FDiff2D & pos, vigra::VigraFalseType) const
 {
     typename vigra::NumericTraits<vigra::RGBValue<VT1> >::RealPromote ret(v);
-    if (Base::m_lutR.size()) {
+    if (!Base::m_lutR.empty()) {
         ret = m_lutRInvFunc(v);
     } else {
         ret /= vigra_ext::LUTTraits<VT1>::max();
@@ -527,7 +530,7 @@ InvResponseTransform<VTIn,VTOut>::apply(vigra::RGBValue<VT1> v, const hugin_util
     ret.red() /= Base::m_WhiteBalanceRed;
     ret.blue() /= Base::m_WhiteBalanceBlue;
     // apply output transform if required
-    if (m_destLut.size() > 0) {
+    if (!m_destLut.empty()) {
         ret = m_destLutFunc(ret);
     }
     // dither 8 bit images.
@@ -560,26 +563,12 @@ template <class VTIn, class VTOut>
 void
 InvResponseTransform<VTIn,VTOut>::emitGLSL(std::ostringstream& oss, std::vector<double>& invLut, std::vector<double>& destLut) const
 {
-    invLut.clear();
-    invLut.reserve(Base::m_lutR.size());
+    invLut = m_lutRInv;
+    destLut = m_destLut;
 
-    for (int i = 0; i < Base::m_lutR.size(); i++) {
-        double f = static_cast<double>(i) / (Base::m_lutR.size() - 1);
-        double v = m_lutRInvFunc(f);
-        invLut.push_back(v);
-    }
-        
-    destLut.clear();
-    destLut.reserve(m_destLut.size());
-
-    for (typename LUTD::const_iterator lutI = m_destLut.begin(); lutI != m_destLut.end(); ++lutI) {
-        typename LUTD::value_type entry = *lutI;
-        destLut.push_back(entry);
-    }
-
-    double invLutSize = Base::m_lutR.size();
-    double pixelMax = vigra_ext::LUTTraits<VT1>::max();
-    double destLutSize = m_destLut.size();
+    const double invLutSize = Base::m_lutR.size();
+    const double pixelMax = vigra_ext::LUTTraits<VT1>::max();
+    const double destLutSize = m_destLut.size();
 
     oss << "    // invLutSize = " << invLutSize << endl
         << "    // pixelMax = " << pixelMax << endl
@@ -589,7 +578,7 @@ InvResponseTransform<VTIn,VTOut>::emitGLSL(std::ostringstream& oss, std::vector<
         << "    // whiteBalanceRed = " << Base::m_src.getWhiteBalanceRed() << endl
         << "    // whiteBalanceBlue = " << Base::m_src.getWhiteBalanceBlue() << endl;
 
-    if (Base::m_lutR.size() > 0) {
+    if (!Base::m_lutR.empty()) {
         oss << "    p.rgb = p.rgb * " << (invLutSize - 1.0) << ";" << endl
             << "    vec2 invR = texture2DRect(InvLutTexture, vec2(p.r, 0.0)).sq;" << endl
             << "    vec2 invG = texture2DRect(InvLutTexture, vec2(p.g, 0.0)).sq;" << endl
@@ -637,7 +626,7 @@ InvResponseTransform<VTIn,VTOut>::emitGLSL(std::ostringstream& oss, std::vector<
         << (m_destExposure / (Base::m_srcExposure * Base::m_src.getWhiteBalanceBlue())) << ");" << endl
         << "    p.rgb = (p.rgb * exposure_whitebalance) / vig;" << endl;
 
-    if (m_destLut.size() > 0) {
+    if (!m_destLut.empty()) {
         oss << "    p.rgb = p.rgb * " << (destLutSize - 1.0) << ";" << endl
             << "    vec2 destR = texture2DRect(DestLutTexture, vec2(p.r, 0.0)).sq;" << endl
             << "    vec2 destG = texture2DRect(DestLutTexture, vec2(p.g, 0.0)).sq;" << endl
