@@ -36,11 +36,7 @@
 
 #include <vigra_ext/utils.h>
 
-#ifdef HAVE_CXX11
 #include <random>
-#else
-#include <boost/random/mersenne_twister.hpp>
-#endif
 
 //#define DEBUG_WRITE_FILES
 
@@ -235,11 +231,7 @@ bool ditheringNeeded(T const &)
 template <class T>
 struct DitherFunctor
 {
-#ifdef HAVE_CXX11
     std::mt19937 Twister;
-#else
-    boost::mt19937 Twister;
-#endif
 
     typedef T result_type;
 
@@ -250,11 +242,7 @@ struct DitherFunctor
     // Such regions are especially objectionable in the green channel of 8-bit images.
     double dither(const double &v) const
     {
-#ifdef HAVE_CXX11
         std::mt19937 &mt = const_cast<std::mt19937 &>(Twister);
-#else
-        boost::mt19937 &mt = const_cast<boost::mt19937 &>(Twister);
-#endif
         double vFraction = v - floor(v);
         // Only dither values within a certain range of the rounding cutoff point.
         if (vFraction > 0.25 && vFraction <= 0.75) {
@@ -437,7 +425,6 @@ void flatfieldVigCorrection(vigra::triple<ImgIter, ImgIter, ImgAccessor> srcImg,
     typedef typename vigra::NumericTraits<PT>::RealPromote RPT;
     typedef typename FFAccessor::value_type FFT;
     typedef typename vigra::NumericTraits<FFT>::RealPromote RFFT;
-    typedef typename DestAccessor::value_type OPT;
 
     typedef PassThroughFunctor<RPT> RnF;
     typedef LinearTransformFunctor<RPT> LTF;
@@ -487,7 +474,6 @@ void radialVigCorrection(vigra::triple<ImgIter, ImgIter, ImgAccessor> srcImg,
 {
     typedef typename ImgAccessor::value_type PT;
     typedef typename vigra::NumericTraits<PT>::RealPromote RPT;
-    typedef typename ImgAccessor::value_type OutPixelType;
 
     typedef PolySqDistFunctor<4> PolyF;
     typedef PassThroughFunctor<RPT> RnF;
