@@ -36,14 +36,8 @@
 #include <ctime>
 
 #include "hugin_config.h"
-#ifdef HAVE_CXX11
 #include <random>
 #include <functional>
-#else
-#include <boost/random/mersenne_twister.hpp>
-#include <boost/random/uniform_int.hpp>
-#include <boost/random/variate_generator.hpp>
-#endif
 
 //#include "ParameterEsitmator.h"
 
@@ -202,7 +196,7 @@ std::vector<const T *> Ransac::compute(S &parameters,
     SubSetIndexComparator subSetIndexComparator(numForEstimate);
     std::set<int *, SubSetIndexComparator > chosenSubSets(subSetIndexComparator);
     int *curSubSetIndexes;
-    double outlierPercentage = maximalOutlierPercentage;
+    // double outlierPercentage = maximalOutlierPercentage;
     double numerator = log(1.0-desiredProbabilityForNoOutliers);
     double denominator = log(1- pow((double)(1.0-maximalOutlierPercentage), (double)(numForEstimate)));
     int allTries = choose(numDataObjects,numForEstimate);
@@ -214,19 +208,9 @@ std::vector<const T *> Ransac::compute(S &parameters,
     
     // intialize random generator
     maxIndex = numDataObjects - 1;
-#ifdef HAVE_CXX11
     std::mt19937 rng(static_cast<unsigned int>(std::time(0)));
     std::uniform_int_distribution<> distribIndex(0, maxIndex);
     auto randIndex=std::bind(distribIndex, rng);
-#else
-    boost::mt19937 rng;
-    // start with a different seed every time.
-    rng.seed(static_cast<unsigned int>(std::time(0)));
-    // randomly sample points.
-    boost::uniform_int<> distribIndex(0, maxIndex);
-    boost::variate_generator<boost::mt19937&, boost::uniform_int<> >
-                             randIndex(rng, distribIndex);  // glues randomness with mapping
-#endif
 
 //    srand((unsigned)time(NULL)); //seed random number generator
     numTries = (int)(numerator/denominator + 0.5);
