@@ -285,7 +285,7 @@ inline
 V
 getMinComponent(vigra::RGBValue<V> const & v)
 {
-    return std::max(std::max(v.red(), v.green()), v.blue());
+    return std::min(std::min(v.red(), v.green()), v.blue());
 }
 
 /** get the maximum component of a vector (also works for single pixel types...) */
@@ -297,6 +297,104 @@ getMinComponent(V v)
     return v;
 }
 
+template <class VALUETYPE>
+class FindComponentsMinMax
+{
+public:
+    /** the functor's argument type */
+    typedef VALUETYPE argument_type;
+    /** the functor's result type */
+    typedef VALUETYPE result_type;
+    /** \deprecated use argument_type */
+    typedef VALUETYPE value_type;
+
+    /** init min and max */
+    FindComponentsMinMax() : min(vigra::NumericTraits<value_type>::max()), max(vigra::NumericTraits<value_type>::min()), count(0)
+    {}
+
+    /** (re-)init functor (clear min, max)  */
+    void reset()
+    {
+        count = 0;
+    }
+
+    /** update min and max */
+    void operator()(argument_type const & v)
+    {
+        if (count)
+        {
+            if (v < min) min = v;
+            if (max < v) max = v;
+        }
+        else
+        {
+            min = v;
+            max = v;
+        }
+        ++count;
+    }
+
+    /** update min and max with components of RGBValue<VALUETYPE> */
+    void operator()(vigra::RGBValue<VALUETYPE> const & v)
+    {
+        const VALUETYPE vMax = vigra_ext::getMaxComponent(v);
+        const VALUETYPE vMin = vigra_ext::getMinComponent(v);
+        if (count)
+        {
+            if (vMin < min)
+            {
+                min = vMin;
+            };
+            if (vMax > max)
+            {
+                max = vMax;
+            };
+        }
+        else
+        {
+            min = vMin;
+            max = vMax;
+        }
+        ++count;
+    }
+
+    /** the current min */
+    VALUETYPE min;
+    /** the current max */
+    VALUETYPE max;
+    /** the number of values processed so far */
+    unsigned int count;
+};
+
+template<class ImgIter, class ImgAccessor, class AlphaIter, class AlphaAccessor>
+void applyExposureClipMask(vigra::triple<ImgIter, ImgIter, ImgAccessor> image, vigra::triple<AlphaIter, AlphaIter, AlphaAccessor> mask, double lowerLimit, double upperLimit)
+{
+    typedef typename ImgAccessor::value_type ImageValueType;
+    vigra_precondition((image.second - image.first) == (mask.second - mask.first), "applyExposureMask: image and mask have different sizes");
+    const vigra::Diff2D imgSize = image.second - image.first;
+    const double LowerLimit = lowerLimit * LUTTraits<ImageValueType>::max();
+    const double UpperLimit = upperLimit * LUTTraits<ImageValueType>::max();
+
+    // create dest y iterator
+    ImgIter yd(image.first);
+    AlphaIter ymd(mask.first);
+    // loop over the image and transform
+    for (int y = 0; y < imgSize.y; ++y, ++yd.y, ++ymd.y)
+    {
+        // create x iterators
+        ImgIter xd(yd);
+        AlphaIter xmd(ymd);
+        for (int x = 0; x < imgSize.x; ++x, ++xd.x, ++xmd.x)
+        {
+            const double minVal = vigra_ext::getMinComponent(*xd);
+            const double maxVal = vigra_ext::getMaxComponent(*xd);
+            if (minVal < LowerLimit || maxVal > UpperLimit)
+            {
+                *xmd = 0;
+            };
+        }
+    }
+}
 
 /** count pixels that are > 0 in both images */
 struct OverlapSizeCounter
