@@ -32,6 +32,7 @@
 
 #include <algorithms/nona/ComputeImageROI.h>
 #include <algorithms/basic/CalculateOptimalScale.h>
+#include <algorithms/basic/LayerStacks.h>
 #include <nona/RemappedPanoImage.h>
 #include <nona/ImageRemapper.h>
 
@@ -44,7 +45,7 @@
 
 #include "ImageImport.h"
 
-#ifdef _WINDOWS
+#ifdef _WIN32
 #include <direct.h>
 #else
 #include <unistd.h>
@@ -59,21 +60,14 @@
 #include <omp.h>
 #endif
 
-using namespace std;
-using namespace HuginBase;
-using namespace AppBase;
-using namespace HuginBase::Nona;
-using namespace hugin_utils;
-
-
-#define TRACE_IMG(X) {if (_panoDetector.getVerbose() == 1) {TRACE_INFO("i" << _imgData._number << " : " << X << endl);}}
+#define TRACE_IMG(X) {if (_panoDetector.getVerbose() == 1) {TRACE_INFO("i" << _imgData._number << " : " << X << std::endl);}}
 #define TRACE_PAIR(X) {if (_panoDetector.getVerbose() == 1){ TRACE_INFO("i" << _matchData._i1->_number << " <> " \
-                "i" << _matchData._i2->_number << " : " << X << endl);}}
+                "i" << _matchData._i2->_number << " : " << X << std::endl);}}
 
 std::string includeTrailingPathSep(std::string path)
 {
     std::string pathWithSep(path);
-#ifdef _WINDOWS
+#ifdef _WIN32
     if(pathWithSep[pathWithSep.length()-1]!='\\' || pathWithSep[pathWithSep.length()-1]!='/')
     {
         pathWithSep.append("\\");
@@ -93,12 +87,12 @@ std::string getKeyfilenameFor(std::string keyfilesPath, std::string filename)
     if(keyfilesPath.empty())
     {
         //if no path for keyfiles is given we are saving into the same directory as image file
-        newfilename=stripExtension(filename);
+        newfilename=hugin_utils::stripExtension(filename);
     }
     else
     {
-        newfilename=includeTrailingPathSep(keyfilesPath);
-        newfilename.append(stripPath(stripExtension(filename)));
+        newfilename = includeTrailingPathSep(keyfilesPath);
+        newfilename.append(hugin_utils::stripPath(hugin_utils::stripExtension(filename)));
     };
     newfilename.append(".key");
     return newfilename;
@@ -107,15 +101,21 @@ std::string getKeyfilenameFor(std::string keyfilesPath, std::string filename)
 PanoDetector::PanoDetector() :
     _writeAllKeyPoints(false), _verbose(1),
     _sieve1Width(10), _sieve1Height(10), _sieve1Size(100),
-    _kdTreeSearchSteps(200), _kdTreeSecondDistance(0.25), _ransacIters(1000), _ransacDistanceThres(50),
-    _sieve2Width(5), _sieve2Height(5),_sieve2Size(1), _test(false), _cores(0),
-    _minimumMatches(6), _linearMatchLen(1), _downscale(true), _cache(false), _cleanup(false),
-    _keypath(""), _outputFile("default.pto"), _outputGiven(false), _celeste(false), _celesteThreshold(0.5), _celesteRadius(20), 
-    _matchingStrategy(ALLPAIRS)
+    _kdTreeSearchSteps(200), _kdTreeSecondDistance(0.25),
+    _minimumMatches(6), _ransacMode(HuginBase::RANSACOptimizer::AUTO), _ransacIters(1000), _ransacDistanceThres(50),
+    _sieve2Width(5), _sieve2Height(5), _sieve2Size(1),
+    _matchingStrategy(ALLPAIRS), _linearMatchLen(1),
+    _test(false), _cores(0), _downscale(true), _cache(false), _cleanup(false),
+    _celeste(false), _celesteThreshold(0.5), _celesteRadius(20), 
+    _keypath(""), _outputFile("default.pto"), _outputGiven(false), svmModel(NULL)
 {
-    _panoramaInfo = new Panorama();
+    _panoramaInfo = new HuginBase::Panorama();
 }
 
+PanoDetector::~PanoDetector()
+{
+    delete _panoramaInfo;
+}
 
 bool PanoDetector::checkData()
 {
@@ -141,107 +141,107 @@ bool PanoDetector::checkData()
 
 void PanoDetector::printDetails()
 {
-    cout << "Input file           : " << _inputFile << endl;
+    std::cout << "Input file           : " << _inputFile << std::endl;
     if (_keyPointsIdx.size() != 0)
     {
-        cout << "Output file(s)       : keyfile(s) for images";
+        std::cout << "Output file(s)       : keyfile(s) for images";
         for (unsigned int i = 0; i < _keyPointsIdx.size(); ++i)
         {
-            cout << " " << _keyPointsIdx[i] << endl;
+            std::cout << " " << _keyPointsIdx[i] << std::endl;
         }
     }
     else
     {
         if(_writeAllKeyPoints)
         {
-            cout << "Output file(s)       : keyfiles for all images in project" << endl;
+            std::cout << "Output file(s)       : keyfiles for all images in project" << std::endl;
         }
         else
         {
-            cout << "Output file          : " << _outputFile << endl;
+            std::cout << "Output file          : " << _outputFile << std::endl;
         };
     }
     if(_keypath.size()>0)
     {
-        cout <<     "Path to keyfiles     : " << _keypath << endl;
+        std::cout <<     "Path to keyfiles     : " << _keypath << std::endl;
     };
     if(_cleanup)
     {
-        cout << "Cleanup temporary files." << endl;
+        std::cout << "Cleanup temporary files." << std::endl;
     };
     if(_cache)
     {
-        cout << "Automatically cache keypoints files to disc." << endl;
+        std::cout << "Automatically cache keypoints files to disc." << std::endl;
     };
 #ifdef HAVE_OPENMP
-    cout << "Number of threads  : " << (_cores>0 ? _cores : omp_get_max_threads()) << endl << endl;
+    std::cout << "Number of threads  : " << (_cores>0 ? _cores : omp_get_max_threads()) << std::endl << std::endl;
 #endif
-    cout << "Input image options" << endl;
-    cout << "  Downscale to half-size : " << (_downscale?"yes":"no") << endl;
+    std::cout << "Input image options" << std::endl;
+    std::cout << "  Downscale to half-size : " << (_downscale?"yes":"no") << std::endl;
     if(_celeste)
     {
-        cout << "Celeste options" << endl;
-        cout << "  Threshold : " << _celesteThreshold << endl;
-        cout << "  Radius : " << _celesteRadius << endl;
+        std::cout << "Celeste options" << std::endl;
+        std::cout << "  Threshold : " << _celesteThreshold << std::endl;
+        std::cout << "  Radius : " << _celesteRadius << std::endl;
     }
-    cout << "Sieve 1 Options" << endl;
-    cout << "  Width : " << _sieve1Width << endl;
-    cout << "  Height : " << _sieve1Height << endl;
-    cout << "  Size : " << _sieve1Size << endl;
-    cout << "  ==> Maximum keypoints per image : " << _sieve1Size* _sieve1Height* _sieve1Width << endl;
-    cout << "KDTree Options" << endl;
-    cout << "  Search steps : " << _kdTreeSearchSteps << endl;
-    cout << "  Second match distance : " << _kdTreeSecondDistance << endl;
-    cout << "Matching Options" << endl;
+    std::cout << "Sieve 1 Options" << std::endl;
+    std::cout << "  Width : " << _sieve1Width << std::endl;
+    std::cout << "  Height : " << _sieve1Height << std::endl;
+    std::cout << "  Size : " << _sieve1Size << std::endl;
+    std::cout << "  ==> Maximum keypoints per image : " << _sieve1Size* _sieve1Height* _sieve1Width << std::endl;
+    std::cout << "KDTree Options" << std::endl;
+    std::cout << "  Search steps : " << _kdTreeSearchSteps << std::endl;
+    std::cout << "  Second match distance : " << _kdTreeSecondDistance << std::endl;
+    std::cout << "Matching Options" << std::endl;
     switch(_matchingStrategy)
     {
         case ALLPAIRS:
-            cout << "  Mode : All pairs" << endl;
+            std::cout << "  Mode : All pairs" << std::endl;
             break;
         case LINEAR:
-            cout << "  Mode : Linear match with length of " << _linearMatchLen << " image" << endl;
+            std::cout << "  Mode : Linear match with length of " << _linearMatchLen << " image" << std::endl;
             break;
         case MULTIROW:
-            cout << "  Mode : Multi row" << endl;
+            std::cout << "  Mode : Multi row" << std::endl;
             break;
         case PREALIGNED:
-            cout << "  Mode : Prealigned positions" << endl;
+            std::cout << "  Mode : Prealigned positions" << std::endl;
             break;
     };
-    cout << "  Distance threshold : " << _ransacDistanceThres << endl;
-    cout << "RANSAC Options" << endl;
-    cout << "  Mode : ";
+    std::cout << "  Distance threshold : " << _ransacDistanceThres << std::endl;
+    std::cout << "RANSAC Options" << std::endl;
+    std::cout << "  Mode : ";
     switch (_ransacMode)
     {
-        case RANSACOptimizer::AUTO:
-            cout << "auto" << endl;
+        case HuginBase::RANSACOptimizer::AUTO:
+            std::cout << "auto" << std::endl;
             break;
-        case RANSACOptimizer::HOMOGRAPHY:
-            cout << "homography" << endl;
+        case HuginBase::RANSACOptimizer::HOMOGRAPHY:
+            std::cout << "homography" << std::endl;
             break;
-        case RANSACOptimizer::RPY:
-            cout << "roll, pitch, yaw" << endl;
+        case HuginBase::RANSACOptimizer::RPY:
+            std::cout << "roll, pitch, yaw" << std::endl;
             break;
-        case RANSACOptimizer::RPYV:
-            cout << "roll, pitch, yaw, fov" << endl;
+        case HuginBase::RANSACOptimizer::RPYV:
+            std::cout << "roll, pitch, yaw, fov" << std::endl;
             break;
-        case RANSACOptimizer::RPYVB:
-            cout << "roll, pitch, yaw, fov, distortion" << endl;
+        case HuginBase::RANSACOptimizer::RPYVB:
+            std::cout << "roll, pitch, yaw, fov, distortion" << std::endl;
             break;
     }
-    cout << "  Iterations : " << _ransacIters << endl;
-    cout << "  Distance threshold : " << _ransacDistanceThres << endl;
-    cout << "Minimum matches per image pair: " << _minimumMatches << endl;
-    cout << "Sieve 2 Options" << endl;
-    cout << "  Width : " << _sieve2Width << endl;
-    cout << "  Height : " << _sieve2Height << endl;
-    cout << "  Size : " << _sieve2Size << endl;
-    cout << "  ==> Maximum matches per image pair : " << _sieve2Size* _sieve2Height* _sieve2Width << endl;
+    std::cout << "  Iterations : " << _ransacIters << std::endl;
+    std::cout << "  Distance threshold : " << _ransacDistanceThres << std::endl;
+    std::cout << "Minimum matches per image pair: " << _minimumMatches << std::endl;
+    std::cout << "Sieve 2 Options" << std::endl;
+    std::cout << "  Width : " << _sieve2Width << std::endl;
+    std::cout << "  Height : " << _sieve2Height << std::endl;
+    std::cout << "  Size : " << _sieve2Size << std::endl;
+    std::cout << "  ==> Maximum matches per image pair : " << _sieve2Size* _sieve2Height* _sieve2Width << std::endl;
 }
 
 void PanoDetector::printFilenames()
 {
-    cout << endl << "Project contains the following images:" << endl;
+    std::cout << std::endl << "Project contains the following images:" << std::endl;
     for(unsigned int i=0; i<_panoramaInfo->getNrOfImages(); i++)
     {
         std::string name(_panoramaInfo->getImage(i).getFilename());
@@ -249,7 +249,7 @@ void PanoDetector::printFilenames()
         {
             name=name.substr(_prefix.length(),name.length()-_prefix.length());
         }
-        cout << "Image " << i << endl << "  Imagefile: " << name << endl;
+        std::cout << "Image " << i << std::endl << "  Imagefile: " << name << std::endl;
         bool writeKeyfileForImage=false;
         if(_keyPointsIdx.size()>0)
         {
@@ -265,17 +265,17 @@ void PanoDetector::printFilenames()
             {
                 name=name.substr(_prefix.length(),name.length()-_prefix.length());
             }
-            cout << "  Keyfile  : " << name;
+            std::cout << "  Keyfile  : " << name;
             if(writeKeyfileForImage)
             {
-                cout << " (will be generated)" << endl;
+                std::cout << " (will be generated)" << std::endl;
             }
             else
             {
-                cout << (_filesData[i]._hasakeyfile?" (will be loaded)":" (will be generated)") << endl;
+                std::cout << (_filesData[i]._hasakeyfile?" (will be loaded)":" (will be generated)") << std::endl;
             };
         };
-        cout << "  Remapped : " << (_filesData[i]._needsremap?"yes":"no") << endl;
+        std::cout << "  Remapped : " << (_filesData[i].NeedsRemapping()?"yes":"no") << std::endl;
     };
 };
 
@@ -284,6 +284,7 @@ class Runnable
 public:
     Runnable() {};
     virtual void run() = 0;
+    virtual ~Runnable() {};
 };
 
 // definition of a runnable class for image data
@@ -291,7 +292,7 @@ class ImgDataRunnable : public Runnable
 {
 public:
     ImgDataRunnable(PanoDetector::ImgData& iImageData, const PanoDetector& iPanoDetector) : Runnable(),
-        _imgData(iImageData), _panoDetector(iPanoDetector) {};
+        _panoDetector(iPanoDetector), _imgData(iImageData) {};
 
     virtual void run()
     {
@@ -317,7 +318,7 @@ class WriteKeyPointsRunnable : public Runnable
 {
 public:
     WriteKeyPointsRunnable(PanoDetector::ImgData& iImageData, const PanoDetector& iPanoDetector) :
-        _imgData(iImageData), _panoDetector(iPanoDetector) {};
+        _panoDetector(iPanoDetector), _imgData(iImageData) {};
 
     virtual void run()
     {
@@ -342,7 +343,7 @@ class LoadKeypointsDataRunnable : public Runnable
 {
 public:
     LoadKeypointsDataRunnable(PanoDetector::ImgData& iImageData, const PanoDetector& iPanoDetector) :
-        _imgData(iImageData), _panoDetector(iPanoDetector) {};
+        _panoDetector(iPanoDetector), _imgData(iImageData) {};
 
     virtual void run()
     {
@@ -361,7 +362,7 @@ class MatchDataRunnable : public Runnable
 {
 public:
     MatchDataRunnable(PanoDetector::MatchData& iMatchData, const PanoDetector& iPanoDetector) :
-        _matchData(iMatchData), _panoDetector(iPanoDetector) {};
+        _panoDetector(iPanoDetector), _matchData(iMatchData) {};
 
     virtual void run()
     {
@@ -381,17 +382,17 @@ private:
 
 bool PanoDetector::LoadSVMModel()
 {
-    string model_file = ("celeste.model");
-    ifstream test(model_file.c_str());
+    std::string model_file = ("celeste.model");
+    std::ifstream test(model_file.c_str());
     if (!test.good())
     {
-        string install_path_model=hugin_utils::GetDataDir();
+        std::string install_path_model=hugin_utils::GetDataDir();
         install_path_model.append(model_file);
-        ifstream test2(install_path_model.c_str());
+        std::ifstream test2(install_path_model.c_str());
         if (!test2.good())
         {
-            cout << endl << "Couldn't open SVM model file " << model_file << endl;
-            cout << "Also tried " << install_path_model << endl << endl;
+            std::cout << std::endl << "Couldn't open SVM model file " << model_file << std::endl;
+            std::cout << "Also tried " << install_path_model << std::endl << std::endl;
             return false;
         };
         model_file = install_path_model;
@@ -453,13 +454,17 @@ void PanoDetector::run()
         if(!aB->second._hasakeyfile)
         {
             maxImageSize=std::max<unsigned long>(aB->second._detectWidth*aB->second._detectHeight,maxImageSize);
-            if(aB->second._needsremap)
+            if(aB->second.NeedsRemapping())
             {
                 withRemap=true;
             };
         };
     };
 #ifdef HAVE_OPENMP
+    if (_cores == 0)
+    {
+        setCores(omp_get_max_threads());
+    };
     if (maxImageSize != 0)
     {
         unsigned long long maxCores;
@@ -478,10 +483,6 @@ void PanoDetector::run()
         {
             maxCores=1;
         }
-        if (_cores == 0)
-        {
-            setCores(omp_get_max_threads());
-        }
         if(maxCores<_cores)
         {
             if(getVerbose()>0)
@@ -512,7 +513,7 @@ void PanoDetector::run()
     }
 
     // 2. run analysis of images or keypoints
-#if _WINDOWS
+#if _WIN32
     //multi threading of image loading results sometime in a race condition
     //try to prevent this by initialisation of codecManager before
     //running multi threading part
@@ -522,7 +523,7 @@ void PanoDetector::run()
     {
         if (_verbose > 0)
         {
-            TRACE_INFO(endl << "--- Analyze Images ---" << endl);
+            TRACE_INFO(std::endl << "--- Analyze Images ---" << std::endl);
         }
         for (unsigned int i = 0; i < _keyPointsIdx.size(); ++i)
         {
@@ -531,7 +532,7 @@ void PanoDetector::run()
     }
     else
     {
-        TRACE_INFO(endl << "--- Analyze Images ---" << endl);
+        TRACE_INFO(std::endl << "--- Analyze Images ---" << std::endl);
         if (getMatchingStrategy() == MULTIROW)
         {
             // when using multirow, don't analyse stacks with linked positions
@@ -585,12 +586,12 @@ void PanoDetector::run()
 
     if(_cache)
     {
-        TRACE_INFO(endl << "--- Cache keyfiles to disc ---" << endl);
+        TRACE_INFO(std::endl << "--- Cache keyfiles to disc ---" << std::endl);
         for (ImgDataIt_t aB = _filesData.begin(); aB != _filesData.end(); ++aB)
         {
             if (!aB->second._hasakeyfile)
             {
-                TRACE_INFO("i" << aB->second._number << " : Caching keypoints..." << endl);
+                TRACE_INFO("i" << aB->second._number << " : Caching keypoints..." << std::endl);
                 writeKeyfile(aB->second);
             };
         };
@@ -622,7 +623,7 @@ void PanoDetector::run()
                     //check, which image pairs are already connected by control points
                     std::vector<HuginBase::UIntSet> connectedImages(_panoramaInfo->getNrOfImages());
                     HuginBase::CPVector cps=_panoramaInfo->getCtrlPoints();
-                    for(HuginBase::CPVector::const_iterator it=cps.begin();it!=cps.end(); it++)
+                    for(HuginBase::CPVector::const_iterator it=cps.begin();it!=cps.end(); ++it)
                     {
                         if((*it).mode==HuginBase::ControlPoint::X_Y)
                         {
@@ -650,25 +651,25 @@ void PanoDetector::run()
     if (_keyPointsIdx.size() != 0)
     {
         //Write all keyfiles
-        TRACE_INFO(endl<< "--- Write Keyfiles output ---" << endl << endl);
+        TRACE_INFO(std::endl<< "--- Write Keyfiles output ---" << std::endl << std::endl);
         for (unsigned int i = 0; i < _keyPointsIdx.size(); ++i)
         {
             writeKeyfile(_filesData[_keyPointsIdx[i]]);
         };
         if(_outputGiven)
         {
-            cout << endl << "Warning: You have given the --output switch." << endl
-                 << "This switch is not compatible with the --writekeyfile or --kall switch." << endl
-                 << "If you want to generate the keyfiles and" << endl
-                 << "do the matching in the same run use the --cache switch instead." << endl << endl;
+            std::cout << std::endl << "Warning: You have given the --output switch." << std::endl
+                 << "This switch is not compatible with the --writekeyfile or --kall switch." << std::endl
+                 << "If you want to generate the keyfiles and" << std::endl
+                 << "do the matching in the same run use the --cache switch instead." << std::endl << std::endl;
         };
     }
     else
     {
         /// Write output project
-        TRACE_INFO(endl<< "--- Write Project output ---" << endl);
+        TRACE_INFO(std::endl<< "--- Write Project output ---" << std::endl);
         writeOutput();
-        TRACE_INFO("Written output to " << _outputFile << endl << endl);
+        TRACE_INFO("Written output to " << _outputFile << std::endl << std::endl);
     };
 }
 
@@ -714,7 +715,7 @@ bool PanoDetector::match(std::vector<HuginBase::UIntSet> &checkedPairs)
         }
     }
     // 4. find matches
-    TRACE_INFO(endl<< "--- Find pair-wise matches ---" << endl);
+    TRACE_INFO(std::endl<< "--- Find pair-wise matches ---" << std::endl);
     for (size_t i = 0; i < matchesData.size(); ++i)
     {
         queue.push_back(new MatchDataRunnable(matchesData[i], *this));
@@ -728,7 +729,7 @@ bool PanoDetector::match(std::vector<HuginBase::UIntSet> &checkedPairs)
         for (size_t j = 0; j < aM._matches.size(); ++j)
         {
             const lfeat::PointMatchPtr& aPM = aM._matches[j];
-            _panoramaInfo->addCtrlPoint(ControlPoint(aM._i1->_number, aPM->_img1_x, aPM->_img1_y,
+            _panoramaInfo->addCtrlPoint(HuginBase::ControlPoint(aM._i1->_number, aPM->_img1_x, aPM->_img1_y,
                 aM._i2->_number, aPM->_img2_x, aPM->_img2_y));
         };
     };
@@ -737,10 +738,10 @@ bool PanoDetector::match(std::vector<HuginBase::UIntSet> &checkedPairs)
 
 bool PanoDetector::loadProject()
 {
-    ifstream ptoFile(_inputFile.c_str());
+    std::ifstream ptoFile(_inputFile.c_str());
     if (ptoFile.bad())
     {
-        cerr << "ERROR: could not open file: '" << _inputFile << "'!" << endl;
+        std::cerr << "ERROR: could not open file: '" << _inputFile << "'!" << std::endl;
         return false;
     }
     _prefix=hugin_utils::getPathPrefix(_inputFile);
@@ -748,7 +749,7 @@ bool PanoDetector::loadProject()
     {
         // Get the current working directory:
         char* buffer;
-#ifdef _WINDOWS
+#ifdef _WIN32
 #define getcwd _getcwd
 #endif
         if((buffer=getcwd(NULL,0))!=NULL)
@@ -762,7 +763,7 @@ bool PanoDetector::loadProject()
     AppBase::DocumentData::ReadWriteError err = _panoramaInfo->readData(ptoFile);
     if (err != AppBase::DocumentData::SUCCESSFUL)
     {
-        cerr << "ERROR: couldn't parse panos tool script: '" << _inputFile << "'!" << endl;
+        std::cerr << "ERROR: couldn't parse panos tool script: '" << _inputFile << "'!" << std::endl;
         return false;
     }
 
@@ -771,18 +772,18 @@ bool PanoDetector::loadProject()
     _panoramaInfoCopy=_panoramaInfo->duplicate();
 
     // Add images found in the project file to _filesData
-    unsigned int nImg = _panoramaInfo->getNrOfImages();
+    const unsigned int nImg = _panoramaInfo->getNrOfImages();
     unsigned int imgWithKeyfile=0;
     for (unsigned int imgNr = 0; imgNr < nImg; ++imgNr)
     {
         // insert the image in the map
-        _filesData.insert(make_pair(imgNr, ImgData()));
+        _filesData.insert(std::make_pair(imgNr, ImgData()));
 
         // get the data
         ImgData& aImgData = _filesData[imgNr];
 
         // get a copy of image info
-        SrcPanoImage img = _panoramaInfoCopy.getSrcImage(imgNr);
+        HuginBase::SrcPanoImage img = _panoramaInfoCopy.getSrcImage(imgNr);
 
         // set the name
         aImgData._name = img.getFilename();
@@ -795,19 +796,18 @@ bool PanoDetector::loadProject()
         img.setY(0);
         img.setZ(0);
         img.setActive(true);
-        img.setResponseType(SrcPanoImage::RESPONSE_LINEAR);
-        img.setExposureValue(0);
         _panoramaInfoCopy.setImage(imgNr,img);
 
         // Number pointing to image info in _panoramaInfo
         aImgData._number = imgNr;
 
-        aImgData._needsremap=(img.getHFOV()>=65 && img.getProjection() != SrcPanoImage::FISHEYE_STEREOGRAPHIC);
+        bool needsremap=(img.getHFOV()>=65 && img.getProjection() != HuginBase::SrcPanoImage::FISHEYE_STEREOGRAPHIC);
         // set image detection size
-        if(aImgData._needsremap)
+        if(needsremap)
         {
-            _filesData[imgNr]._detectWidth = max(img.getSize().width(),img.getSize().height());
-            _filesData[imgNr]._detectHeight = max(img.getSize().width(),img.getSize().height());
+            _filesData[imgNr]._detectWidth = std::max(img.getSize().width(),img.getSize().height());
+            _filesData[imgNr]._detectHeight = std::max(img.getSize().width(),img.getSize().height());
+            _filesData[imgNr].SetSizeMode(ImgData::REMAPPED);
         }
         else
         {
@@ -815,16 +815,21 @@ bool PanoDetector::loadProject()
             _filesData[imgNr]._detectHeight = img.getSize().height();
         };
 
-        if (_downscale)
+        // don't downscale if downscale image is smaller than 1000 pixel
+        if (_downscale && std::min(img.getSize().width(), img.getSize().height()) > 2000)
         {
             _filesData[imgNr]._detectWidth >>= 1;
             _filesData[imgNr]._detectHeight >>= 1;
+            if (!_filesData[imgNr].NeedsRemapping())
+            {
+                _filesData[imgNr].SetSizeMode(ImgData::DOWNSCALED);
+            };
         }
 
         // set image remapping options
-        if(aImgData._needsremap)
+        if (aImgData.GetSizeMode() == ImgData::REMAPPED)
         {
-            aImgData._projOpts.setProjection(PanoramaOptions::STEREOGRAPHIC);
+            aImgData._projOpts.setProjection(HuginBase::PanoramaOptions::STEREOGRAPHIC);
             aImgData._projOpts.setHFOV(250);
             aImgData._projOpts.setVFOV(250);
             aImgData._projOpts.setWidth(250);
@@ -834,7 +839,7 @@ bool PanoDetector::loadProject()
             // The old code did not work with images with images with a FOV
             // approaching 180 degrees
             vigra::Rect2D roi=estimateOutputROI(_panoramaInfoCopy,aImgData._projOpts,imgNr);
-            double scalefactor = max((double)_filesData[imgNr]._detectWidth / roi.width(),
+            double scalefactor = std::max((double)_filesData[imgNr]._detectWidth / roi.width(),
                                      (double)_filesData[imgNr]._detectHeight / roi.height() );
 
             // resize output canvas
@@ -907,38 +912,24 @@ void PanoDetector::CleanupKeyfiles()
     };
 };
 
-struct SortVectorByExposure
-{
-    SortVectorByExposure(const HuginBase::Panorama* pano) : m_pano(pano) {};
-    bool operator()(const size_t& img1, const size_t& img2)
-    {
-        return m_pano->getImage(img1).getExposureValue() < m_pano->getImage(img2).getExposureValue();
-    }
-private:
-    const HuginBase::Panorama* m_pano;
-};
-
 void PanoDetector::buildMultiRowImageSets()
 {
-    HuginBase::ConstStandardImageVariableGroups variable_groups(*_panoramaInfo);
-    HuginBase::UIntSetVector imageGroups = variable_groups.getStacks().getPartsSet();
+    std::vector<HuginBase::UIntVector> stacks = HuginBase::getSortedStacks(_panoramaInfo);
     //get image with median exposure for search with cp generator
-    for (size_t imgGroup = 0; imgGroup < imageGroups.size(); ++imgGroup)
+    for (size_t i = 0; i < stacks.size(); ++i)
     {
-        HuginBase::UIntVector stackImages(imageGroups[imgGroup].begin(), imageGroups[imgGroup].end());
-        std::sort(stackImages.begin(), stackImages.end(), SortVectorByExposure(_panoramaInfo));
         size_t index = 0;
-        if (_panoramaInfo->getImage(*(stackImages.begin())).getExposureValue() != _panoramaInfo->getImage(*(stackImages.rbegin())).getExposureValue())
+        if (_panoramaInfo->getImage(*(stacks[i].begin())).getExposureValue() != _panoramaInfo->getImage(*(stacks[i].rbegin())).getExposureValue())
         {
-            index = stackImages.size() / 2;
+            index = stacks[i].size() / 2;
         };
-        _image_layer.insert(stackImages[index]);
-        if (stackImages.size()>1)
+        _image_layer.insert(stacks[i][index]);
+        if (stacks[i].size()>1)
         {
             //build list for stacks, consider only unlinked stacks
-            if (!_panoramaInfo->getImage(*(stackImages.begin())).YawisLinked())
+            if (!_panoramaInfo->getImage(*(stacks[i].begin())).YawisLinked())
             {
-                _image_stacks.push_back(stackImages);
+                _image_stacks.push_back(stacks[i]);
             };
         };
     };
@@ -980,7 +971,7 @@ bool PanoDetector::matchMultiRow()
         {
             const size_t img1 = *it;
             HuginBase::UIntSet::const_iterator it2 = it;
-            it2++;
+            ++it2;
             if (it2 != _image_layer.end())
             {
                 const size_t img2 = *it2;
@@ -1001,7 +992,7 @@ bool PanoDetector::matchMultiRow()
             };
         };
     };
-    TRACE_INFO(endl<< "--- Find matches ---" << endl);
+    TRACE_INFO(std::endl<< "--- Find matches ---" << std::endl);
     for (size_t i = 0; i < matchesData.size(); ++i)
     {
         queue.push_back(new MatchDataRunnable(matchesData[i], *this));
@@ -1015,7 +1006,7 @@ bool PanoDetector::matchMultiRow()
         for (size_t j = 0; j < aM._matches.size(); ++j)
         {
             const lfeat::PointMatchPtr& aPM = aM._matches[j];
-            _panoramaInfo->addCtrlPoint(ControlPoint(aM._i1->_number, aPM->_img1_x, aPM->_img1_y,
+            _panoramaInfo->addCtrlPoint(HuginBase::ControlPoint(aM._i1->_number, aPM->_img1_x, aPM->_img1_y,
                 aM._i2->_number, aPM->_img2_x, aPM->_img2_y));
         };
     };
@@ -1023,15 +1014,14 @@ bool PanoDetector::matchMultiRow()
     // step 2: connect all image groups
     queue.clear();
     matchesData.clear();
-    Panorama mediumPano=_panoramaInfo->getSubset(_image_layer);
-    HuginBase::CPGraph graph;
-    HuginBase::createCPGraph(mediumPano, graph);
-    HuginBase::CPComponents comps;
-    unsigned int n = HuginBase::findCPComponents(graph, comps);
+    HuginBase::Panorama mediumPano = _panoramaInfo->getSubset(_image_layer);
+    HuginGraph::ImageGraph graph(mediumPano);
+    const HuginGraph::ImageGraph::Components comps = graph.GetComponents();
+    const size_t n = comps.size();
     if(n>1)
     {
-        vector<unsigned int> ImagesGroups;
-        for(unsigned int i=0; i<n; i++)
+        std::vector<unsigned int> ImagesGroups;
+        for(size_t i=0; i<n; i++)
         {
             HuginBase::UIntSet::iterator imgIt = _image_layer.begin();
             std::advance(imgIt, *(comps[i].begin()));
@@ -1070,7 +1060,7 @@ bool PanoDetector::matchMultiRow()
                 checkedImagePairs[img2].insert(img1);
             };
         };
-        TRACE_INFO(endl<< "--- Find matches in images groups ---" << endl);
+        TRACE_INFO(std::endl<< "--- Find matches in images groups ---" << std::endl);
         for (size_t i = 0; i < matchesData.size(); ++i)
         {
             queue.push_back(new MatchDataRunnable(matchesData[i], *this));
@@ -1083,7 +1073,7 @@ bool PanoDetector::matchMultiRow()
             for (size_t j = 0; j < aM._matches.size(); ++j)
             {
                 const lfeat::PointMatchPtr& aPM = aM._matches[j];
-                _panoramaInfo->addCtrlPoint(ControlPoint(aM._i1->_number, aPM->_img1_x, aPM->_img1_y,
+                _panoramaInfo->addCtrlPoint(HuginBase::ControlPoint(aM._i1->_number, aPM->_img1_x, aPM->_img1_y,
                     aM._i2->_number, aPM->_img2_x, aPM->_img2_y));
             };
         };
@@ -1092,13 +1082,13 @@ bool PanoDetector::matchMultiRow()
     queue.clear();
     matchesData.clear();
     HuginBase::Panorama optPano=_panoramaInfo->getSubset(_image_layer);
-    HuginBase::createCPGraph(optPano, graph);
-    if(HuginBase::findCPComponents(graph, comps)==1)
+    HuginGraph::ImageGraph graph2(optPano);
+    if(graph2.IsConnected())
     {
         if(_image_layer.size()>2)
         {
             //reset translation parameters
-            VariableMapVector varMapVec=optPano.getVariables();
+            HuginBase::VariableMapVector varMapVec = optPano.getVariables();
             for(size_t i=0; i<varMapVec.size(); i++)
             {
                 map_get(varMapVec[i], "TrX").setValue(0);
@@ -1108,8 +1098,8 @@ bool PanoDetector::matchMultiRow()
             optPano.updateVariables(varMapVec);
             //next steps happens only when all images are connected;
             //now optimize panorama
-            PanoramaOptions opts = optPano.getOptions();
-            opts.setProjection(PanoramaOptions::EQUIRECTANGULAR);
+            HuginBase::PanoramaOptions opts = optPano.getOptions();
+            opts.setProjection(HuginBase::PanoramaOptions::EQUIRECTANGULAR);
             opts.optimizeReferenceImage=0;
             // calculate proper scaling, 1:1 resolution.
             // Otherwise optimizer distances are meaningless.
@@ -1123,8 +1113,7 @@ bool PanoDetector::matchMultiRow()
             optPano.setOptions(opts);
 
             //generate optimize vector, optimize only yaw and pitch
-            OptimizeVector optvars;
-            const SrcPanoImage& anchorImage = optPano.getImage(opts.optimizeReferenceImage);
+            HuginBase::OptimizeVector optvars;
             for (unsigned i=0; i < optPano.getNrOfImages(); i++)
             {
                 std::set<std::string> imgopt;
@@ -1143,11 +1132,11 @@ bool PanoDetector::matchMultiRow()
             optPano.setOptimizeVector(optvars);
 
             // remove vertical and horizontal control points
-            CPVector cps = optPano.getCtrlPoints();
-            CPVector newCP;
-            for (CPVector::const_iterator it = cps.begin(); it != cps.end(); it++)
+            HuginBase::CPVector cps = optPano.getCtrlPoints();
+            HuginBase::CPVector newCP;
+            for (HuginBase::CPVector::const_iterator it = cps.begin(); it != cps.end(); ++it)
             {
-                if (it->mode == ControlPoint::X_Y)
+                if (it->mode == HuginBase::ControlPoint::X_Y)
                 {
                     newCP.push_back(*it);
                 }
@@ -1187,18 +1176,18 @@ bool PanoDetector::matchMultiRow()
     return true;
 };
 
-bool PanoDetector::matchPrealigned(Panorama* pano, std::vector<HuginBase::UIntSet> &connectedImages, std::vector<size_t> imgMap, bool exactOverlap)
+bool PanoDetector::matchPrealigned(HuginBase::Panorama* pano, std::vector<HuginBase::UIntSet> &connectedImages, std::vector<size_t> imgMap, bool exactOverlap)
 {
     RunnableVector queue;
     MatchData_t matchesData;
-    Panorama tempPano=pano->duplicate();
+    HuginBase::Panorama tempPano = pano->duplicate();
     if(!exactOverlap)
     {
         // increase hfov by 25 % to handle narrow overlaps (or even no overlap) better
-        VariableMapVector varMapVec=tempPano.getVariables();
+        HuginBase::VariableMapVector varMapVec = tempPano.getVariables();
         for(size_t i=0; i<tempPano.getNrOfImages(); i++)
         {
-            Variable hfovVar=map_get(varMapVec[i], "v");
+            HuginBase::Variable& hfovVar = map_get(varMapVec[i], "v");
             hfovVar.setValue(std::min(360.0, 1.25 * hfovVar.getValue()));
         };
         tempPano.updateVariables(varMapVec);
@@ -1225,7 +1214,7 @@ bool PanoDetector::matchPrealigned(Panorama* pano, std::vector<HuginBase::UIntSe
         };
     };
 
-    TRACE_INFO(endl<< "--- Find matches for overlapping images ---" << endl);
+    TRACE_INFO(std::endl<< "--- Find matches for overlapping images ---" << std::endl);
     for (size_t i = 0; i < matchesData.size(); ++i)
     {
         queue.push_back(new MatchDataRunnable(matchesData[i], *this));
@@ -1239,7 +1228,7 @@ bool PanoDetector::matchPrealigned(Panorama* pano, std::vector<HuginBase::UIntSe
         for (size_t j = 0; j < aM._matches.size(); ++j)
         {
             const lfeat::PointMatchPtr& aPM = aM._matches[j];
-            _panoramaInfo->addCtrlPoint(ControlPoint(aM._i1->_number, aPM->_img1_x, aPM->_img1_y,
+            _panoramaInfo->addCtrlPoint(HuginBase::ControlPoint(aM._i1->_number, aPM->_img1_x, aPM->_img1_y,
                 aM._i2->_number, aPM->_img2_x, aPM->_img2_y));
         };
     };
