@@ -25,7 +25,7 @@
 #include <hugin_config.h>
 
 #include "PanoDetectorDefs.h"
-#include "hugin_utils/shared_ptr.h"
+#include <memory>
 #include <string>
 #include <map>
 #include <localfeatures/Image.h>
@@ -49,7 +49,7 @@ public:
     typedef std::vector<std::string>						FileNameList_t;
     typedef std::vector<std::string>::iterator				FileNameListIt_t;
     typedef KDTreeSpace::KDTree<KDElemKeyPoint, double>		KPKDTree;
-    typedef sharedPtrNamespace::shared_ptr<KPKDTree>        KPKDTreePtr;
+    typedef std::shared_ptr<KPKDTree>        KPKDTreePtr;
 
     typedef lfeat::KeyPointDetector KeyPointDetector;
 
@@ -63,6 +63,7 @@ public:
     };
 
     PanoDetector();
+    ~PanoDetector();
 
     bool checkData();
     void printDetails();
@@ -385,6 +386,8 @@ private:
 public:
     struct ImgData
     {
+        /** enumeration of different detection modes */
+        enum SizeMode { DOWNSCALED, REMAPPED, FULLSIZE};
         std::string			_name;
 
         int					_number;
@@ -394,7 +397,6 @@ public:
         lfeat::Image		_ii;
         vigra::BImage		_distancemap;
 
-        bool				_needsremap;
         HuginBase::PanoramaOptions 	_projOpts;
 
         bool 					_hasakeyfile;
@@ -414,11 +416,29 @@ public:
             _number = 0;
             _detectWidth = 0;
             _detectHeight = 0;
-            _needsremap = false;
+            m_sizeMode = FULLSIZE;
             _hasakeyfile = false;
             _descLength = 0;
             _flann_index = NULL;
         }
+
+        ~ImgData()
+        {
+            if (_flann_index != NULL)
+            {
+                delete _flann_index;
+            };
+            if (_flann_descriptors.rows + _flann_descriptors.cols > 0)
+            {
+                delete[]_flann_descriptors.ptr();
+            };
+        }
+        void SetSizeMode(const SizeMode newSizeMode) { m_sizeMode = newSizeMode; };
+        SizeMode GetSizeMode() const { return m_sizeMode; };
+        bool IsDownscale() const { return m_sizeMode == DOWNSCALED; };
+        bool NeedsRemapping() const { return m_sizeMode == REMAPPED; };
+    private:
+        SizeMode m_sizeMode;
     };
 
     typedef std::map<int, ImgData>					ImgData_t;
