@@ -29,11 +29,7 @@
 
 #include <fstream>
 #include <sstream>
-#ifdef _WIN32
 #include <getopt.h>
-#else
-#include <unistd.h>
-#endif
 
 #include <hugin_basic.h>
 #include <hugin_utils/stl_utils.h>
@@ -51,7 +47,7 @@
 
 static void usage(const char* name)
 {
-    std::cerr << name << ": optimize image positions" << std::endl
+    std::cout << name << ": optimize image positions" << std::endl
         << "autooptimiser version " << hugin_utils::GetHuginVersion() << std::endl
         << std::endl
         << "Usage:  " << name << " [options] input.pto" << std::endl
@@ -87,6 +83,12 @@ int main(int argc, char* argv[])
     // parse arguments
     const char* optstring = "alho:npqsv:m";
     int c;
+    static struct option longOptions[] =
+    {
+        { "output", required_argument, NULL, 'o'},
+        { "help", no_argument, NULL, 'h' },
+        0
+    };
     std::string output;
     bool doPairwise = false;
     bool doAutoOpt = false;
@@ -96,7 +98,7 @@ int main(int argc, char* argv[])
     bool quiet = false;
     bool doPhotometric = false;
     double hfov = 0.0;
-    while ((c = getopt (argc, argv, optstring)) != -1)
+    while ((c = getopt_long(argc, argv, optstring, longOptions, nullptr)) != -1)
     {
         switch (c)
         {
@@ -130,14 +132,27 @@ int main(int argc, char* argv[])
             case 'm':
                 doPhotometric = true;
                 break;
+            case ':':
+            case '?':
+                // missing argument or invalid switch
+                return 1;
+                break;
             default:
+                // this should not happen
                 abort ();
         }
     }
 
     if (argc - optind != 1)
     {
-        usage(hugin_utils::stripPath(argv[0]).c_str());
+        if (argc - optind < 1)
+        {
+            std::cerr << hugin_utils::stripPath(argv[0]) << ": No project file given." << std::endl;
+        }
+        else
+        {
+            std::cerr << hugin_utils::stripPath(argv[0]) << ": Only one project file expected." << std::endl;
+        };
         return 1;
     }
 
@@ -281,26 +296,73 @@ int main(int argc, char* argv[])
         // avoid perspective projection if field of view > 100 deg
         const double mf = 100;
         bool changedProjection=false;
-        if (vfov < mf)
+        if (pano.getNrOfImages() == 1)
         {
-            // cylindrical or rectilinear
-            if (hfov < mf)
+            // special case for single image projects
+            switch (pano.getImage(0).getProjection())
             {
-                if (opts.getProjection() != HuginBase::PanoramaOptions::RECTILINEAR)
+                case HuginBase::SrcPanoImage::RECTILINEAR:
+                    // single rectilinear image, keep rectilinear projection
+                    if (opts.getProjection() != HuginBase::PanoramaOptions::RECTILINEAR)
+                    {
+                        opts.setProjection(HuginBase::PanoramaOptions::RECTILINEAR);
+                        changedProjection = true;
+                    };
+                    break;
+                default:
+                    if (vfov < mf)
+                    {
+                        // small vfov, use cylindrical
+                        if (opts.getProjection() != HuginBase::PanoramaOptions::CYLINDRICAL)
+                        {
+                            opts.setProjection(HuginBase::PanoramaOptions::CYLINDRICAL);
+                            changedProjection = true;
+                        };
+                    }
+                    else
+                    {
+                        // otherwise go to equirectangular
+                        if (opts.getProjection() != HuginBase::PanoramaOptions::EQUIRECTANGULAR)
+                        {
+                            opts.setProjection(HuginBase::PanoramaOptions::EQUIRECTANGULAR);
+                            changedProjection = true;
+                        };
+                    };
+                    break;
+            };
+        }
+        else
+        {
+            if (vfov < mf)
+            {
+                // cylindrical or rectilinear
+                if (hfov < mf)
                 {
-                    opts.setProjection(HuginBase::PanoramaOptions::RECTILINEAR);
-                    changedProjection = true;
+                    if (opts.getProjection() != HuginBase::PanoramaOptions::RECTILINEAR)
+                    {
+                        opts.setProjection(HuginBase::PanoramaOptions::RECTILINEAR);
+                        changedProjection = true;
+                    };
+                }
+                else
+                {
+                    if (opts.getProjection() != HuginBase::PanoramaOptions::CYLINDRICAL)
+                    {
+                        opts.setProjection(HuginBase::PanoramaOptions::CYLINDRICAL);
+                        changedProjection = true;
+                    };
                 };
             }
             else
             {
-                if (opts.getProjection() != HuginBase::PanoramaOptions::CYLINDRICAL)
+                // vfov > 100, use equirectangular projection
+                if (opts.getProjection() != HuginBase::PanoramaOptions::EQUIRECTANGULAR)
                 {
-                    opts.setProjection(HuginBase::PanoramaOptions::CYLINDRICAL);
+                    opts.setProjection(HuginBase::PanoramaOptions::EQUIRECTANGULAR);
                     changedProjection = true;
                 };
-            }
-        }
+            };
+        };
         pano.setOptions(opts);
         // the projection could be changed, calculate fit again
         if(changedProjection)
@@ -336,9 +398,10 @@ int main(int argc, char* argv[])
         {
             progressDisplay=new AppBase::DummyProgressDisplay();
         }
+        float imageStepSize;
         try
         {
-            loadImgsAndExtractPoints(pano, nPoints, 3, true, *progressDisplay, points, !quiet);
+            loadImgsAndExtractPoints(pano, nPoints, 3, true, *progressDisplay, points, !quiet, imageStepSize);
         }
         catch (std::exception& e)
         {
@@ -395,7 +458,7 @@ int main(int argc, char* argv[])
         {
             optmode = HuginBase::SmartPhotometricOptimizer::OPT_PHOTOMETRIC_HDR;
         }
-        HuginBase::SmartPhotometricOptimizer photoOpt(pano, progressDisplay, pano.getOptimizeVector(), points, optmode);
+        HuginBase::SmartPhotometricOptimizer photoOpt(pano, progressDisplay, pano.getOptimizeVector(), points, imageStepSize, optmode);
         photoOpt.run();
 
         // calculate the mean exposure.
