@@ -35,6 +35,7 @@
 
 #include <vigra/error.hxx>
 #include <vigra/functorexpression.hxx>
+#include <vigra/transformimage.hxx>
 
 #include <hugin_utils/utils.h>
 
@@ -42,11 +43,7 @@
 #include <vigra_ext/HDRUtils.h>
 #include <vigra_ext/ReduceOpenEXR.h>
 
-#ifdef _WIN32
 #include <getopt.h>
-#else
-#include <unistd.h>
-#endif
 
 #include "../deghosting/deghosting.h"
 #include "../deghosting/khan.h"
@@ -64,7 +61,7 @@ const uint16_t OTHER_GRAY = 1;
 
 // load all images and apply a weighted average merge, with
 // special cases for completely over or underexposed pixels.
-bool mergeWeightedAverage(std::vector<std::string> inputFiles, vigra::FRGBImage& output)
+bool mergeWeightedAverage(std::vector<std::string> inputFiles, vigra::FRGBImage& output, vigra::BImage& alpha)
 {
     // load all images into memory
     std::vector<ImagePtr> images;
@@ -81,7 +78,7 @@ bool mergeWeightedAverage(std::vector<std::string> inputFiles, vigra::FRGBImage&
         }
         vigra::ImageImportInfo info(inputFiles[i].c_str());
         img->resize(info.size());
-        weight->resize(info.size());
+        weight->resize(info.size().width(), info.size().height(), 255);
         if (info.numBands() == 4)
         {
             importImageAlpha(info, destImage(*img), destImage(*weight));
@@ -106,6 +103,7 @@ bool mergeWeightedAverage(std::vector<std::string> inputFiles, vigra::FRGBImage&
         }
     }
     output.resize(width,height);
+    alpha.resize(width, height, 0);
     if (g_verbose > 0)
     {
         std::cout << "Calculating weighted average " << std::endl;
@@ -121,13 +119,20 @@ bool mergeWeightedAverage(std::vector<std::string> inputFiles, vigra::FRGBImage&
         {
             waverage.reset();
             // loop over all exposures
+            bool hasValues = false;
             for (unsigned imgNr=0; imgNr < images.size(); imgNr++)
             {
                 // add pixel to weighted average
-                waverage( (*images[imgNr])(x,y), (*weightImages[imgNr])(x,y) );
+                const vigra::UInt8 weight = (*weightImages[imgNr])(x, y);
+                waverage( (*images[imgNr])(x,y), weight);
+                hasValues |= (weight > 0);
             }
             // get result
-            output(x,y) = waverage();
+            if(hasValues)
+            {
+                output(x,y) = waverage();
+                alpha(x, y) = 255;
+            };
         }
     }
     return true;
@@ -136,7 +141,8 @@ bool mergeWeightedAverage(std::vector<std::string> inputFiles, vigra::FRGBImage&
 /** compute output image when given source images */
 bool weightedAverageOfImageFiles(const std::vector<std::string>& inputFiles,
                                  const std::vector<deghosting::FImagePtr>& weights,
-                                 vigra::FRGBImage& output)
+                                 vigra::FRGBImage& output,
+                                 vigra::BImage& alpha)
 {
     if(g_verbose > 0)
     {
@@ -166,27 +172,26 @@ bool weightedAverageOfImageFiles(const std::vector<std::string>& inputFiles,
         }
 
         //combine with weight
-        vigra::combineTwoImages(vigra::srcImageRange(tmpImg), vigra::srcImage(*(weights[i])), vigra::destImage(tmpImg), vigra::functor::Arg1() * vigra::functor::Arg2());
-
-        vigra::combineTwoImages(srcImageRange(tmpImg), srcImage(weightedImg), destImage(weightedImg), vigra::functor::Arg1() + vigra::functor::Arg2());
-
+        vigra::combineThreeImages(srcImageRange(tmpImg), srcImage(*(weights[i])), srcImage(weightedImg), destImage(weightedImg), vigra::functor::Arg1() *vigra::functor::Arg2() + vigra::functor::Arg3());
         vigra::combineTwoImages(srcImageRange(weightAdded), srcImage(*(weights[i])), destImage(weightAdded), vigra::functor::Arg1() + vigra::functor::Arg2());
     }
     output.resize(width, height);
+    alpha.resize(width, height, 0);
     vigra::combineTwoImages(srcImageRange(weightedImg), srcImage(weightAdded), destImage(output), vigra::functor::Arg1() / vigra::functor::Arg2());
-
+    vigra::transformImage(vigra::srcImageRange(weightAdded), vigra::destImage(alpha),
+        vigra::Threshold<vigra::FImage::PixelType, vigra::BImage::PixelType>(1e-7f, FLT_MAX, 0, 255));
     return true;
 }
 
 static void usage(const char* name)
 {
-    std::cerr << name << ": merge overlapping images" << std::endl
+    std::cout << name << ": merge overlapping images" << std::endl
          << std::endl
          << "hugin_hdrmerge version " << hugin_utils::GetHuginVersion() << std::endl
          << std::endl
          << "Usage: " << name  << " [options] -o output.exr <input-files>" << std::endl
          << "Valid options are:" << std::endl
-         << "  -o prefix output file" << std::endl
+         << "  -o|--output prefix output file" << std::endl
          << "  -m mode   merge mode, can be one of: avg (default), avg_slow, khan, if avg, no" << std::endl
          << "            -i and -s options apply" << std::endl
          << "  -i iter   number of iterations to execute (default is 4). Khan only" << std::endl
@@ -198,9 +203,9 @@ static void usage(const char* name)
          << "              g   use gamma 2.2 correction instead of logarithm" << std::endl
          << "              m   do not scale image, NOTE: slows down process" << std::endl
          << "  -c        Only consider pixels that are defined in all images (avg mode only)" << std::endl
-         << "  -v        Verbose, print progress messages, repeat for" << std::endl
-         << "            even more verbose output" << std::endl
-         << "  -h        Display help (this text)" << std::endl
+         << "  -v|--verbose   Verbose, print progress messages, repeat for" << std::endl
+         << "                 even more verbose output" << std::endl
+         << "  -h|help   Display help (this text)" << std::endl
          << std::endl;
 }
 
@@ -210,10 +215,15 @@ int main(int argc, char* argv[])
 
     // parse arguments
     const char* optstring = "chvo:m:i:s:a:el";
+    static struct option longOptions[] =
+    {
+        { "output", required_argument, NULL, 'o' },
+        { "verbose", no_argument, NULL, 'v' },
+        { "help", no_argument, NULL, 'h' },
+        0
+    };
     int c;
 
-    opterr = 0;
-
     g_verbose = 0;
     std::string outputFile = "merged.exr";
     std::string mode = "avg";
@@ -223,7 +233,7 @@ int main(int argc, char* argv[])
     uint16_t flags = 0;
     uint16_t otherFlags = 0;
 
-    while ((c = getopt (argc, argv, optstring)) != -1)
+    while ((c = getopt_long(argc, argv, optstring, longOptions, nullptr)) != -1)
     {
         switch (c)
         {
@@ -251,7 +261,7 @@ int main(int argc, char* argv[])
                             flags -= deghosting::ADV_MULTIRES;
                             break;
                         default:
-                            std::cerr<< "Error: unknown option" << std::endl;
+                            std::cerr << hugin_utils::stripPath(argv[0]) << ": unknown option" << std::endl;
                             exit(1);
                     }
                 }
@@ -267,18 +277,21 @@ int main(int argc, char* argv[])
             case 'h':
                 usage(hugin_utils::stripPath(argv[0]).c_str());
                 return 0;
-            default:
-                std::cerr << "Invalid parameter: " << optarg << std::endl;
-                usage(hugin_utils::stripPath(argv[0]).c_str());
+            case ':':
+            case '?':
+                // missing argument or invalid switch
                 return 1;
+                break;
+            default:
+                // this should not happen
+                abort();
         }
     }//end while
 
     unsigned nFiles = argc - optind;
     if (nFiles == 0)
     {
-        std::cerr << std::endl << "Error: at least one input image needed" << std::endl <<std::endl;
-        usage(hugin_utils::stripPath(argv[0]).c_str());
+        std::cerr << hugin_utils::stripPath(argv[0]) << ": at least one input image needed" << std::endl;
         return 1;
     }
     else if (nFiles == 1)
@@ -310,8 +323,8 @@ int main(int argc, char* argv[])
             {
                 std::cout << "Running simple weighted avg algorithm" << std::endl;
             }
-
-            mergeWeightedAverage(inputFiles, output);
+            vigra::BImage alpha;
+            mergeWeightedAverage(inputFiles, output, alpha);
             // save output file
             if (g_verbose > 0)
             {
@@ -319,7 +332,6 @@ int main(int argc, char* argv[])
             }
             vigra::ImageExportInfo exinfo(outputFile.c_str());
             exinfo.setPixelType("FLOAT");
-            vigra::BImage alpha(output.width(), output.height(), 255);
             vigra::exportImageAlpha(srcImageRange(output), srcImage(alpha), exinfo);
         }
         else if (mode == "avg")
@@ -347,15 +359,14 @@ int main(int argc, char* argv[])
                 deghoster = &khanDeghoster;
                 weights = deghoster->createWeightMasks();
             }
-
-            weightedAverageOfImageFiles(inputFiles, weights, output);
+            vigra::BImage alpha;
+            weightedAverageOfImageFiles(inputFiles, weights, output, alpha);
             if (g_verbose > 0)
             {
                 std::cout << "Writing " << outputFile << std::endl;
             }
             vigra::ImageExportInfo exinfo(outputFile.c_str());
             exinfo.setPixelType("FLOAT");
-            vigra::BImage alpha(output.width(), output.height(), 255);
             vigra::exportImageAlpha(vigra::srcImageRange(output), vigra::srcImage(alpha), exinfo);
         }
         else
