@@ -28,8 +28,15 @@
 #include <iostream>
 #include <string>
 #include <fstream>
+#include "hugin_config.h"
+#ifdef HAVE_STD_FILESYSTEM
+#include <filesystem>
+namespace fs = std::tr2::sys;
+#else
 #define BOOST_FILESYSTEM_VERSION 3
 #include <boost/filesystem.hpp>
+namespace fs = boost::filesystem;
+#endif
 #include <getopt.h>
 #include <panodata/Panorama.h>
 #include <hugin_utils/stl_utils.h>
@@ -37,7 +44,7 @@
 #include <panodata/StandardImageVariableGroups.h>
 #include <hugin_base/panotools/PanoToolsUtils.h>
 
-typedef std::vector<boost::filesystem::path> pathVec;
+typedef std::vector<fs::path> pathVec;
 
 
 template <class iteratorType>
@@ -54,7 +61,7 @@ bool iterateFileSystem(std::string src, pathVec& projectFiles)
             };
         }
     }
-    catch(boost::filesystem::filesystem_error e)
+    catch(fs::filesystem_error& e)
     {
         std::cout << e.what() << std::endl;
         return false;
@@ -66,15 +73,15 @@ void FindPTOFiles(pathVec& projectFiles, std::string src, bool recursive)
 {
     if(recursive)
     {
-        iterateFileSystem<boost::filesystem::recursive_directory_iterator>(src, projectFiles);
+        iterateFileSystem<fs::recursive_directory_iterator>(src, projectFiles);
     }
     else
     {
-        iterateFileSystem<boost::filesystem::directory_iterator>(src, projectFiles);
+        iterateFileSystem<fs::directory_iterator>(src, projectFiles);
     };
 };
 
-bool CheckProjectFile(boost::filesystem::path filename)
+bool CheckProjectFile(const fs::path filename)
 {
     // open project file
     HuginBase::Panorama pano;
@@ -172,7 +179,7 @@ int main(int argc, char* argv[])
     {
         { "compress", no_argument, NULL, 'c' },
         { "recursive", no_argument, NULL, 'r' },
-        { "populate", no_argument, NULL, 'p' },
+        { "populate", required_argument, NULL, 'p' },
         { "remove-lens", required_argument, NULL, REMOVE_LENS },
         { "remove-camera", required_argument, NULL, REMOVE_CAM },
         { "export-database", required_argument, NULL, EXPORT_DB },
@@ -190,8 +197,7 @@ int main(int argc, char* argv[])
     std::string exportDatabase;
     std::string importDatabase;
     int c;
-    int optionIndex = 0;
-    while ((c = getopt_long (argc, argv, optstring, longOptions,&optionIndex)) != -1)
+    while ((c = getopt_long (argc, argv, optstring, longOptions,nullptr)) != -1)
     {
         switch (c)
         {
@@ -206,6 +212,7 @@ int main(int argc, char* argv[])
                 break;
             case 'p':
                 populate = true;
+                basepath = hugin_utils::StrTrim(std::string(optarg));
                 break;
             case REMOVE_LENS:
                 lensToRemove = hugin_utils::StrTrim(std::string(optarg));
@@ -219,43 +226,36 @@ int main(int argc, char* argv[])
             case IMPORT_DB:
                 importDatabase = hugin_utils::StrTrim(std::string(optarg));
                 break;
+            case ':':
             case '?':
+                // missing argument or invalid switch
+                return 1;
                 break;
             default:
-                abort ();
+                // this should not happen
+                abort();
         }
     }
 
     if (!exportDatabase.empty() && !importDatabase.empty())
     {
-        std::cerr << "ERROR: Export and import can not be done at the same time. " << std::endl;
+        std::cerr << hugin_utils::stripPath(argv[0]) << ": Export and import can not be done at the same time. " << std::endl;
         return -1;
     };
 
-    if (populate)
-    {
-        if (argc - optind != 1)
-        {
-            usage(hugin_utils::stripPath(argv[0]).c_str());
-            return -1;
-        };
-
-        basepath = argv[optind];
-    };
-
     if (!populate && !compress && lensToRemove.empty() && camToRemove.empty() && exportDatabase.empty() && importDatabase.empty())
     {
         std::cout << "Lensdatabase file: " << HuginBase::LensDB::LensDB::GetSingleton().GetDBFilename() << std::endl;
         std::cout << "Nothing to do." << std::endl;
     };
 
-    if (!basepath.empty())
+    if (populate)
     {
-        boost::filesystem::path p(basepath);
-        if (boost::filesystem::exists(p))
+        fs::path p(basepath);
+        if (fs::exists(p))
         {
-            p = boost::filesystem::absolute(p);
-            if (boost::filesystem::is_directory(p))
+            p = fs::absolute(p);
+            if (fs::is_directory(p))
             {
                 pathVec projectFiles;
                 FindPTOFiles(projectFiles, p.string(), recursive);
