@@ -34,9 +34,6 @@
 #include <vigra/error.hxx>
 
 #include <getopt.h>
-#ifndef _WIN32
-#include <unistd.h>
-#endif
 
 #include <hugin_basic.h>
 #include "hugin_base/algorithms/basic/LayerStacks.h"
@@ -50,7 +47,7 @@
 
 static void usage(const char* name)
 {
-    std::cerr << name << ": stitch a panorama image" << std::endl
+    std::cout << name << ": stitch a panorama image" << std::endl
          << std::endl
          << "nona version " << hugin_utils::GetHuginVersion() << std::endl
          << std::endl
@@ -70,7 +67,7 @@ static void usage(const char* name)
          << "      -c         create coordinate images (only TIFF_m output)" << std::endl
          << "      -v         verbose output" << std::endl
          << "      -d         print detailed output for gpu processing" << std::endl
-         << "      -g         perform image remapping on the GPU" << std::endl
+         << "      -g|--gpu   perform image remapping on the GPU" << std::endl
          << std::endl
          << "  The following options can be used to override settings in the project file:" << std::endl
          << "      -i num     remap only image with number num" << std::endl
@@ -95,6 +92,7 @@ static void usage(const char* name)
          << "                   LZW       lzw compression" << std::endl
          << "                   DEFLATE   deflate compression" << std::endl
          << "                  For jpeg output set quality number" << std::endl
+         << "      --bigtiff   Use BigTIFF format for TIFF images" << std::endl
          << "      --ignore-exposure  don't correct exposure" << std::endl
          << "                   (this does not work with -e switch together)" << std::endl
          << "      --save-intermediate-images  saves also the intermediate" << std::endl
@@ -118,8 +116,6 @@ int main(int argc, char* argv[])
     const char* optstring = "z:cho:i:t:m:p:r:e:vgd";
     int c;
 
-    opterr = 0;
-
     bool doCoord = false;
     HuginBase::UIntSet outputImages;
     std::string basename;
@@ -142,7 +138,8 @@ int main(int argc, char* argv[])
         INTERMEDIATESUFFIX,
         EXPOSURELAYERS,
         MASKCLIPEXPOSURE,
-        SEAMMODE
+        SEAMMODE,
+        USE_BIGTIFF
     };
     static struct option longOptions[] =
     {
@@ -153,11 +150,13 @@ int main(int argc, char* argv[])
         { "create-exposure-layers", no_argument, NULL, EXPOSURELAYERS },
         { "clip-exposure", optional_argument, NULL, MASKCLIPEXPOSURE },
         { "seam", required_argument, NULL, SEAMMODE},
+        { "gpu", no_argument, NULL, 'g'},
+        { "bigtiff", no_argument, NULL, USE_BIGTIFF },
+        { "help", no_argument, NULL, 'h'},
         0
     };
     
-    int optionIndex = 0;
-    while ((c = getopt_long(argc, argv, optstring, longOptions, &optionIndex)) != -1)
+    while ((c = getopt_long(argc, argv, optstring, longOptions, nullptr)) != -1)
     {
         switch (c)
         {
@@ -189,7 +188,7 @@ int main(int argc, char* argv[])
                 }
                 else
                 {
-                    usage(hugin_utils::stripPath(argv[0]).c_str());
+                    std::cerr << hugin_utils::stripPath(argv[0]) << ": \"" << optarg << "\" is not a valid parameter for output mode (-r)." << std::endl;
                     return 1;
                 }
                 break;
@@ -223,21 +222,18 @@ int main(int argc, char* argv[])
                         {
                             if (lowerCutoff < 0 || lowerCutoff>1)
                             {
-                                std::cerr << "nona: Argument \"" << tokens[0] << "\" is not a valid number for lower cutoff." << std::endl
-                                    << "      Aborting." << std::endl;
+                                std::cerr << hugin_utils::stripPath(argv[0]) << ": Argument \"" << tokens[0] << "\" is not a valid number for lower cutoff." << std::endl;
                                 return 1;
                             };
                             if (upperCutoff < 0 || upperCutoff>1)
                             {
-                                std::cerr << "nona: Argument \"" << tokens[1] << "\" is not a valid number for upper cutoff." << std::endl
-                                    << "      Aborting." << std::endl;
+                                std::cerr << hugin_utils::stripPath(argv[0]) << ": Argument \"" << tokens[1] << "\" is not a valid number for upper cutoff." << std::endl;
                                 return 1;
                             };
                             if (lowerCutoff >= upperCutoff)
                             {
-                                std::cerr << "nona: Lower cutoff \"" << tokens[0] << "\" is higher than upper cutoff" << std::endl
-                                    << "     \"" << tokens[1] << "\". This is no valid input." << std::endl
-                                    << "      Aborting." << std::endl;
+                                std::cerr << hugin_utils::stripPath(argv[0]) << ": Lower cutoff \"" << tokens[0] << "\" is higher than upper cutoff" << std::endl
+                                    << "     \"" << tokens[1] << "\". This is no valid input." << std::endl;
                                 return 1;
                             };
                             HuginBase::Nona::SetAdvancedOption(advOptions, "maskClipExposureLowerCutoff", static_cast<float>(lowerCutoff));
@@ -245,18 +241,16 @@ int main(int argc, char* argv[])
                         }
                         else
                         {
-                            std::cerr << "nona: Argument \"" << optarg << "\" is not valid number for --clip-exposure" << std::endl
+                            std::cerr << hugin_utils::stripPath(argv[0]) << ": Argument \"" << optarg << "\" is not valid number for --clip-exposure" << std::endl
                                 << "      Expected --clip-exposure=lower cutoff:upper cutoff" << std::endl
-                                << "      Both should be numbers between 0 and 1."
-                                << "      Aborting." << std::endl;
+                                << "      Both should be numbers between 0 and 1." << std::endl;
                             return 1;
                         }
                     }
                     else
                     {
-                        std::cerr << "nona: Argument \"" << optarg << "\" is not valid for --clip-exposure" << std::endl
-                            << "      Expected --clip-exposure=lower cutoff:upper cutoff" << std::endl
-                            << "      Aborting." << std::endl;
+                        std::cerr << hugin_utils::stripPath(argv[0]) << ": Argument \"" << optarg << "\" is not valid for --clip-exposure" << std::endl
+                            << "      Expected --clip-exposure=lower cutoff:upper cutoff" << std::endl;
                         return 1;
                     };
                 }
@@ -277,12 +271,12 @@ int main(int argc, char* argv[])
                         }
                         else
                         {
-                            std::cerr << "String \"" << text << "\" is not a recognized seam blend mode. Ignoring." << std::endl;
+                            std::cerr << hugin_utils::stripPath(argv[0]) << ": String \"" << text << "\" is not a recognized seam blend mode." << std::endl;
+                            return 1;
                         };
                     };
                 };
                 break;
-            case '?':
             case 'h':
                 usage(hugin_utils::stripPath(argv[0]).c_str());
                 return 0;
@@ -302,15 +296,28 @@ int main(int argc, char* argv[])
             case 'd':
                 vigra_ext::SetGPUDebugMessages(true);
                 break;
+            case USE_BIGTIFF:
+                HuginBase::Nona::SetAdvancedOption(advOptions, "useBigTIFF", true);
+                break;
+            case ':':
+            case '?':
+                // missing argument or invalid switch
+                return 1;
+                break;
             default:
-                usage(hugin_utils::stripPath(argv[0]).c_str());
-                abort ();
+                // this should not happen
+                abort();
         }
     }
 
-    if (basename == "" || argc - optind <1)
+    if (basename.empty())
     {
-        usage(hugin_utils::stripPath(argv[0]).c_str());
+        std::cerr << hugin_utils::stripPath(argv[0]) << ": No output prefix given." << std::endl;
+        return 1;
+    };
+    if(argc - optind < 1)
+    {
+        std::cerr << hugin_utils::stripPath(argv[0]) << ": No project file given." << std::endl;
         return 1;
     }
     unsigned nCmdLineImgs = argc -optind -1;
