@@ -37,19 +37,17 @@ namespace fs = std::tr2::sys;
 #define BOOST_FILESYSTEM_VERSION 3
 #ifdef __GNUC__
   #include "hugin_config.h"
-  #ifdef HAVE_CXX11
-    #include <boost/version.hpp>
-    #if BOOST_VERSION<105700
-      #if BOOST_VERSION>=105100
-        // workaround a bug in boost filesystem
-        // boost filesystem is probably compiled with C++03
-        // but Hugin is compiled with C++11, this results in
-        // conflicts in boost::filesystems at a enum
-        // see https://svn.boost.org/trac/boost/ticket/6779
-        #define BOOST_NO_CXX11_SCOPED_ENUMS
-      #else
-        #define BOOST_NO_SCOPED_ENUMS
-      #endif
+  #include <boost/version.hpp>
+  #if BOOST_VERSION<105700
+    #if BOOST_VERSION>=105100
+      // workaround a bug in boost filesystem
+      // boost filesystem is probably compiled with C++03
+      // but Hugin is compiled with C++11, this results in
+      // conflicts in boost::filesystems at a enum
+      // see https://svn.boost.org/trac/boost/ticket/6779
+      #define BOOST_NO_CXX11_SCOPED_ENUMS
+    #else
+      #define BOOST_NO_SCOPED_ENUMS
     #endif
   #endif
 #endif
@@ -112,7 +110,7 @@ bool checkDestinationDirectory(std::string dir, fs::path& pathTo)
             if(!fs::create_directories(pathTo))
             {
                 std::cerr << "ERROR: Could not create destination directory: " << pathTo.string() << std::endl
-                          << "Maybe you have not sufficent rights to create this directory." << std::endl;
+                          << "Maybe you have not sufficient rights to create this directory." << std::endl;
                 return false;
             };
         };
@@ -391,8 +389,7 @@ int main(int argc, char* argv[])
     bool recursive=false;
     bool forceOverwrite=false;
     int c;
-    int optionIndex = 0;
-    while ((c = getopt_long (argc, argv, optstring, longOptions,&optionIndex)) != -1)
+    while ((c = getopt_long (argc, argv, optstring, longOptions,nullptr)) != -1)
     {
         switch (c)
         {
@@ -408,16 +405,20 @@ int main(int argc, char* argv[])
             case 'o':
                 forceOverwrite=true;
                 break;
+            case ':':
             case '?':
+                // missing argument or invalid switch
+                return 1;
                 break;
             default:
-                abort ();
+                // this should not happen
+                abort();
         }
     }
 
     if(argc-optind<2)
     {
-        std::cout << "PTO_MOVE: You need to give at least a source and a destination project file or directory." << std::endl;
+        std::cerr << hugin_utils::stripPath(argv[0]) << ": You need to give at least a source and a destination project file or directory." << std::endl;
         return 1;
     };
 
