@@ -27,109 +27,52 @@
 #include <fstream>
 #include <sstream>
 #include <getopt.h>
-#ifndef _WIN32
-#include <unistd.h>
-#endif
 #include <panodata/Panorama.h>
 #include <panodata/ImageVariableTranslate.h>
 #include <panodata/ImageVariableGroup.h>
 #include <panodata/StandardImageVariableGroups.h>
 #include "hugin_utils/utils.h"
-#include "ParseExp.h"
-
-struct ParseVar
-{
-    std::string varname;
-    int imgNr;
-    std::string expression;
-    bool removeOpt;
-    ParseVar(): varname(""), imgNr(-1), expression(""), removeOpt(false) {};
-};
-
-typedef std::vector<ParseVar> ParseVarVec;
-
-bool ParseVarNumber(const std::string&s, ParseVar& var)
-{
-    std::size_t pos = s.find_first_of("0123456789");
-    std::string varName;
-    if (pos == std::string::npos)
-    {
-        varName = s;
-        var.imgNr = -1;
-    }
-    else
-    {
-        if (pos == 0)
-        {
-            return false;
-        };
-        varName = s.substr(0, pos);
-        if (!hugin_utils::stringToInt(s.substr(pos, s.length() - pos), var.imgNr))
-        {
-            return false;
-        };
-    }
-#define image_variable( name, type, default_value ) \
-    if (HuginBase::PTOVariableConverterFor##name::checkApplicability(varName))\
-    {\
-        var.varname=varName;\
-        return true;\
-    };
-#include "panodata/image_variables.h"
-#undef image_variable
-    return false;
-};
+#include "panodata/ParseExp.h"
 
 // parse a single variable and put result in struct ParseVar
-void ParseSingleOptVar(ParseVarVec& varVec, const std::string& s)
+void ParseSingleOptVar(Parser::ParseVarVec& varVec, const std::string& s, std::ostream& errorStream)
 {
     // parse following regex ([!]?)([a-zA-Z]{1,3})(\\d*?) 
     std::string tempString(s);
-    ParseVar var;
-    var.removeOpt = (tempString[0] == '!');
-    if (var.removeOpt)
+    Parser::ParseVar var;
+    var.flag = (tempString[0] == '!');
+    if (var.flag)
     {
         tempString.erase(0, 1);
     };
-    if (ParseVarNumber(tempString, var))
+    if (Parser::ParseVarNumber(tempString, var))
     {
         varVec.push_back(var);
+    }
+    else
+    {
+        errorStream << "The expression \"" << tempString << "\" is not a valid image variable." << std::endl;
     };
 };
 
-void ParseSingleLinkVar(ParseVarVec& varVec, const std::string& s)
+void ParseSingleLinkVar(Parser::ParseVarVec& varVec, const std::string& s, std::ostream& errorStream)
 {
     // parse following regex ([a-zA-Z]{1,3})(\\d+?)
-    ParseVar var;
-    if (ParseVarNumber(s, var))
+    Parser::ParseVar var;
+    if (Parser::ParseVarNumber(s, var))
     {
-        varVec.push_back(var);
-    };
-};
-
-void ParseSingleVar(ParseVarVec& varVec, const std::string& s)
-{
-    // parse following regex ([a-zA-Z]{1,3})(\\d*?)=(.*)
-    const std::size_t pos = s.find_first_of("=", 0);
-    if (pos != std::string::npos && pos > 0 && pos < s.length() - 1)
-    {
-        ParseVar var;
-        const std::string tempString(s.substr(0, pos));
-        if (ParseVarNumber(tempString, var))
+        if (var.imgNr >= 0)
         {
-            var.expression = s.substr(pos + 1, s.length() - pos - 1);
             varVec.push_back(var);
-        };
-    };
-};
-
-//parse complete variables string
-void ParseVariableString(ParseVarVec& parseVec, const std::string& input, void (*func)(ParseVarVec&, const std::string&))
-{
-    std::vector<std::string> splitResult = hugin_utils::SplitString(input, ", ");
-    for(size_t i=0; i<splitResult.size(); i++)
+        }
+        else
+        {
+            errorStream << "The expression \"" << s << "\" does not contain a valid image number." << std::endl;
+        }
+    }
+    else
     {
-        (*func)(parseVec, splitResult[i]);
+        errorStream << "The expression \"" << s << "\" is not a valid image variable." << std::endl;
     };
 };
 
@@ -212,7 +155,7 @@ void RemoveFromOptVec(HuginBase::OptimizeVector& optVec, std::string varname, si
 };
 
 // link or unlink the parsed image variables
-void UnLinkVars(HuginBase::Panorama& pano, ParseVarVec parseVec, bool link)
+void UnLinkVars(HuginBase::Panorama& pano, Parser::ParseVarVec parseVec, bool link)
 {
     for(size_t i=0; i<parseVec.size(); i++)
     {
@@ -240,13 +183,16 @@ void UnLinkVars(HuginBase::Panorama& pano, ParseVarVec parseVec, bool link)
                 HuginBase::ImageVariableGroup group(HuginBase::StandardImageVariableGroups::getLensVariables(), pano);
                 if (link)
                 {
+                    std::cout << "Linking";
                     group.linkVariableImage(*variables.begin(), parseVec[i].imgNr);
                 }
                 else
                 {
+                    std::cout << "Unlinking";
                     group.unlinkVariableImage(*variables.begin(), parseVec[i].imgNr);
                     group.updatePartNumbers();
                 }
+                std::cout << " image variable " << parseVec[i].varname << " for image " << parseVec[i].imgNr << std::endl;
             }
             else
             {
@@ -257,6 +203,7 @@ void UnLinkVars(HuginBase::Panorama& pano, ParseVarVec parseVec, bool link)
                     HuginBase::ImageVariableGroup group(HuginBase::StandardImageVariableGroups::getStackVariables(), pano);
                     if (link)
                     {
+                        std::cout << "Linking";
                         group.linkVariableImage(HuginBase::ImageVariableGroup::IVE_Yaw, parseVec[i].imgNr);
                         group.linkVariableImage(HuginBase::ImageVariableGroup::IVE_Pitch, parseVec[i].imgNr);
                         group.linkVariableImage(HuginBase::ImageVariableGroup::IVE_Roll, parseVec[i].imgNr);
@@ -268,6 +215,7 @@ void UnLinkVars(HuginBase::Panorama& pano, ParseVarVec parseVec, bool link)
                     }
                     else
                     {
+                        std::cout << "Unlinking";
                         group.unlinkVariableImage(HuginBase::ImageVariableGroup::IVE_Yaw, parseVec[i].imgNr);
                         group.unlinkVariableImage(HuginBase::ImageVariableGroup::IVE_Pitch, parseVec[i].imgNr);
                         group.unlinkVariableImage(HuginBase::ImageVariableGroup::IVE_Roll, parseVec[i].imgNr);
@@ -278,6 +226,7 @@ void UnLinkVars(HuginBase::Panorama& pano, ParseVarVec parseVec, bool link)
                         group.unlinkVariableImage(HuginBase::ImageVariableGroup::IVE_TranslationPlanePitch, parseVec[i].imgNr);
                         group.updatePartNumbers();
                     }
+                    std::cout << " image position (ypr, TrXYZ, Tpyp) for image " << parseVec[i].imgNr << std::endl;
                 }
                 else
                 {
@@ -288,73 +237,221 @@ void UnLinkVars(HuginBase::Panorama& pano, ParseVarVec parseVec, bool link)
     };
 };
 
-bool UpdateSingleVar(HuginBase::Panorama& pano, ParseVar parseVar, size_t imgNr)
+// parse number, take an optional % sign into account
+// in case of a relativ value the result is normed to 1
+bool ParseCoordinateRelativ(const std::string& s, double& val, bool& relativ)
 {
-    double val=pano.getImage(imgNr).getVar(parseVar.varname);
-    Parser::ConstantMap constMap;
-    constMap["i"]=1.0*imgNr;
-    constMap["val"]=val;
-    std::cout << "Updating variable " << parseVar.varname << imgNr << ": " << val;
-    if(Parser::ParseExpression(parseVar.expression, val, constMap))
+    size_t pos = s.find('%');
+    relativ = (pos != std::string::npos);
+    if (relativ)
     {
-        std::cout << " -> " << val << std::endl;
-        HuginBase::Variable var(parseVar.varname, val);
-        pano.updateVariable(imgNr, var);
-        return true;
+        if (pos < s.length() - 1)
+        {
+            // there are characters afters the percent sign
+            // this is not supported
+            return false;
+        };
+        if( hugin_utils::stringToDouble(s.substr(0, pos), val))
+        {
+            val /= 100.0;
+            return true;
+        };
     }
     else
     {
-        std::cout << std::endl;
-        std::cerr << "Could not parse given expression \"" << parseVar.expression << "\" for image " << imgNr << "." << std::endl;
-        return false;
+        // enforce integer values
+        int intValue;
+        if (hugin_utils::stringToInt(s, intValue))
+        {
+            val = intValue;
+            return true;
+        };
+    };
+    return false;
+}
+
+// parse given crop string s and set corresponding crop in pano for images in UIntSet
+void SetCropToImages(const std::string& s, HuginBase::Panorama& pano, HuginBase::UIntSet& imgs)
+{
+    std::vector<std::string> coords = hugin_utils::SplitString(s, ",");
+    if (coords.size() == 2)
+    {
+        // only 2 coordinates, take them as width and height and activate autocenter crop
+        double width, height;
+        bool relWidth = false;
+        bool relHeight = false;
+        if (ParseCoordinateRelativ(coords[0], width, relWidth) && ParseCoordinateRelativ(coords[1], height, relHeight))
+        {
+            for (auto& i : imgs)
+            {
+                HuginBase::SrcPanoImage img = pano.getSrcImage(i);
+                vigra::Rect2D cropRect;
+                cropRect.setSize(relWidth ? (img.getWidth()*width) : width, relHeight ? (img.getHeight()*height) : height);
+                img.setCropRect(cropRect);
+                img.setAutoCenterCrop(true);
+                pano.setSrcImage(i, img);
+                pano.changeFinished();
+                // print result
+                std::cout << "Set crop for image " << i << " to " << pano.getImage(i).getCropRect() << std::endl;
+            };
+        }
+        else
+        {
+            std::cerr << "Could not parse crop string \"" << s << "\"." << std::endl;
+            return;
+        };
+    }
+    else
+    {
+        if (coords.size() == 4)
+        {
+            // we got 4 coordinates
+            int left, right, top, bottom;
+            if (hugin_utils::stringToInt(coords[0], left) && hugin_utils::stringToInt(coords[1], right) &&
+                hugin_utils::stringToInt(coords[2], top) && hugin_utils::stringToInt(coords[3], bottom))
+            {
+                vigra::Rect2D cropRect;
+                if (right > left && bottom > top)
+                {
+                    cropRect.setUpperLeft(vigra::Point2D(left, top));
+                    cropRect.setLowerRight(vigra::Point2D(right, bottom));
+                }
+                else
+                {
+                    std::cerr << "Crop \"" << s << "\" is an invalid crop area." << std::endl;
+                    return;
+                };
+                for (auto& i : imgs)
+                {
+                    HuginBase::SrcPanoImage img = pano.getSrcImage(i);
+                    img.setAutoCenterCrop(false);
+                    img.setCropRect(cropRect);
+                    pano.setSrcImage(i, img);
+                    pano.changeFinished();
+                    // print result
+                    std::cout << "Set crop for image " << i << " to " << pano.getImage(i).getCropRect() << std::endl;
+                };
+            }
+            else
+            {
+                std::cerr << "Could not parse crop values \"" << s << "\"." << std::endl;
+                return;
+            };
+        }
+        else
+        {
+            std::cerr << "Invalid coordinates \"" << s << "\"." << std::endl;
+            return;
+        }
+    };
+    return;
+}
+
+// set the crop from the string
+void SetCrop(HuginBase::Panorama& pano, const std::string& crop)
+{
+    // split string at ';'
+    std::vector<std::string> splitResult = hugin_utils::SplitString(crop, ";");
+    // now process each sub-string
+    for (auto& s : splitResult)
+    {
+        std::string subString = hugin_utils::StrTrim(s);
+        if (subString.empty())
+        {
+            continue;
+        };
+        size_t pos = subString.find("=");
+        if(subString[0]=='i' && pos==std::string::npos)
+        { 
+            std::cerr << "Crop expression \"" << s << "\" is not a valid crop." << std::endl;
+            continue;
+        };
+        if (subString[0] == 'i')
+        {
+            if (pos < 2)
+            {
+                std::cerr << "Crop expression \"" << s << "\" does not contain a valid image number."<< std::endl;
+                continue;
+            };
+            unsigned int imgNr;
+            if(!hugin_utils::stringToUInt(subString.substr(1, pos-1), imgNr))
+            { 
+                std::cerr << "Crop expression \"" << s << "\" does not contain a valid image number." << std::endl;
+                continue;
+            };
+            if (imgNr >= pano.getNrOfImages())
+            {
+                std::cerr << "Pano does not contain image with number " << imgNr << std::endl;
+                continue;
+            };
+            HuginBase::UIntSet imgs;
+            imgs.insert(imgNr);
+            SetCropToImages(subString.substr(pos + 1), pano, imgs);
+        }
+        else
+        {
+            // update crop for all images
+            HuginBase::UIntSet imgs;
+            fill_set(imgs, 0, pano.getNrOfImages() - 1);
+            SetCropToImages(subString, pano, imgs);
+        };
     };
 };
 
 static void usage(const char* name)
 {
     std::cout << name << ": change image variables inside pto files" << std::endl
-         << name << " version " << hugin_utils::GetHuginVersion() << std::endl
-         << std::endl
-         << "Usage:  " << name << " [options] --opt|--link|--unlink|--set varlist input.pto" << std::endl
-         << std::endl
-         << "     -o, --output=file.pto  Output Hugin PTO file. Default: <filename>_var.pto" << std::endl
-         << "     -h, --help             Shows this help" << std::endl
-         << std::endl
-         << "     --opt varlist          Change optimizer variables" << std::endl
-         << "     --modify-opt           Modify the existing optimizer variables" << std::endl
-         << "                            (without pto_var will start with an" << std::endl
-         << "                             empty variables set)" << std::endl
-         << "                            Examples:" << std::endl
-         << "           --opt=y,p,r        Optimize yaw, pitch and roll of all images" << std::endl
-         << "                              (special treatment for anchor image applies)" << std::endl
-         << "           --opt=v0,b2        Optimize hfov of image 0 and barrel distortion" << std::endl
-         << "                              of image 2" << std::endl
-         << "           --opt=v,!v0        Optimize field of view for all images except" << std::endl
-         << "                              for the first image" << std::endl
-         << "           --opt=!a,!b,!c     Don't optimise distortion (works only with" << std::endl
-         << "                              switch --modify-opt together)" << std::endl
-         << std::endl
-         << "     --link varlist         Link given variables" << std::endl
-         << "                            Example:" << std::endl
-         << "           --link=v3          Link hfov of image 3" << std::endl
-         << "           --link=a1,b1,c1    Link distortions parameter for image 1" << std::endl
-         << std::endl
-         << "     --unlink varlist       Unlink given variables" << std::endl
-         << "                            Examples:" << std::endl
-         << "           --unlink=v5        Unlink hfov for image 5" << std::endl
-         << "           --unlink=a2,b2,c2  Unlink distortions parameters for image 2" << std::endl
-         << std::endl
-         << "     --set varlist          Sets variables to new values" << std::endl
-         << "                            Examples:" << std::endl
-         << "           --set=y0=0,r0=0,p0=0  Resets position of image 0" << std::endl
-         << "           --set=Vx4=-10,Vy4=10  Sets vignetting offset for image 4" << std::endl
-         << "           --set=v=20            Sets the field of view to 20 for all images" << std::endl
-         << "           --set=y=val+20        Increase yaw by 20 deg for all images" << std::endl
-         << "           --set=v=val*1.1       Increase fov by 10 % for all images" << std::endl
-         << "           --set=y=i*20          Set yaw to 0, 20, 40, ..." << std::endl
-         << "     --set-from-file filename  Sets variables to new values" << std::endl
-         << "                               It reads the varlist from a file" << std::endl
-         << std::endl;
+        << name << " version " << hugin_utils::GetHuginVersion() << std::endl
+        << std::endl
+        << "Usage:  " << name << " [options] --opt|--link|--unlink|--set varlist input.pto" << std::endl
+        << std::endl
+        << "     -o, --output=file.pto  Output Hugin PTO file. Default: <filename>_var.pto" << std::endl
+        << "     -h, --help             Shows this help" << std::endl
+        << std::endl
+        << "     --opt varlist          Change optimizer variables" << std::endl
+        << "     --modify-opt           Modify the existing optimizer variables" << std::endl
+        << "                            (without pto_var will start with an" << std::endl
+        << "                             empty variables set)" << std::endl
+        << "                            Examples:" << std::endl
+        << "           --opt=y,p,r        Optimize yaw, pitch and roll of all images" << std::endl
+        << "                              (special treatment for anchor image applies)" << std::endl
+        << "           --opt=v0,b2        Optimize hfov of image 0 and barrel distortion" << std::endl
+        << "                              of image 2" << std::endl
+        << "           --opt=v,!v0        Optimize field of view for all images except" << std::endl
+        << "                              for the first image" << std::endl
+        << "           --opt=!a,!b,!c     Don't optimise distortion (works only with" << std::endl
+        << "                              switch --modify-opt together)" << std::endl
+        << std::endl
+        << "     --link varlist         Link given variables" << std::endl
+        << "                            Example:" << std::endl
+        << "           --link=v3          Link hfov of image 3" << std::endl
+        << "           --link=a1,b1,c1    Link distortions parameter for image 1" << std::endl
+        << std::endl
+        << "     --unlink varlist       Unlink given variables" << std::endl
+        << "                            Examples:" << std::endl
+        << "           --unlink=v5        Unlink hfov for image 5" << std::endl
+        << "           --unlink=a2,b2,c2  Unlink distortions parameters for image 2" << std::endl
+        << std::endl
+        << "     --set varlist          Sets variables to new values" << std::endl
+        << "                            Examples:" << std::endl
+        << "           --set=y0=0,r0=0,p0=0  Resets position of image 0" << std::endl
+        << "           --set=Vx4=-10,Vy4=10  Sets vignetting offset for image 4" << std::endl
+        << "           --set=v=20            Sets the field of view to 20 for all images" << std::endl
+        << "           --set=y=val+20        Increase yaw by 20 deg for all images" << std::endl
+        << "           --set=v=val*1.1       Increase fov by 10 % for all images" << std::endl
+        << "           --set=y=i*20          Set yaw to 0, 20, 40, ..." << std::endl
+        << "     --set-from-file filename  Sets variables to new values" << std::endl
+        << "                               It reads the varlist from a file" << std::endl
+        << std::endl
+        << "     --crop=left,right,top,bottom Set the crop for all images" << std::endl
+        << "     --crop=width,height       Set the crop for all images and activate" << std::endl
+        << "                               autocenter for crop" << std::endl
+        << "                               relative values can be used with %" << std::endl
+        << "     --crop=iNUM=left,right,top,bottom Set the crop for image NUM" << std::endl
+        << "     --crop=iNUM=width,height  Set the crop for image NUM and" <<std::endl
+        << "                             activate autocenter for crop"<<std::endl
+        << "                             These switches can be used several times."<<std::endl
+        << std::endl;
 }
 
 int main(int argc, char* argv[])
@@ -369,7 +466,8 @@ int main(int argc, char* argv[])
         SWITCH_UNLINK,
         SWITCH_SET,
         SWITCH_SET_FILE,
-        OPT_MODIFY_OPTVEC
+        OPT_MODIFY_OPTVEC,
+        SWITCH_CROP
     };
     static struct option longOptions[] =
     {
@@ -380,19 +478,19 @@ int main(int argc, char* argv[])
         {"set", required_argument, NULL, SWITCH_SET },
         {"set-from-file", required_argument, NULL, SWITCH_SET_FILE },
         {"modify-opt", no_argument, NULL, OPT_MODIFY_OPTVEC },
+        {"crop", required_argument, NULL, SWITCH_CROP },
         {"help", no_argument, NULL, 'h' },
         0
     };
 
-    ParseVarVec optVars;
-    ParseVarVec linkVars;
-    ParseVarVec unlinkVars;
-    ParseVarVec setVars;
+    Parser::ParseVarVec optVars;
+    Parser::ParseVarVec linkVars;
+    Parser::ParseVarVec unlinkVars;
+    std::string setVars, crop;
     bool modifyOptVec=false;
     int c;
-    int optionIndex = 0;
     std::string output;
-    while ((c = getopt_long (argc, argv, optstring, longOptions,&optionIndex)) != -1)
+    while ((c = getopt_long (argc, argv, optstring, longOptions,nullptr)) != -1)
     {
         switch (c)
         {
@@ -403,16 +501,20 @@ int main(int argc, char* argv[])
                 usage(hugin_utils::stripPath(argv[0]).c_str());
                 return 0;
             case SWITCH_OPT:
-                ParseVariableString(optVars, std::string(optarg), ParseSingleOptVar);
+                Parser::ParseVariableString(optVars, std::string(optarg), std::cerr, ParseSingleOptVar);
                 break;
             case SWITCH_LINK:
-                ParseVariableString(linkVars, std::string(optarg), ParseSingleLinkVar);
+                Parser::ParseVariableString(linkVars, std::string(optarg), std::cerr, ParseSingleLinkVar);
                 break;
             case SWITCH_UNLINK:
-                ParseVariableString(unlinkVars, std::string(optarg), ParseSingleLinkVar);
+                Parser::ParseVariableString(unlinkVars, std::string(optarg), std::cerr, ParseSingleLinkVar);
                 break;
             case SWITCH_SET:
-                ParseVariableString(setVars, std::string(optarg), ParseSingleVar);
+                if (!setVars.empty())
+                {
+                    setVars.append(",");
+                };
+                setVars.append(optarg);
                 break;
             case SWITCH_SET_FILE:
                 {
@@ -422,44 +524,53 @@ int main(int argc, char* argv[])
                         std::ostringstream contents;
                         contents << ifs.rdbuf();
                         ifs.close();
-                        std::string s(contents.str());
-                        hugin_utils::ReplaceAll(s, "\n", ',');
-                        ParseVariableString(setVars, s, ParseSingleVar);
+                        setVars = contents.str();
                     }
                     else
                     {
-                        std::cerr << "Could not open file " << optarg << std::endl;
+                        std::cerr << hugin_utils::stripPath(argv[0]) << ": Could not open file " << optarg << std::endl;
+                        return 1;
                     };
                 };
                 break;
             case OPT_MODIFY_OPTVEC:
                 modifyOptVec=true;
                 break;
+            case SWITCH_CROP:
+                if (!crop.empty())
+                {
+                    crop.append(";");
+                };
+                crop.append(optarg);
+                break;
             case ':':
-                std::cerr <<"Option " << longOptions[optionIndex].name << " requires a parameter." << std::endl;
+            case '?':
+                // missing argument or invalid switch
                 return 1;
                 break;
-            case '?':
-                break;
             default:
-                abort ();
+                // this should not happen
+                abort();
+
         }
     }
 
-    if (argc - optind == 0)
-    {
-        std::cerr << "Error: " << argv[0] << " needs at least one project file." << std::endl;
-        return 1;
-    };
     if (argc - optind != 1)
     {
-        std::cout << "Error: " << argv[0] << " can only work on one project file at one time" << std::endl;
+        if (argc - optind < 1)
+        {
+            std::cerr << hugin_utils::stripPath(argv[0]) << ": No project file given." << std::endl;
+        }
+        else
+        {
+            std::cerr << hugin_utils::stripPath(argv[0]) << ": Only one project file expected." << std::endl;
+        };
         return 1;
     };
 
-    if(optVars.size() + linkVars.size() + unlinkVars.size() + setVars.size()==0)
+    if(optVars.empty() && linkVars.empty() && unlinkVars.empty() && setVars.empty() && crop.empty())
     {
-        std::cerr << "Error: no variables to modify given" << std::endl;
+        std::cerr << hugin_utils::stripPath(argv[0]) << ": no variables to modify given" << std::endl;
         return 1;
     };
 
@@ -489,77 +600,32 @@ int main(int argc, char* argv[])
     };
 
     //link/unlink variables
-    if(linkVars.size()>0)
+    if(!linkVars.empty())
     {
+        std::cout << "Linking image variables" << std::endl;
         UnLinkVars(pano, linkVars, true);
+        std::cout << std::endl;
     };
 
-    if(unlinkVars.size()>0)
+    if(!unlinkVars.empty())
     {
+        std::cout << "Unlinking image variables" << std::endl;
         UnLinkVars(pano, unlinkVars, false);
+        std::cout << std::endl;
     };
 
     // set variables to new value
-    if(setVars.size()>0)
+    if(!setVars.empty())
     {
-        for(size_t i=0; i<setVars.size(); i++)
-        {
-            //skip invalid image numbers
-            if(setVars[i].imgNr>=(int)pano.getNrOfImages())
-            {
-                continue;
-            };
-            if(setVars[i].imgNr<0)
-            {
-                HuginBase::UIntSet updatedImgs;
-                for(size_t j=0; j<pano.getNrOfImages(); j++)
-                {
-                    //if we already update the variable in this image via links, skip it
-                    if(set_contains(updatedImgs, j))
-                    {
-                        continue;
-                    };
-                    // skip following images, if expression could not parsed
-                    if(!UpdateSingleVar(pano, setVars[i], j))
-                    {
-                        break;
-                    };
-                    updatedImgs.insert(j);
-                    if(j==pano.getNrOfImages()-1)
-                    {
-                        break;
-                    };
-                    // now remember linked variables
-                    const HuginBase::SrcPanoImage& img1=pano.getImage(j);
-#define image_variable( name, type, default_value ) \
-    if (HuginBase::PTOVariableConverterFor##name::checkApplicability(setVars[i].varname))\
-    {\
-        if(img1.name##isLinked())\
-        {\
-            for(size_t k=j+1; k<pano.getNrOfImages(); k++)\
-            {\
-                if(img1.name##isLinkedWith(pano.getImage(k)))\
-                {\
-                    updatedImgs.insert(k);\
-                }\
-            };\
-        };\
-    };
-#include "panodata/image_variables.h"
-#undef image_variable
-                };
-            }
-            else
-            {
-                UpdateSingleVar(pano, setVars[i], setVars[i].imgNr);
-            };
-        };
-        Parser::CleanUpParser();
+        std::cout << "Setting image variables" << std::endl;
+        Parser::PanoParseExpression(pano, setVars);
+        std::cout << std::endl;
     };
 
     // update optimzer vector
-    if(optVars.size()>0)
+    if(!optVars.empty())
     {
+        std::cout << "Updating optimizer variables" << std::endl;
         std::set<size_t> refImgs=pano.getRefImages();
         bool linkRefImgsYaw=false;
         bool linkRefImgsPitch=false;
@@ -605,7 +671,7 @@ int main(int argc, char* argv[])
             {
                 for(size_t imgNr=0; imgNr<pano.getNrOfImages(); imgNr++)
                 {
-                    if(optVars[i].removeOpt)
+                    if(optVars[i].flag)
                     {
                         RemoveFromOptVec(optVec, optVars[i].varname, imgNr, groupedVars);
                     }
@@ -617,7 +683,7 @@ int main(int argc, char* argv[])
             }
             else
             {
-                if(optVars[i].removeOpt)
+                if(optVars[i].flag)
                 {
                     RemoveFromOptVec(optVec, optVars[i].varname, optVars[i].imgNr, groupedVars);
                 }
@@ -630,6 +696,22 @@ int main(int argc, char* argv[])
         pano.setOptimizerSwitch(0);
         pano.setPhotometricOptimizerSwitch(0);
         pano.setOptimizeVector(optVec);
+        std::cout << "Optimizer variables:" << std::endl;
+        for (size_t i = 0; i < optVec.size(); ++i)
+        {
+            std::cout << "Image " << i << ": ";
+            std::copy(optVec[i].begin(), optVec[i].end(), std::ostream_iterator<std::string>(std::cout, " "));
+            std::cout << std::endl;
+        };
+        std::cout << std::endl;
+    };
+
+    // update crop
+    if (!crop.empty())
+    {
+        std::cout << "Setting image crop" << std::endl;
+        SetCrop(pano, crop);
+        std::cout << std::endl;
     };
 
     //write output
