@@ -27,9 +27,6 @@
 #include <stdio.h>
 #include <iostream>
 #include <getopt.h>
-#ifndef _WIN32
-#include <unistd.h>
-#endif
 #include <vigra_ext/impexalpha.hxx>
 #include <vigra_ext/StitchWatershed.h>
 #include <vigra_ext/utils.h>
@@ -43,7 +40,16 @@ bool SaveImage(ImageType& image, MaskType& mask, vigra::ImageExportInfo& exportI
     exportImageInfo.setPixelType(pixelType.c_str());
     if (vigra::isBandNumberSupported(filetype, inputNumberBands))
     {
-        vigra::exportImageAlpha(vigra::srcImageRange(image, roi), vigra::srcImage(mask, roi.upperLeft()), exportImageInfo);
+        try
+        {
+            vigra::exportImageAlpha(vigra::srcImageRange(image, roi), vigra::srcImage(mask, roi.upperLeft()), exportImageInfo);
+        }
+        catch (std::exception& e)
+        {
+            std::cerr << "ERROR: Could not save " << exportImageInfo.getFileName() << std::endl
+                << "Cause: " << e.what() << std::endl;
+            return false;
+        };
         return true;
     }
     else
@@ -52,12 +58,21 @@ bool SaveImage(ImageType& image, MaskType& mask, vigra::ImageExportInfo& exportI
         {
             std::cout << "Warning: Filetype " << filetype << " does not support alpha channels." << std::endl
                 << "Saving image without alpha channel." << std::endl;
-            vigra::exportImage(vigra::srcImageRange(image, roi), exportImageInfo);
+            try
+            {
+                vigra::exportImage(vigra::srcImageRange(image, roi), exportImageInfo);
+            }
+            catch (std::exception& e)
+            {
+                std::cerr << "ERROR: Could not save " << exportImageInfo.getFileName() << std::endl
+                    << "Cause: " << e.what() << std::endl;
+                return false;
+            };
             return true;
         }
         else
         {
-            std::cerr << "Error: Output filetype " << filetype << " does not support " << inputNumberBands << " channels." << std::endl
+            std::cerr << "ERROR: Output filetype " << filetype << " does not support " << inputNumberBands << " channels." << std::endl
                 << "Can't save image." << std::endl;
         };
     };
@@ -66,34 +81,33 @@ bool SaveImage(ImageType& image, MaskType& mask, vigra::ImageExportInfo& exportI
 
 /** save final image, take care of some supported pixel types and convert when necessary to smaller pixel type */
 template <class ImageType, class MaskType>
-bool SaveFinalImage(ImageType& image, MaskType& mask, const vigra::ImageImportInfo& input, vigra::ImageExportInfo& output, const vigra::Rect2D& roi)
+bool SaveFinalImage(ImageType& image, MaskType& mask, const std::string& inputPixelType, const int inputNumBands, vigra::ImageExportInfo& output, const vigra::Rect2D& roi)
 {
     VIGRA_UNIQUE_PTR<vigra::Encoder> encoder(vigra::encoder(output));
-    if (vigra::isPixelTypeSupported(encoder->getFileType(), input.getPixelType()))
+    if (vigra::isPixelTypeSupported(encoder->getFileType(), inputPixelType))
     {
-        return SaveImage(image, mask, output, encoder->getFileType(), input.getPixelType(), roi, input.numBands());
+        return SaveImage(image, mask, output, encoder->getFileType(), inputPixelType, roi, inputNumBands);
     }
     else
     {
         if (vigra::isPixelTypeSupported(encoder->getFileType(), "UINT16"))
         {
             // transform to UINT16
-            vigra::omp::transformImage(vigra::srcImageRange(image), vigra::destImage(image),
-                vigra::linearIntensityTransform<typename ImageType::PixelType>(65535.0 / vigra::NumericTraits<typename vigra::NumericTraits<typename ImageType::PixelType>::ValueType>::max()));
-            return SaveImage(image, mask, output, encoder->getFileType(), "UINT16", roi, input.numBands());
+            output.setForcedRangeMapping(0, vigra::NumericTraits<typename vigra::NumericTraits<typename ImageType::PixelType>::ValueType>::max(), 0, 65535);
+            return SaveImage(image, mask, output, encoder->getFileType(), "UINT16", roi, inputNumBands);
         }
         else
         {
             if (vigra::isPixelTypeSupported(encoder->getFileType(), "UINT8"))
             {
                 // transform to UINT8
-                vigra_ext::ConvertTo8Bit(image);
-                return SaveImage(image, mask, output, encoder->getFileType(), "UINT8", roi, input.numBands());
+                output.setForcedRangeMapping(0, vigra::NumericTraits<typename vigra::NumericTraits<typename ImageType::PixelType>::ValueType>::max(), 0, 255);
+                return SaveImage(image, mask, output, encoder->getFileType(), "UINT8", roi, inputNumBands);
             }
             else
             {
                 std::cerr << "ERROR: Output file type " << encoder->getFileType() << " does not support" << std::endl
-                    << "requested pixeltype " << input.getPixelType() << "." << std::endl
+                    << "requested pixeltype " << inputPixelType << "." << std::endl
                     << "Save output in other file format." << std::endl;
             };
         };
@@ -120,7 +134,7 @@ void SetCompression(vigra::ImageExportInfo& output, const std::string& compressi
 
 /** loads image one by one and merge with all previouly loaded images, saves the final results */
 template <class ImageType>
-bool LoadAndMergeImages(std::vector<vigra::ImageImportInfo> imageInfos, const std::string& filename, const std::string& compression, const bool wrap, const bool hardSeam)
+bool LoadAndMergeImages(std::vector<vigra::ImageImportInfo> imageInfos, const std::string& filename, const std::string& compression, const bool wrap, const bool hardSeam, const bool useBigTiff)
 {
     if (imageInfos.empty())
     {
@@ -154,14 +168,14 @@ bool LoadAndMergeImages(std::vector<vigra::ImageImportInfo> imageInfos, const st
     };
     // save output
     {
-        vigra::ImageExportInfo exportImageInfo(filename.c_str());
+        vigra::ImageExportInfo exportImageInfo(filename.c_str(), useBigTiff ? "w8" : "w");
         exportImageInfo.setXResolution(imageInfos[0].getXResolution());
         exportImageInfo.setYResolution(imageInfos[0].getYResolution());
         exportImageInfo.setPosition(roi.upperLeft());
         exportImageInfo.setCanvasSize(mask.size());
         exportImageInfo.setICCProfile(imageInfos[0].getICCProfile());
         SetCompression(exportImageInfo, compression);
-        return SaveFinalImage(image, mask, imageInfos[0], exportImageInfo, roi);
+        return SaveFinalImage(image, mask, imageInfos[0].getPixelType(), imageInfos[0].numBands(), exportImageInfo, roi);
     };
 };
 
@@ -179,6 +193,8 @@ static void usage(const char* name)
         << "                            For tiff output: PACKBITS, DEFLATE, LZW" << std::endl
         << "     -w, --wrap          Wraparound 360 deg border." << std::endl
         << "     --seam=hard|blend   Select the blend mode for the seam" << std::endl
+        << "     --bigtiff           Write output in BigTIFF format" << std::endl
+        << "                         (only with TIFF output)" << std::endl
         << "     -h, --help          Shows this help" << std::endl
         << std::endl;
 };
@@ -191,11 +207,13 @@ bool ResaveImage(const vigra::ImageImportInfo& importInfo, vigra::ImageExportInf
 {
     ImageType image(importInfo.size());
     MaskType mask(image.size());
+    int numBands = importInfo.numBands();
     if (importInfo.numExtraBands() == 0)
     {
         vigra::importImage(importInfo, vigra::destImage(image));
         // init mask
         vigra::initImage(vigra::destImageRange(mask), vigra_ext::LUTTraits<typename MaskType::value_type>::max());
+        ++numBands;
     }
     else
     {
@@ -211,7 +229,7 @@ bool ResaveImage(const vigra::ImageImportInfo& importInfo, vigra::ImageExportInf
     };
 
     const vigra::Rect2D roi(vigra::Point2D(0, 0), image.size());
-    return SaveFinalImage(image, mask, importInfo, exportInfo, roi);
+    return SaveFinalImage(image, mask, importInfo.getPixelType(), numBands, exportInfo, roi);
 };
 
 int main(int argc, char* argv[])
@@ -222,7 +240,8 @@ int main(int argc, char* argv[])
     enum
     {
         OPT_COMPRESSION = 1000,
-        OPT_SEAMMODE
+        OPT_SEAMMODE,
+        OPT_BIGTIFF
     };
     static struct option longOptions[] =
     {
@@ -230,17 +249,18 @@ int main(int argc, char* argv[])
         { "compression", required_argument, NULL, OPT_COMPRESSION},
         { "seam", required_argument, NULL, OPT_SEAMMODE},
         { "wrap", no_argument, NULL, 'w' },
+        { "bigtiff", no_argument, NULL, OPT_BIGTIFF},
         { "help", no_argument, NULL, 'h' },
         0
     };
 
     int c;
-    int optionIndex = 0;
     std::string output;
     std::string compression;
     bool wraparound = false;
     bool hardSeam = true;
-    while ((c = getopt_long(argc, argv, optstring, longOptions, &optionIndex)) != -1)
+    bool useBigTIFF = false;
+    while ((c = getopt_long(argc, argv, optstring, longOptions, nullptr)) != -1)
     {
         switch (c)
         {
@@ -270,7 +290,8 @@ int main(int argc, char* argv[])
                     }
                     else
                     {
-                        std::cerr << "String \"" << text << "\" is not a recognized seam blend mode. Ignoring." << std::endl;
+                        std::cerr << hugin_utils::stripPath(argv[0]) << ": String \"" << text << "\" is not a recognized seam blend mode." << std::endl;
+                        return 1;
                     };
                 };
             };
@@ -278,13 +299,16 @@ int main(int argc, char* argv[])
         case 'w':
             wraparound = true;
             break;
+        case OPT_BIGTIFF:
+            useBigTIFF = true;
+            break;
         case ':':
-            std::cerr << "Option " << longOptions[optionIndex].name << " requires a parameter." << std::endl;
+        case '?':
+            // missing argument or invalid switch
             return 1;
             break;
-        case '?':
-            break;
         default:
+            // this should not happen
             abort();
         }
     };
@@ -292,7 +316,7 @@ int main(int argc, char* argv[])
     unsigned nFiles = argc - optind;
     if (nFiles < 1)
     {
-        std::cerr << std::endl << "Error: at least one image need to be specified" << std::endl << std::endl;
+        std::cerr << hugin_utils::stripPath(argv[0]) << ": at least one image need to be specified" << std::endl;
         return 1;
     }
 
@@ -310,7 +334,7 @@ int main(int argc, char* argv[])
 
     if (files.empty())
     {
-        std::cerr << "Error: " << hugin_utils::stripPath(argv[0]) << " needs at least one image." << std::endl;
+        std::cerr << "ERROR: " << hugin_utils::stripPath(argv[0]) << " needs at least one image." << std::endl;
         return 1;
     };
 
@@ -318,13 +342,20 @@ int main(int argc, char* argv[])
     {
         output = "final.tif";
     };
+    hugin_utils::EnforceExtension(output, "tif");
+    if (!hugin_utils::IsFileTypeSupported(output))
+    {
+        std::cerr << "ERROR: Extension \"" << hugin_utils::getExtension(output) << "\" is unknown." << std::endl;
+        return 1;
+    };
+
 
     bool success = false;
     if (files.size() == 1)
     {
         //special case, only one image given
         vigra::ImageImportInfo imageInfo(files[0].c_str());
-        vigra::ImageExportInfo exportInfo(output.c_str());
+        vigra::ImageExportInfo exportInfo(output.c_str(), useBigTIFF ? "w8" : "w");
         exportInfo.setXResolution(imageInfo.getXResolution());
         exportInfo.setYResolution(imageInfo.getYResolution());
         exportInfo.setCanvasSize(imageInfo.getCanvasSize());
@@ -438,31 +469,31 @@ int main(int argc, char* argv[])
         {
             if (pixeltype == "UINT8")
             {
-                success = LoadAndMergeImages<vigra::BRGBImage>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::BRGBImage>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "INT16")
             {
-                success = LoadAndMergeImages<vigra::Int16RGBImage>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::Int16RGBImage>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "UINT16")
             {
-                success = LoadAndMergeImages<vigra::UInt16RGBImage>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::UInt16RGBImage>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "INT32")
             {
-                success = LoadAndMergeImages<vigra::Int32RGBImage>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::Int32RGBImage>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "UINT32")
             {
-                success = LoadAndMergeImages<vigra::UInt32RGBImage>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::UInt32RGBImage>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "FLOAT")
             {
-                success = LoadAndMergeImages<vigra::FRGBImage>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::FRGBImage>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "DOUBLE")
             {
-                success = LoadAndMergeImages<vigra::DRGBImage>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::DRGBImage>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else
             {
@@ -474,31 +505,31 @@ int main(int argc, char* argv[])
             //grayscale images
             if (pixeltype == "UINT8")
             {
-                success = LoadAndMergeImages<vigra::BImage>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::BImage>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "INT16")
             {
-                success = LoadAndMergeImages<vigra::Int16Image>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::Int16Image>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "UINT16")
             {
-                success = LoadAndMergeImages<vigra::UInt16Image>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::UInt16Image>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "INT32")
             {
-                success = LoadAndMergeImages<vigra::Int32Image>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::Int32Image>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "UINT32")
             {
-                success = LoadAndMergeImages<vigra::UInt32Image>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::UInt32Image>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "FLOAT")
             {
-                success = LoadAndMergeImages<vigra::FImage>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::FImage>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else if (pixeltype == "DOUBLE")
             {
-                success = LoadAndMergeImages<vigra::DImage>(imageInfos, output, compression, wraparound, hardSeam);
+                success = LoadAndMergeImages<vigra::DImage>(imageInfos, output, compression, wraparound, hardSeam, useBigTIFF);
             }
             else
             {
