@@ -30,40 +30,24 @@
 
 #include <algorithms/optimizer/PhotometricOptimizer.h>
 #include "ExtractPoints.h"
-
-#ifdef WIN32
 #include <getopt.h>
-#else
-#include <unistd.h>
-#endif
-
 #include <hugin_basic.h>
 #include <nona/Stitcher.h>
 
 #include <tiff.h>
 
-using namespace std;
-using namespace vigra;
-using namespace vigra_ext;
-using namespace AppBase;
-using namespace HuginBase;
-
-
-
 static void usage(const char* name)
 {
-    cerr << name << ": Try to determine the radial vignetting" << std::endl
-         << "vig_optimize version " << hugin_utils::GetHuginVersion() << endl
+    std::cout << name << ": Try to determine the radial vignetting" << std::endl
+         << "vig_optimize version " << hugin_utils::GetHuginVersion() << std::endl
          << std::endl
          << "Usage: " << name  << " [options] -o output.pto input.pto" << std::endl
          << "Valid options are:" << std::endl
-         << "  -o file   write results to output project" << std::endl
-         << "  -v        Verbose, print progress messages" << std::endl
-         << "  -p n      Number of points to extract" << std::endl
-         // random points is default, all points was only implemented for testing purposes
-         // << "  -r        Extract random point (faster, but less accurate)" << std::endl
-         << "  -s level  Work on downscaled images, every step halves width and height" << std::endl
-         << "  -h        Display help (this text)" << std::endl
+         << "  -o|--output file   write results to output project" << std::endl
+         << "  -v|--verbose       Verbose, print progress messages" << std::endl
+         << "  -p n               Number of points to extract" << std::endl
+         << "  -s level           Work on downscaled images, every step halves width and height" << std::endl
+         << "  -h|--help          Display help (this text)" << std::endl
          << std::endl
          << " Expert and debugging options:" << std::endl
          << "  -i file   Read corresponding points from file" << std::endl
@@ -82,10 +66,10 @@ void importROIImage(ImageImportInfo & info, RIMG & img)
 */
 
 
-void loadPointsC(FILE* f, std::vector<PointPairRGB>& vec)
+void loadPointsC(FILE* f, std::vector<vigra_ext::PointPairRGB>& vec)
 {
     double dummy1, dummy2;
-    PointPairRGB point;
+    vigra_ext::PointPairRGB point;
     double i1, i2;
 
     int n=0;
@@ -113,12 +97,12 @@ void loadPointsC(FILE* f, std::vector<PointPairRGB>& vec)
     while (n == 16);
 }
 
-void loadPoints(istream& i, std::vector<PointPairRGB>& vec )
+void loadPoints(std::istream& i, std::vector<vigra_ext::PointPairRGB>& vec )
 {
     while(!i.eof() && i.good())
     {
         double dummy1, dummy2;
-        PointPairRGB point;
+        vigra_ext::PointPairRGB point;
         double i1, i2;
         i >> i1 >> i2
           >> point.p1.x >> point.p1.y
@@ -139,13 +123,12 @@ void loadPoints(istream& i, std::vector<PointPairRGB>& vec )
     }
 }
 
-bool hasphotometricParams(Panorama& pano)
+bool hasphotometricParams(HuginBase::Panorama& pano)
 {
-    OptimizeVector vars=pano.getOptimizeVector();
+    HuginBase::OptimizeVector vars = pano.getOptimizeVector();
 
-    for (OptimizeVector::const_iterator it=vars.begin(); it != vars.end(); ++it)
+    for (HuginBase::OptimizeVector::const_iterator it = vars.begin(); it != vars.end(); ++it)
     {
-        std::set<std::string> cvars;
         for (std::set<std::string>::const_iterator itv = (*it).begin();
                 itv != (*it).end(); ++itv)
         {
@@ -161,23 +144,27 @@ bool hasphotometricParams(Panorama& pano)
 
 int main(int argc, char* argv[])
 {
-    StreamProgressDisplay progressDisplay(std::cout);
+    AppBase::StreamProgressDisplay progressDisplay(std::cout);
 
     // parse arguments
     const char* optstring = "hi:o:p:s:vw:";
+    static struct option longOptions[] =
+    {
+        { "output", required_argument, NULL, 'o' },
+        { "verbose", no_argument, NULL, 'v' },
+        { "help", no_argument, NULL, 'h' },
+        0
+    };
     int c;
 
-    opterr = 0;
-
     int pyrLevel=3;
     int verbose = 0;
     int nPoints = 200;
-    bool randomPoints = true;
     std::string outputFile;
     std::string outputPointsFile;
     std::string inputPointsFile;
-    string basename;
-    while ((c = getopt (argc, argv, optstring)) != -1)
+    while ((c = getopt_long(argc, argv, optstring, longOptions, nullptr)) != -1)
+    {
         switch (c)
         {
             case 'i':
@@ -189,11 +176,8 @@ int main(int argc, char* argv[])
             case 'p':
                 nPoints = atoi(optarg);
                 break;
-            /*case 'r':
-                randomPoints = true;
-                break; */
             case 's':
-                pyrLevel=atoi(optarg);
+                pyrLevel = atoi(optarg);
                 break;
             case 'v':
                 verbose++;
@@ -204,42 +188,53 @@ int main(int argc, char* argv[])
             case 'w':
                 outputPointsFile = optarg;
                 break;
-            default:
-                cerr << "Invalid parameter: " << optarg << std::endl;
-                usage(hugin_utils::stripPath(argv[0]).c_str());
+            case ':':
+            case '?':
+                // missing argument or invalid switch
                 return 1;
+                break;
+            default:
+                // this should not happen
+                abort();
         }
+    };
 
     unsigned nFiles = argc - optind;
     if (nFiles != 1)
     {
-        std::cerr << std::endl << "Error: one pto file needs to be specified" << std::endl <<std::endl;
-        usage(hugin_utils::stripPath(argv[0]).c_str());
+        if (nFiles< 1)
+        {
+            std::cerr << hugin_utils::stripPath(argv[0]) << ": No project file given." << std::endl;
+        }
+        else
+        {
+            std::cerr << hugin_utils::stripPath(argv[0]) << ": Only one project file expected." << std::endl;
+        };
         return 1;
-    }
+    };
 
     const char* scriptFile = argv[optind];
-    Panorama pano;
-    ifstream prjfile(scriptFile);
+    HuginBase::Panorama pano;
+    std::ifstream prjfile(scriptFile);
     if (!prjfile.good())
     {
-        cerr << "could not open script : " << scriptFile << endl;
+        std::cerr << "could not open script : " << scriptFile << std::endl;
         return 1;
     }
     pano.setFilePrefix(hugin_utils::getPathPrefix(scriptFile));
-    DocumentData::ReadWriteError err = pano.readData(prjfile);
-    if (err != DocumentData::SUCCESSFUL)
+    AppBase::DocumentData::ReadWriteError err = pano.readData(prjfile);
+    if (err != AppBase::DocumentData::SUCCESSFUL)
     {
-        cerr << "error while parsing panos tool script: " << scriptFile << endl;
-        cerr << "DocumentData::ReadWriteError code: " << err << endl;
+        std::cerr << "error while parsing panos tool script: " << scriptFile << std::endl;
+        std::cerr << "AppBase::DocumentData::ReadWriteError code: " << err << std::endl;
         return 1;
     }
 
     // Ensure photometric parameters are selected for optimizaion
     if (!hasphotometricParams(pano))
     {
-        cerr << "ERROR:no photometric parameters were selected for optimization" << endl;
-        cerr << "please update 'v' line in .pto script and try again." << endl;
+        std::cerr << "ERROR:no photometric parameters were selected for optimization" << std::endl;
+        std::cerr << "please update 'v' line in .pto script and try again." << std::endl;
         return 1;
     }
 
@@ -251,6 +246,7 @@ int main(int argc, char* argv[])
     {
         std::vector<vigra_ext::PointPairRGB> points;
 
+        float imageStepSize = 1 / 255.0f;
         if (inputPointsFile != "" )
         {
             //ifstream ifs(inputPointsFile.c_str());
@@ -266,11 +262,11 @@ int main(int argc, char* argv[])
         }
         else
         {
-            loadImgsAndExtractPoints(pano, nPoints, pyrLevel, randomPoints, progressDisplay, points, verbose);
+            loadImgsAndExtractPoints(pano, nPoints, pyrLevel, true, progressDisplay, points, verbose, imageStepSize);
         }
         if (verbose)
         {
-            cout << "\rSelected " << points.size() << " points" << std::endl;
+            std::cout << "\rSelected " << points.size() << " points" << std::endl;
         }
         if (points.size() == 0)
         {
@@ -280,8 +276,8 @@ int main(int argc, char* argv[])
 
         if (outputPointsFile.size() > 0)
         {
-            ofstream of(outputPointsFile.c_str());
-            for (std::vector<PointPairRGB>::iterator it = points.begin(); it != points.end(); ++it)
+            std::ofstream of(outputPointsFile.c_str());
+            for (std::vector<vigra_ext::PointPairRGB>::iterator it = points.begin(); it != points.end(); ++it)
             {
                 of << (*it).imgNr1 << " " << (*it).imgNr2 << " "
                    << (*it).p1.x << " " << (*it).p1.y<< " "
@@ -298,13 +294,13 @@ int main(int argc, char* argv[])
 
 
         progressDisplay.setMessage("Vignetting Optimization");
-        PhotometricOptimizer photoopt(pano, &progressDisplay, pano.getOptimizeVector(), points);
+        HuginBase::PhotometricOptimizer photoopt(pano, &progressDisplay, pano.getOptimizeVector(), points, imageStepSize);
         photoopt.run();
         //		double error = photoopt.getResultError();
 
         progressDisplay.taskFinished();
 
-        UIntSet allImgs;
+        HuginBase::UIntSet allImgs;
         fill_set(allImgs,0, pano.getNrOfImages()-1);
         // save project
         if (outputFile == "" || outputFile == "-")
@@ -313,14 +309,14 @@ int main(int argc, char* argv[])
         }
         else
         {
-            ofstream of(outputFile.c_str());
+            std::ofstream of(outputFile.c_str());
             pano.printPanoramaScript(of, pano.getOptimizeVector(), pano.getOptions(), allImgs, false, hugin_utils::getPathPrefix(scriptFile));
         }
 
     }
     catch (std::exception& e)
     {
-        cerr << "caught exception: " << e.what() << std::endl;
+        std::cerr << "caught exception: " << e.what() << std::endl;
         return 1;
     }
     return 0;
